@@ -91,35 +91,35 @@ void genie_backtrace (NODE_T *p)
 
 //! @brief Open a file in ~/.a68g, if possible.
 
-FILE *a68_fopen (char *fn, char *mode, char *new_fn)
+FILE *a68g_fopen (char *fn, char *mode, char *new_fn)
 {
 #if defined (BUILD_WIN32) || !defined (HAVE_DIRENT_H)
-  ASSERT (a68_bufprt (new_fn, SNPRINTF_SIZE, "%s", fn) >= 0);
+  ASSERT (a68g_bufprt (new_fn, SNPRINTF_SIZE, "%s", fn) >= 0);
   return fopen (new_fn, mode);
 #else
   errno = 0;
   BUFFER dn;
-  ASSERT (a68_bufprt (dn, SNPRINTF_SIZE, "%s/%s", getenv ("HOME"), A68_DIR) >= 0);
+  ASSERT (a68g_bufprt (dn, SNPRINTF_SIZE, "%s/%s", getenv ("HOME"), A68_DIR) >= 0);
   int ret = mkdir (dn, (mode_t) (S_IRUSR | S_IWUSR | S_IXUSR));
   if (ret == 0 || (ret == -1 && errno == EEXIST)) {
     struct stat status;
     if (stat (dn, &status) == 0 && S_ISDIR (ST_MODE (&status)) != 0) {
       FILE *f;
-      ASSERT (a68_bufprt (new_fn, SNPRINTF_SIZE, "%s/%s", dn, fn) >= 0);
+      ASSERT (a68g_bufprt (new_fn, SNPRINTF_SIZE, "%s/%s", dn, fn) >= 0);
       f = fopen (new_fn, mode);
       if (f != NO_FILE) {
         return f;
       }
     }
   }
-  ASSERT (a68_bufprt (new_fn, SNPRINTF_SIZE, "%s", fn) >= 0);
+  ASSERT (a68g_bufprt (new_fn, SNPRINTF_SIZE, "%s", fn) >= 0);
   return fopen (new_fn, mode);
 #endif
 }
 
 //! @brief Get terminal size.
 
-void a68_getty (int *h, int *c)
+void a68g_getty (int *h, int *c)
 {
 // Default action first.
   (*h) = MAX_TERM_HEIGTH;
@@ -167,7 +167,7 @@ void sigwinch_handler (int i)
 {
   (void) i;
   ABEND (signal (SIGWINCH, sigwinch_handler) == SIG_ERR, ERROR_ACTION, __func__);
-  a68_getty (&A68 (term_heigth), &A68 (term_width));
+  a68g_getty (&A68 (term_heigth), &A68 (term_width));
 }
 #endif
 
@@ -219,7 +219,7 @@ void sigpipe_handler (int i)
 
 //! @brief Signal alarm - time limit check.
 
-unsigned a68_alarm (unsigned seconds)
+unsigned a68g_alarm (unsigned seconds)
 {
   struct itimerval old, new;
   new.it_interval.tv_usec = 0;
@@ -244,7 +244,7 @@ void sigalrm_handler (int i)
     }
   }
   ABEND (signal (SIGALRM, sigalrm_handler) == SIG_ERR, ERROR_ACTION, __func__);
-  (void) a68_alarm (INTERRUPT_INTERVAL);
+  (void) a68g_alarm (INTERRUPT_INTERVAL);
 }
 
 #endif
@@ -274,7 +274,7 @@ REAL_T seconds (void)
 
 //! @brief Delay for specified number of microseconds.
 
-int a68_usleep (unsigned delay)
+int a68g_usleep (unsigned delay)
 {
 #if defined (BUILD_WIN32)
   errno = ENOSYS; // Function not implemented.
@@ -290,9 +290,9 @@ int a68_usleep (unsigned delay)
 
 //! @brief Safely set buffer.
 
-void *a68_bufset (void *dst, int val, size_t len)
+void *a68g_bufset (void *dst, int val, size_t len)
 {
-// Function a68_bufset can be optimized away by a compiler.
+// Function a68g_bufset can be optimized away by a compiler.
 // Therefore we have this alternative.
   ASSERT (dst != NO_TEXT);
   char *p = (char *) dst;
@@ -304,7 +304,7 @@ void *a68_bufset (void *dst, int val, size_t len)
 
 //! @brief Safely append to buffer.
 
-void a68_bufcat (char *dst, char *src, size_t len)
+void a68g_bufcat (char *dst, char *src, size_t len)
 {
   ASSERT (dst != NO_TEXT);
   ASSERT (src != NO_TEXT);
@@ -332,7 +332,7 @@ void a68_bufcat (char *dst, char *src, size_t len)
 
 //! @brief Safely copy to buffer.
 
-void a68_bufcpy (char *dst, char *src, size_t len)
+void a68g_bufcpy (char *dst, char *src, size_t len)
 {
   ASSERT (dst != NO_TEXT);
   ASSERT (src != NO_TEXT);
@@ -356,7 +356,7 @@ void a68_bufcpy (char *dst, char *src, size_t len)
 
 //! @brief Safely print to buffer.
 
-int a68_bufprt (char *dst, size_t len, const char *format, ...)
+int a68g_bufprt (char *dst, size_t len, const char *format, ...)
 {
   ASSERT (dst != NO_TEXT);
   ASSERT (len > 1);
