@@ -38,9 +38,9 @@ char *error_specification (void)
 {
   static BUFFER txt;
   if (errno == 0) {
-    ASSERT (a68_bufprt (txt, SNPRINTF_SIZE, "no information") >= 0);
+    ASSERT (a68g_bufprt (txt, SNPRINTF_SIZE, "no information") >= 0);
   } else {
-    ASSERT (a68_bufprt (txt, SNPRINTF_SIZE, "%s", strerror (errno)) >= 0);
+    ASSERT (a68g_bufprt (txt, SNPRINTF_SIZE, "%s", strerror (errno)) >= 0);
   }
   if (strlen (txt) > 0) {
     txt[0] = TO_LOWER (txt[0]);
@@ -62,9 +62,9 @@ char *ctrl_char (int ch)
   static char txt[SMALL_BUFFER_SIZE];
   ch = TO_UCHAR (ch);
   if (IS_CNTRL (ch) && IS_LOWER (ch + 96)) {
-    ASSERT (a68_bufprt (txt, (size_t) SMALL_BUFFER_SIZE, "\\^%c", ch + 96) >= 0);
+    ASSERT (a68g_bufprt (txt, (size_t) SMALL_BUFFER_SIZE, "\\^%c", ch + 96) >= 0);
   } else {
-    ASSERT (a68_bufprt (txt, (size_t) SMALL_BUFFER_SIZE, "\\%02x", (unt) ch) >= 0);
+    ASSERT (a68g_bufprt (txt, (size_t) SMALL_BUFFER_SIZE, "\\%02x", (unt) ch) >= 0);
   }
   return txt;
 }
@@ -117,20 +117,20 @@ void pretty_diag (FILE_T f, char *p)
 
 void abend (char *reason, char *info, char *file, int line)
 {
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "%s: exiting: %s: %d: %s", A68 (a68_cmd_name), file, line, reason) >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "%s: exiting: %s: %d: %s", A68 (a68g_cmd_name), file, line, reason) >= 0);
   if (info != NO_TEXT) {
-    a68_bufcat (A68 (output_line), ", ", BUFFER_SIZE);
-    a68_bufcat (A68 (output_line), info, BUFFER_SIZE);
+    a68g_bufcat (A68 (output_line), ", ", BUFFER_SIZE);
+    a68g_bufcat (A68 (output_line), info, BUFFER_SIZE);
   }
   if (errno != 0) {
-    a68_bufcat (A68 (output_line), " (", BUFFER_SIZE);
-    a68_bufcat (A68 (output_line), error_specification (), BUFFER_SIZE);
-    a68_bufcat (A68 (output_line), ")", BUFFER_SIZE);
+    a68g_bufcat (A68 (output_line), " (", BUFFER_SIZE);
+    a68g_bufcat (A68 (output_line), error_specification (), BUFFER_SIZE);
+    a68g_bufcat (A68 (output_line), ")", BUFFER_SIZE);
   }
-  a68_bufcat (A68 (output_line), "\n", BUFFER_SIZE);
+  a68g_bufcat (A68 (output_line), "\n", BUFFER_SIZE);
   io_close_tty_line ();
   pretty_diag (A68_STDERR, A68 (output_line));
-  a68_exit (EXIT_FAILURE);
+  a68g_exit (EXIT_FAILURE);
 }
 
 //! @brief Position in line .
@@ -196,9 +196,9 @@ void write_source_line (FILE_T f, LINE_T * p, NODE_T * nwhere, int mask)
     WRITE (f, NEWLINE_STRING);
   }
   if (NUMBER (p) == 0) {
-    ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "      ") >= 0);
+    ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "      ") >= 0);
   } else {
-    ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "%-5d ", NUMBER (p) % 100000) >= 0);
+    ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "%-5d ", NUMBER (p) % 100000) >= 0);
   }
   WRITE (f, A68 (output_line));
 // Pretty print line.
@@ -211,17 +211,17 @@ void write_source_line (FILE_T f, LINE_T * p, NODE_T * nwhere, int mask)
     int len = 0;
     char *new_pos = NO_TEXT;
     if (c[0] == NULL_CHAR) {
-      a68_bufcpy (A68 (output_line), "", BUFFER_SIZE);
+      a68g_bufcpy (A68 (output_line), "", BUFFER_SIZE);
       line_ended = A68_TRUE;
     } else {
       if (IS_GRAPH (c[0])) {
         char *c1;
-        a68_bufcpy (A68 (output_line), "", BUFFER_SIZE);
+        a68g_bufcpy (A68 (output_line), "", BUFFER_SIZE);
         for (c1 = c; IS_GRAPH (c1[0]) && len <= line_width - 5; c1++, len++) {
-          a68_bufcat (A68 (output_line), char_to_str (c1[0]), BUFFER_SIZE);
+          a68g_bufcat (A68 (output_line), char_to_str (c1[0]), BUFFER_SIZE);
         }
         if (len > line_width - 5) {
-          a68_bufcpy (A68 (output_line), char_to_str (c[0]), BUFFER_SIZE);
+          a68g_bufcpy (A68 (output_line), char_to_str (c[0]), BUFFER_SIZE);
           len = 1;
         }
         new_pos = &c[len];
@@ -230,18 +230,18 @@ void write_source_line (FILE_T f, LINE_T * p, NODE_T * nwhere, int mask)
         int n = TABULATE (col);
         len = n;
         col += n;
-        a68_bufcpy (A68 (output_line), "", BUFFER_SIZE);
+        a68g_bufcpy (A68 (output_line), "", BUFFER_SIZE);
         while (n--) {
-          a68_bufcat (A68 (output_line), " ", BUFFER_SIZE);
+          a68g_bufcat (A68 (output_line), " ", BUFFER_SIZE);
         }
         new_pos = &c[1];
       } else if (unprintable (c[0])) {
-        a68_bufcpy (A68 (output_line), ctrl_char ((int) c[0]), BUFFER_SIZE);
+        a68g_bufcpy (A68 (output_line), ctrl_char ((int) c[0]), BUFFER_SIZE);
         len = (int) strlen (A68 (output_line));
         new_pos = &c[1];
         col++;
       } else {
-        a68_bufcpy (A68 (output_line), char_to_str (c[0]), BUFFER_SIZE);
+        a68g_bufcpy (A68 (output_line), char_to_str (c[0]), BUFFER_SIZE);
         len = 1;
         new_pos = &c[1];
         col++;
@@ -282,32 +282,32 @@ void write_source_line (FILE_T f, LINE_T * p, NODE_T * nwhere, int mask)
             }
           }
           if (y == A68_TRUE && c1 == where_pos (p, nwhere)) {
-            a68_bufcpy (A68 (output_line), "-", BUFFER_SIZE);
+            a68g_bufcpy (A68 (output_line), "-", BUFFER_SIZE);
           } else if (diags_at_this_pos != 0) {
             if (mask == A68_NO_DIAGNOSTICS) {
-              a68_bufcpy (A68 (output_line), " ", BUFFER_SIZE);
+              a68g_bufcpy (A68 (output_line), " ", BUFFER_SIZE);
             } else if (diags_at_this_pos == 1) {
-              ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "%c", digchar (k)) >= 0);
+              ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "%c", digchar (k)) >= 0);
             } else {
-              a68_bufcpy (A68 (output_line), "*", BUFFER_SIZE);
+              a68g_bufcpy (A68 (output_line), "*", BUFFER_SIZE);
             }
           } else {
             if (unprintable (c1[0])) {
               int n = (int) strlen (ctrl_char (c1[0]));
               col_2 += 1;
-              a68_bufcpy (A68 (output_line), "", BUFFER_SIZE);
+              a68g_bufcpy (A68 (output_line), "", BUFFER_SIZE);
               while (n--) {
-                a68_bufcat (A68 (output_line), " ", BUFFER_SIZE);
+                a68g_bufcat (A68 (output_line), " ", BUFFER_SIZE);
               }
             } else if (c1[0] == TAB_CHAR) {
               int n = TABULATE (col_2);
               col_2 += n;
-              a68_bufcpy (A68 (output_line), "", BUFFER_SIZE);
+              a68g_bufcpy (A68 (output_line), "", BUFFER_SIZE);
               while (n--) {
-                a68_bufcat (A68 (output_line), " ", BUFFER_SIZE);
+                a68g_bufcat (A68 (output_line), " ", BUFFER_SIZE);
               }
             } else {
-              a68_bufcpy (A68 (output_line), " ", BUFFER_SIZE);
+              a68g_bufcpy (A68 (output_line), " ", BUFFER_SIZE);
               col_2++;
             }
           }
@@ -317,7 +317,7 @@ void write_source_line (FILE_T f, LINE_T * p, NODE_T * nwhere, int mask)
 // Resume pretty printing of line.
       if (!line_ended) {
         continuations++;
-        ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "\n.%1d   ", continuations) >= 0);
+        ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "\n.%1d   ", continuations) >= 0);
         WRITE (f, A68 (output_line));
         if (continuations >= 9) {
           WRITE (f, "...");
@@ -358,7 +358,7 @@ void diagnostics_to_terminal (LINE_T * p, int sev)
       BOOL_T z = A68_FALSE;
       for (DIAGNOSTIC_T *d = DIAGNOSTICS (p); d != NO_DIAGNOSTIC; FORWARD (d)) {
         if (sev == A68_ALL_DIAGNOSTICS) {
-          z = (BOOL_T) (z | (IS (d, A68_WARNING) || IS (d, A68_ERROR) || IS (d, A68_SYNTAX_ERROR) || IS (d, A68_MATH_ERROR) || IS (d, A68_RUNTIME_ERROR) || IS (d, A68_SUPPRESS_SEVERITY)));
+          z = (BOOL_T) (z | (IS (d, A68_WARNING) || IS (d, A68_ERROR) || IS (d, A68_SYNTAX_ERROR) || IS (d, A68_MATH_ERROR) || IS (d, A68_RUNTIME_ERROR) || IS (d, A68_SCANNER_ERROR)));
         } else if (sev == A68_RUNTIME_ERROR) {
           z = (BOOL_T) (z | (IS (d, A68_RUNTIME_ERROR) || (IS (d, A68_MATH_ERROR))));
         }
@@ -375,9 +375,9 @@ void diagnostics_to_terminal (LINE_T * p, int sev)
 void scan_error (LINE_T * u, char *v, char *txt)
 {
   if (errno != 0) {
-    diagnostic (A68_SUPPRESS_SEVERITY, NO_NODE, txt, u, v, error_specification ());
+    diagnostic (A68_SCANNER_ERROR, NO_NODE, txt, u, v, error_specification ());
   } else {
-    diagnostic (A68_SUPPRESS_SEVERITY, NO_NODE, txt, u, v, ERROR_UNSPECIFIED);
+    diagnostic (A68_SCANNER_ERROR, NO_NODE, txt, u, v, ERROR_UNSPECIFIED);
   }
   longjmp (RENDEZ_VOUS (&A68_JOB), 1);
 }
@@ -386,14 +386,14 @@ void scan_error_info (LINE_T * u, char *v, char *txt, char *info)
 {
   if (info != NO_TEXT) {
     size_t len = strlen (txt) + 3;
-    char *txti = a68_alloc(len, __FILE__, __LINE__);
+    char *txti = a68g_alloc(len, __FILE__, __LINE__);
     ABEND (txti == NO_TEXT, ERROR_OUT_OF_CORE, __func__);
-    a68_bufcpy (txti, txt, len);
-    a68_bufcat (txti, " Z", len);
+    a68g_bufcpy (txti, txt, len);
+    a68g_bufcat (txti, " Z", len);
     if (errno != 0) {
-      diagnostic (A68_SUPPRESS_SEVERITY, NO_NODE, txti, u, v, info, error_specification ());
+      diagnostic (A68_SCANNER_ERROR, NO_NODE, txti, u, v, info, error_specification ());
     } else {
-      diagnostic (A68_SUPPRESS_SEVERITY, NO_NODE, txti, u, v, info, ERROR_UNSPECIFIED);
+      diagnostic (A68_SCANNER_ERROR, NO_NODE, txti, u, v, info, ERROR_UNSPECIFIED);
     }
     longjmp (RENDEZ_VOUS (&A68_JOB), 1);
   } else {
@@ -406,9 +406,9 @@ void scan_error_info (LINE_T * u, char *v, char *txt, char *info)
 void scan_warning (LINE_T * u, char *v, char *txt)
 {
   if (errno != 0) {
-    diagnostic (A68_SUPPRESS_SEVERITY, NO_NODE, txt, u, v, error_specification ());
+    diagnostic (A68_SCANNER_WARNING, NO_NODE, txt, u, v, error_specification ());
   } else {
-    diagnostic (A68_SUPPRESS_SEVERITY, NO_NODE, txt, u, v, ERROR_UNSPECIFIED);
+    diagnostic (A68_SCANNER_WARNING, NO_NODE, txt, u, v, ERROR_UNSPECIFIED);
   }
 }
 
@@ -435,8 +435,11 @@ char *get_severity (int sev)
   case A68_WARNING: {
       return "warning";
     }
-  case A68_SUPPRESS_SEVERITY: {
-      return NO_TEXT;
+  case A68_SCANNER_ERROR: {
+      return "scanner error";
+    }
+  case A68_SCANNER_WARNING: {
+      return "scanner warning";
     }
   default: {
       return NO_TEXT;
@@ -451,10 +454,10 @@ void write_diagnostic (int sev, char *b)
   char txt[SMALL_BUFFER_SIZE];
   char *severity = get_severity (sev);
   if (severity == NO_TEXT) {
-    ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "%s: %s.", A68 (a68_cmd_name), b) >= 0);
+    ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "%s: %s.", A68 (a68g_cmd_name), b) >= 0);
   } else {
-    a68_bufcpy (txt, get_severity (sev), SMALL_BUFFER_SIZE);
-    ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "%s: %s: %s.", A68 (a68_cmd_name), txt, b) >= 0);
+    a68g_bufcpy (txt, get_severity (sev), SMALL_BUFFER_SIZE);
+    ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "%s: %s: %s.", A68 (a68g_cmd_name), txt, b) >= 0);
   }
   io_close_tty_line ();
   pretty_diag (A68_STDERR, A68 (output_line));
@@ -499,19 +502,19 @@ void add_diagnostic (LINE_T * line, char *pos, NODE_T * p, int sev, char *b)
       char *nt = non_terminal_string (A68 (edit_line), ATTRIBUTE (n));
       if (nt != NO_TEXT) {
         if (LINE_NUMBER (n) == 0) {
-          ASSERT (a68_bufprt (nst, SNPRINTF_SIZE, ", in %s", nt) >= 0);
+          ASSERT (a68g_bufprt (nst, SNPRINTF_SIZE, ", in %s", nt) >= 0);
         } else {
           if (MOID (n) != NO_MOID) {
             if (LINE_NUMBER (n) == NUMBER (line)) {
-              ASSERT (a68_bufprt (nst, SNPRINTF_SIZE, ", in %s %s starting at \"%.64s\" in this line", moid_to_string (MOID (n), MOID_ERROR_WIDTH, p), nt, NSYMBOL (n)) >= 0);
+              ASSERT (a68g_bufprt (nst, SNPRINTF_SIZE, ", in %s %s starting at \"%.64s\" in this line", moid_to_string (MOID (n), MOID_ERROR_WIDTH, p), nt, NSYMBOL (n)) >= 0);
             } else {
-              ASSERT (a68_bufprt (nst, SNPRINTF_SIZE, ", in %s %s starting at \"%.64s\" in line %d", moid_to_string (MOID (n), MOID_ERROR_WIDTH, p), nt, NSYMBOL (n), LINE_NUMBER (n)) >= 0);
+              ASSERT (a68g_bufprt (nst, SNPRINTF_SIZE, ", in %s %s starting at \"%.64s\" in line %d", moid_to_string (MOID (n), MOID_ERROR_WIDTH, p), nt, NSYMBOL (n), LINE_NUMBER (n)) >= 0);
             }
           } else {
             if (LINE_NUMBER (n) == NUMBER (line)) {
-              ASSERT (a68_bufprt (nst, SNPRINTF_SIZE, ", in %s starting at \"%.64s\" in this line", nt, NSYMBOL (n)) >= 0);
+              ASSERT (a68g_bufprt (nst, SNPRINTF_SIZE, ", in %s starting at \"%.64s\" in this line", nt, NSYMBOL (n)) >= 0);
             } else {
-              ASSERT (a68_bufprt (nst, SNPRINTF_SIZE, ", in %s starting at \"%.64s\" in line %d", nt, NSYMBOL (n), LINE_NUMBER (n)) >= 0);
+              ASSERT (a68g_bufprt (nst, SNPRINTF_SIZE, ", in %s starting at \"%.64s\" in line %d", nt, NSYMBOL (n), LINE_NUMBER (n)) >= 0);
             }
           }
         }
@@ -520,29 +523,29 @@ void add_diagnostic (LINE_T * line, char *pos, NODE_T * p, int sev, char *b)
   }
   if (severity == NO_TEXT) {
     if (FILENAME (line) != NO_TEXT && strcmp (FILE_SOURCE_NAME (&A68_JOB), FILENAME (line)) == 0) {
-      ASSERT (a68_bufprt (a, SNPRINTF_SIZE, "%s: %x: %s", A68 (a68_cmd_name), (unt) k, b) >= 0);
+      ASSERT (a68g_bufprt (a, SNPRINTF_SIZE, "%s: %x: %s", A68 (a68g_cmd_name), (unt) k, b) >= 0);
     } else if (FILENAME (line) != NO_TEXT) {
-      ASSERT (a68_bufprt (a, SNPRINTF_SIZE, "%s: %s: %x: %s", A68 (a68_cmd_name), FILENAME (line), (unt) k, b) >= 0);
+      ASSERT (a68g_bufprt (a, SNPRINTF_SIZE, "%s: %s: %x: %s", A68 (a68g_cmd_name), FILENAME (line), (unt) k, b) >= 0);
     } else {
-      ASSERT (a68_bufprt (a, SNPRINTF_SIZE, "%s: %x: %s", A68 (a68_cmd_name), (unt) k, b) >= 0);
+      ASSERT (a68g_bufprt (a, SNPRINTF_SIZE, "%s: %x: %s", A68 (a68g_cmd_name), (unt) k, b) >= 0);
     }
   } else {
-    a68_bufcpy (st, get_severity (sev), SMALL_BUFFER_SIZE);
+    a68g_bufcpy (st, get_severity (sev), SMALL_BUFFER_SIZE);
     if (FILENAME (line) != NO_TEXT && strcmp (FILE_SOURCE_NAME (&A68_JOB), FILENAME (line)) == 0) {
-      ASSERT (a68_bufprt (a, SNPRINTF_SIZE, "%s: %s: %x: %s", A68 (a68_cmd_name), st, (unt) k, b) >= 0);
+      ASSERT (a68g_bufprt (a, SNPRINTF_SIZE, "%s: %s: %x: %s", A68 (a68g_cmd_name), st, (unt) k, b) >= 0);
     } else if (FILENAME (line) != NO_TEXT) {
-      ASSERT (a68_bufprt (a, SNPRINTF_SIZE, "%s: %s: %s: %x: %s", A68 (a68_cmd_name), FILENAME (line), st, (unt) k, b) >= 0);
+      ASSERT (a68g_bufprt (a, SNPRINTF_SIZE, "%s: %s: %s: %x: %s", A68 (a68g_cmd_name), FILENAME (line), st, (unt) k, b) >= 0);
     } else {
-      ASSERT (a68_bufprt (a, SNPRINTF_SIZE, "%s: %s: %x: %s", A68 (a68_cmd_name), st, (unt) k, b) >= 0);
+      ASSERT (a68g_bufprt (a, SNPRINTF_SIZE, "%s: %s: %x: %s", A68 (a68g_cmd_name), st, (unt) k, b) >= 0);
     }
   }
 // cppcheck might complain here but this memory is not returned, for obvious reasons.
   *ref_msg = msg;
   ATTRIBUTE (msg) = sev;
   if (nst[0] != NULL_CHAR) {
-    a68_bufcat (a, nst, BUFFER_SIZE);
+    a68g_bufcat (a, nst, BUFFER_SIZE);
   }
-  a68_bufcat (a, ".", BUFFER_SIZE);
+  a68g_bufcat (a, ".", BUFFER_SIZE);
   TEXT (msg) = new_string (a, NO_TEXT);
   WHERE (msg) = p;
   LINE (msg) = line;
@@ -590,7 +593,7 @@ void diagnostic (STATUS_MASK_T sev, NODE_T * p, char *loc_str, ...)
 // Suppressed?.
   if (sev == A68_ERROR || sev == A68_SYNTAX_ERROR) {
     if (ERROR_COUNT (&A68_JOB) == MAX_ERRORS) {
-      a68_bufcpy (b, "further diagnostics suppressed", BUFFER_SIZE);
+      a68g_bufcpy (b, "further diagnostics suppressed", BUFFER_SIZE);
       compose = A68_FALSE;
       sev = A68_ERROR;
     } else if (ERROR_COUNT (&A68_JOB) > MAX_ERRORS) {
@@ -599,7 +602,7 @@ void diagnostic (STATUS_MASK_T sev, NODE_T * p, char *loc_str, ...)
     }
   } else if (sev == A68_WARNING || sev == A68_MATH_WARNING) {
     if (WARNING_COUNT (&A68_JOB) == MAX_ERRORS) {
-      a68_bufcpy (b, "further diagnostics suppressed", BUFFER_SIZE);
+      a68g_bufcpy (b, "further diagnostics suppressed", BUFFER_SIZE);
       compose = A68_FALSE;
     } else if (WARNING_COUNT (&A68_JOB) > MAX_ERRORS) {
       WARNING_COUNT (&A68_JOB)++;
@@ -610,7 +613,7 @@ void diagnostic (STATUS_MASK_T sev, NODE_T * p, char *loc_str, ...)
 // Synthesize diagnostic message.
     if ((sev & A68_NO_SYNTHESIS) != NULL_MASK) {
       sev &= ~A68_NO_SYNTHESIS;
-      a68_bufcat (b, t, BUFFER_SIZE);
+      a68g_bufcat (b, t, BUFFER_SIZE);
     } else {
 // Legend for special symbols:
 // * as first character, copy rest of string literally
@@ -631,82 +634,82 @@ void diagnostic (STATUS_MASK_T sev, NODE_T * p, char *loc_str, ...)
 // Y string literal. 
 // Z quoted string literal. 
       if (t[0] == '*') {
-        a68_bufcat (b, &t[1], BUFFER_SIZE);
+        a68g_bufcat (b, &t[1], BUFFER_SIZE);
       } else
         while (t[0] != NULL_CHAR) {
           if (t[0] == '#') {
             ;
           } else if (t[0] == '@') {
             if (p == NO_NODE) {
-              a68_bufcat (b, "construct", BUFFER_SIZE);
+              a68g_bufcat (b, "construct", BUFFER_SIZE);
             } else {
               char *nt = non_terminal_string (A68 (edit_line), ATTRIBUTE (p));
               if (t != NO_TEXT) {
-                a68_bufcat (b, nt, BUFFER_SIZE);
+                a68g_bufcat (b, nt, BUFFER_SIZE);
               } else {
-                a68_bufcat (b, "construct", BUFFER_SIZE);
+                a68g_bufcat (b, "construct", BUFFER_SIZE);
               }
             }
           } else if (t[0] == 'A') {
             int att = va_arg (args, int);
             char *nt = non_terminal_string (A68 (edit_line), att);
             if (nt != NO_TEXT) {
-              a68_bufcat (b, nt, BUFFER_SIZE);
+              a68g_bufcat (b, nt, BUFFER_SIZE);
             } else {
-              a68_bufcat (b, "construct", BUFFER_SIZE);
+              a68g_bufcat (b, "construct", BUFFER_SIZE);
             }
           } else if (t[0] == 'B') {
             int att = va_arg (args, int);
             KEYWORD_T *nt = find_keyword_from_attribute (A68 (top_keyword), att);
             if (nt != NO_KEYWORD) {
-              a68_bufcat (b, "\"", BUFFER_SIZE);
-              a68_bufcat (b, TEXT (nt), BUFFER_SIZE);
-              a68_bufcat (b, "\"", BUFFER_SIZE);
+              a68g_bufcat (b, "\"", BUFFER_SIZE);
+              a68g_bufcat (b, TEXT (nt), BUFFER_SIZE);
+              a68g_bufcat (b, "\"", BUFFER_SIZE);
             } else {
-              a68_bufcat (b, "keyword", BUFFER_SIZE);
+              a68g_bufcat (b, "keyword", BUFFER_SIZE);
             }
           } else if (t[0] == 'C') {
             int att = va_arg (args, int);
             if (att == NO_SORT) {
-              a68_bufcat (b, "this", BUFFER_SIZE);
+              a68g_bufcat (b, "this", BUFFER_SIZE);
             }
             if (att == SOFT) {
-              a68_bufcat (b, "a soft", BUFFER_SIZE);
+              a68g_bufcat (b, "a soft", BUFFER_SIZE);
             } else if (att == WEAK) {
-              a68_bufcat (b, "a weak", BUFFER_SIZE);
+              a68g_bufcat (b, "a weak", BUFFER_SIZE);
             } else if (att == MEEK) {
-              a68_bufcat (b, "a meek", BUFFER_SIZE);
+              a68g_bufcat (b, "a meek", BUFFER_SIZE);
             } else if (att == FIRM) {
-              a68_bufcat (b, "a firm", BUFFER_SIZE);
+              a68g_bufcat (b, "a firm", BUFFER_SIZE);
             } else if (att == STRONG) {
-              a68_bufcat (b, "a strong", BUFFER_SIZE);
+              a68g_bufcat (b, "a strong", BUFFER_SIZE);
             }
           } else if (t[0] == 'D') {
             int a = va_arg (args, int);
             BUFFER d;
             BUFCLR (d);
-            ASSERT (a68_bufprt (d, SNPRINTF_SIZE, "%d", a) >= 0);
-            a68_bufcat (b, d, BUFFER_SIZE);
+            ASSERT (a68g_bufprt (d, SNPRINTF_SIZE, "%d", a) >= 0);
+            a68g_bufcat (b, d, BUFFER_SIZE);
           } else if (t[0] == 'H') {
             char *a = va_arg (args, char *);
             char d[SMALL_BUFFER_SIZE];
-            ASSERT (a68_bufprt (d, (size_t) SMALL_BUFFER_SIZE, "\"%c\"", a[0]) >= 0);
-            a68_bufcat (b, d, BUFFER_SIZE);
+            ASSERT (a68g_bufprt (d, (size_t) SMALL_BUFFER_SIZE, "\"%c\"", a[0]) >= 0);
+            a68g_bufcat (b, d, BUFFER_SIZE);
           } else if (t[0] == 'K') {
-            a68_bufcat (b, "LONG", BUFFER_SIZE);
+            a68g_bufcat (b, "LONG", BUFFER_SIZE);
           } else if (t[0] == 'L') {
             LINE_T *a = va_arg (args, LINE_T *);
             char d[SMALL_BUFFER_SIZE];
             ABEND (a == NO_LINE, ERROR_INTERNAL_CONSISTENCY, __func__);
             if (NUMBER (a) == 0) {
-              a68_bufcat (b, "in standard environment", BUFFER_SIZE);
+              a68g_bufcat (b, "in standard environment", BUFFER_SIZE);
             } else {
               if (p != NO_NODE && NUMBER (a) == LINE_NUMBER (p)) {
-                ASSERT (a68_bufprt (d, (size_t) SMALL_BUFFER_SIZE, "in this line") >= 0);
+                ASSERT (a68g_bufprt (d, (size_t) SMALL_BUFFER_SIZE, "in this line") >= 0);
               } else {
-                ASSERT (a68_bufprt (d, (size_t) SMALL_BUFFER_SIZE, "in line %d", NUMBER (a)) >= 0);
+                ASSERT (a68g_bufprt (d, (size_t) SMALL_BUFFER_SIZE, "in line %d", NUMBER (a)) >= 0);
               }
-              a68_bufcat (b, d, BUFFER_SIZE);
+              a68g_bufcat (b, d, BUFFER_SIZE);
             }
           } else if (t[0] == 'M') {
             moid = va_arg (args, MOID_T *);
@@ -715,18 +718,18 @@ void diagnostic (STATUS_MASK_T sev, NODE_T * p, char *loc_str, ...)
             }
             if (IS (moid, SERIES_MODE)) {
               if (PACK (moid) != NO_PACK && NEXT (PACK (moid)) == NO_PACK) {
-                a68_bufcat (b, moid_to_string (MOID (PACK (moid)), MOID_ERROR_WIDTH, p), BUFFER_SIZE);
+                a68g_bufcat (b, moid_to_string (MOID (PACK (moid)), MOID_ERROR_WIDTH, p), BUFFER_SIZE);
               } else {
-                a68_bufcat (b, moid_to_string (moid, MOID_ERROR_WIDTH, p), BUFFER_SIZE);
+                a68g_bufcat (b, moid_to_string (moid, MOID_ERROR_WIDTH, p), BUFFER_SIZE);
               }
             } else {
-              a68_bufcat (b, moid_to_string (moid, MOID_ERROR_WIDTH, p), BUFFER_SIZE);
+              a68g_bufcat (b, moid_to_string (moid, MOID_ERROR_WIDTH, p), BUFFER_SIZE);
             }
           } else if (t[0] == 'N') {
-            a68_bufcat (b, "NIL name of mode ", BUFFER_SIZE);
+            a68g_bufcat (b, "NIL name of mode ", BUFFER_SIZE);
             moid = va_arg (args, MOID_T *);
             if (moid != NO_MOID) {
-              a68_bufcat (b, moid_to_string (moid, MOID_ERROR_WIDTH, p), BUFFER_SIZE);
+              a68g_bufcat (b, moid_to_string (moid, MOID_ERROR_WIDTH, p), BUFFER_SIZE);
             }
           } else if (t[0] == 'O') {
             moid = va_arg (args, MOID_T *);
@@ -734,31 +737,31 @@ void diagnostic (STATUS_MASK_T sev, NODE_T * p, char *loc_str, ...)
               moid = M_UNDEFINED;
             }
             if (moid == M_VOID) {
-              a68_bufcat (b, "UNION (VOID, ..)", BUFFER_SIZE);
+              a68g_bufcat (b, "UNION (VOID, ..)", BUFFER_SIZE);
             } else if (IS (moid, SERIES_MODE)) {
               if (PACK (moid) != NO_PACK && NEXT (PACK (moid)) == NO_PACK) {
-                a68_bufcat (b, moid_to_string (MOID (PACK (moid)), MOID_ERROR_WIDTH, p), BUFFER_SIZE);
+                a68g_bufcat (b, moid_to_string (MOID (PACK (moid)), MOID_ERROR_WIDTH, p), BUFFER_SIZE);
               } else {
-                a68_bufcat (b, moid_to_string (moid, MOID_ERROR_WIDTH, p), BUFFER_SIZE);
+                a68g_bufcat (b, moid_to_string (moid, MOID_ERROR_WIDTH, p), BUFFER_SIZE);
               }
             } else {
-              a68_bufcat (b, moid_to_string (moid, MOID_ERROR_WIDTH, p), BUFFER_SIZE);
+              a68g_bufcat (b, moid_to_string (moid, MOID_ERROR_WIDTH, p), BUFFER_SIZE);
             }
           } else if (t[0] == 'S') {
             if (p != NO_NODE && NSYMBOL (p) != NO_TEXT) {
               char *txt = NSYMBOL (p);
               char *sym = NCHAR_IN_LINE (p);
               int n = 0, size = (int) strlen (txt);
-              a68_bufcat (b, "\"", BUFFER_SIZE);
+              a68g_bufcat (b, "\"", BUFFER_SIZE);
               if (txt[0] != sym[0] || (int) strlen (sym) < size) {
-                a68_bufcat (b, txt, BUFFER_SIZE);
+                a68g_bufcat (b, txt, BUFFER_SIZE);
               } else {
                 while (n < size) {
                   if (IS_PRINT (sym[0])) {
                     char str[2];
                     str[0] = sym[0];
                     str[1] = NULL_CHAR;
-                    a68_bufcat (b, str, BUFFER_SIZE);
+                    a68g_bufcat (b, str, BUFFER_SIZE);
                   }
                   if (TO_LOWER (txt[0]) == TO_LOWER (sym[0])) {
                     txt++;
@@ -767,34 +770,34 @@ void diagnostic (STATUS_MASK_T sev, NODE_T * p, char *loc_str, ...)
                   sym++;
                 }
               }
-              a68_bufcat (b, "\"", BUFFER_SIZE);
+              a68g_bufcat (b, "\"", BUFFER_SIZE);
             } else {
-              a68_bufcat (b, "symbol", BUFFER_SIZE);
+              a68g_bufcat (b, "symbol", BUFFER_SIZE);
             }
           } else if (t[0] == 'V') {
-            a68_bufcat (b, PACKAGE_STRING, BUFFER_SIZE);
+            a68g_bufcat (b, PACKAGE_STRING, BUFFER_SIZE);
           } else if (t[0] == 'X') {
             int att = va_arg (args, int);
             BUFFER z;
             (void) non_terminal_string (z, att);
-            a68_bufcat (b, new_string (z, NO_TEXT), BUFFER_SIZE);
+            a68g_bufcat (b, new_string (z, NO_TEXT), BUFFER_SIZE);
           } else if (t[0] == 'Y') {
             char *loc_string = va_arg (args, char *);
             if (loc_string != NO_TEXT) {
-              a68_bufcat (b, loc_string, BUFFER_SIZE);
+              a68g_bufcat (b, loc_string, BUFFER_SIZE);
             }
           } else if (t[0] == 'Z') {
             char *loc_string = va_arg (args, char *);
-            a68_bufcat (b, "\"", BUFFER_SIZE);
+            a68g_bufcat (b, "\"", BUFFER_SIZE);
             if (loc_string != NO_TEXT) {
-              a68_bufcat (b, loc_string, BUFFER_SIZE);
+              a68g_bufcat (b, loc_string, BUFFER_SIZE);
             }
-            a68_bufcat (b, "\"", BUFFER_SIZE);
+            a68g_bufcat (b, "\"", BUFFER_SIZE);
           } else {
             char q[2];
             q[0] = t[0];
             q[1] = NULL_CHAR;
-            a68_bufcat (b, q, BUFFER_SIZE);
+            a68g_bufcat (b, q, BUFFER_SIZE);
           }
           t++;
         }
@@ -803,11 +806,11 @@ void diagnostic (STATUS_MASK_T sev, NODE_T * p, char *loc_str, ...)
         char *loc_str2 = new_string (error_specification (), NO_TEXT);
         if (loc_str2 != NO_TEXT) {
           char *stu;
-          a68_bufcat (b, ", ", BUFFER_SIZE);
+          a68g_bufcat (b, ", ", BUFFER_SIZE);
           for (stu = loc_str2; stu[0] != NULL_CHAR; stu++) {
             stu[0] = (char) TO_LOWER (stu[0]);
           }
-          a68_bufcat (b, loc_str2, BUFFER_SIZE);
+          a68g_bufcat (b, loc_str2, BUFFER_SIZE);
         }
       }
     }
