@@ -70,9 +70,9 @@ char *read_string_from_tty (char *prompt)
   if (line != NO_TEXT && (int) strlen (line) > 0) {
     add_history (line);
   }
-  a68_bufcpy (A68 (input_line), line, BUFFER_SIZE);
+  a68g_bufcpy (A68 (input_line), line, BUFFER_SIZE);
   A68 (chars_in_stdout) = (int) strlen (A68 (input_line));
-  a68_free (line);
+  a68g_free (line);
   return A68 (input_line);
 #else
   int ch, k = 0, n;
