@@ -37,7 +37,7 @@ void init_heap (void)
   REAL_T /* sic */ total_size = A68_ALIGN (heap_a_size + handle_a_size + frame_a_size + 2 * expr_a_size);
   ABEND (OVER_2G (total_size), ERROR_OVER_2G, __func__);
   errno = 0;
-  BYTE_T *core = (BYTE_T *) (A68_ALIGN_T *) a68_alloc ((size_t) total_size, __func__, __LINE__);
+  BYTE_T *core = (BYTE_T *) (A68_ALIGN_T *) a68g_alloc ((size_t) total_size, __func__, __LINE__);
   ABEND (core == NO_BYTE, ERROR_OUT_OF_CORE, __func__);
   A68_HEAP = NO_BYTE;
   A68_HANDLES = NO_BYTE;
@@ -59,7 +59,7 @@ void init_heap (void)
 
 //! @brief aligned allocation.
 
-void *a68_alloc (size_t len, const char *f, int line)
+void *a68g_alloc (size_t len, const char *f, int line)
 {
 // We need this since malloc aligns to "standard C types".
 // __float128 is not a standard type, apparently ...
@@ -90,7 +90,7 @@ void *a68_alloc (size_t len, const char *f, int line)
 #endif
     if (p == (void *) NULL || errno != 0) {
       static BUFFER msg;
-      a68_bufprt (msg, SNPRINTF_SIZE, "cannot allocate %lu bytes; called from function %s, line %d", (long unt) len, f, line);
+      a68g_bufprt (msg, SNPRINTF_SIZE, "cannot allocate %lu bytes; called from function %s, line %d", (long unt) len, f, line);
       ABEND (A68_TRUE, ERROR_ALLOCATION, msg);
     }
     errno = save;
@@ -100,7 +100,7 @@ void *a68_alloc (size_t len, const char *f, int line)
   }
 }
 
-void a68_free (void *z)
+void a68g_free (void *z)
 {
   if (z != NULL) {
 #if defined (BUILD_WIN32)
@@ -117,7 +117,7 @@ void a68_free (void *z)
 BYTE_T *get_heap_space (size_t s)
 {
   ABEND (s == 0, ERROR_INVALID_SIZE, __func__);
-  BYTE_T *z = (BYTE_T *) (A68_ALIGN_T *) a68_alloc (A68_ALIGN (s), __func__, __LINE__);
+  BYTE_T *z = (BYTE_T *) (A68_ALIGN_T *) a68g_alloc (A68_ALIGN (s), __func__, __LINE__);
   ABEND (z == NO_BYTE, ERROR_OUT_OF_CORE, __func__);
   return z;
 }
@@ -145,7 +145,7 @@ char *new_string (char *t, ...)
   q = t;
   va_start (vl, t);
   while (q != NO_TEXT) {
-    a68_bufcat (z, q, len);
+    a68g_bufcat (z, q, len);
     q = va_arg (vl, char *);
   }
   va_end (vl);
@@ -158,7 +158,7 @@ char *new_fixed_string (char *t)
 {
   int n = (int) (strlen (t) + 1);
   char *z = (char *) get_fixed_heap_space ((size_t) n);
-  a68_bufcpy (z, t, n);
+  a68g_bufcpy (z, t, n);
   return z;
 }
 
@@ -168,7 +168,7 @@ char *new_temp_string (char *t)
 {
   int n = (int) (strlen (t) + 1);
   char *z = (char *) get_temp_heap_space ((size_t) n);
-  a68_bufcpy (z, t, n);
+  a68g_bufcpy (z, t, n);
   return z;
 }
 
@@ -233,9 +233,9 @@ void genie_free (NODE_T * p)
   for (; p != NO_NODE; FORWARD (p)) {
     genie_free (SUB (p));
     if (GINFO (p) != NO_GINFO) {
-      a68_free (CONSTANT (GINFO (p)));
+      a68g_free (CONSTANT (GINFO (p)));
       CONSTANT (GINFO (p)) = NO_CONSTANT;
-      a68_free (COMPILE_NAME (GINFO (p)));
+      a68g_free (COMPILE_NAME (GINFO (p)));
       COMPILE_NAME (GINFO (p)) = NO_TEXT;
     }
   }
@@ -247,14 +247,14 @@ void free_syntax_tree (NODE_T * p)
 {
   for (; p != NO_NODE; FORWARD (p)) {
     free_syntax_tree (SUB (p));
-    a68_free (NPRAGMENT (p));
+    a68g_free (NPRAGMENT (p));
     NPRAGMENT (p) = NO_TEXT;
     DIAGNOSTIC_T *d = DIAGNOSTICS (LINE (INFO (p)));
     while (d != NO_DIAGNOSTIC) {
-      a68_free (TEXT (d));
+      a68g_free (TEXT (d));
       DIAGNOSTIC_T *stale = d;
       FORWARD (d);
-      a68_free (stale);
+      a68g_free (stale);
     }
     DIAGNOSTICS (LINE (INFO (p))) = NO_DIAGNOSTIC;
   }
