@@ -398,7 +398,7 @@ char *non_terminal_string (char *buf, int att)
   if (att > 0 && att < WILDCARD) {
     if (attribute_names[att] != NO_TEXT) {
       char *q = buf;
-      a68_bufcpy (q, attribute_names[att], BUFFER_SIZE);
+      a68g_bufcpy (q, attribute_names[att], BUFFER_SIZE);
       while (q[0] != NULL_CHAR) {
         if (q[0] == '_') {
           q[0] = '-';
