@@ -66,8 +66,8 @@ void read_rc_options (void)
   BUFFER name, new_name;
   BUFCLR (name);
   BUFCLR (new_name);
-  ASSERT (a68_bufprt (name, SNPRINTF_SIZE, ".%src", A68 (a68_cmd_name)) >= 0);
-  FILE *f = a68_fopen (name, "r", new_name);
+  ASSERT (a68g_bufprt (name, SNPRINTF_SIZE, ".%src", A68 (a68g_cmd_name)) >= 0);
+  FILE *f = a68g_fopen (name, "r", new_name);
   if (f != NO_FILE) {
     while (!feof (f)) {
       if (fgets (A68 (input_line), BUFFER_SIZE, f) != NO_TEXT) {
@@ -193,11 +193,11 @@ void default_options (MODULE_T * p)
 
 void option_error (LINE_T * l, char *option, char *info)
 {
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "%s", option) >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "%s", option) >= 0);
   if (info != NO_TEXT) {
-    ASSERT (a68_bufprt (A68 (edit_line), SNPRINTF_SIZE, "*error: %s option \"%s\"", info, A68 (output_line)) >= 0);
+    ASSERT (a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "*error: %s option \"%s\"", info, A68 (output_line)) >= 0);
   } else {
-    ASSERT (a68_bufprt (A68 (edit_line), SNPRINTF_SIZE, "*error: in option \"%s\"", A68 (output_line)) >= 0);
+    ASSERT (a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "*error: in option \"%s\"", A68 (output_line)) >= 0);
   }
   scan_error (l, NO_TEXT, A68 (edit_line));
 }
@@ -234,8 +234,8 @@ void free_option_list (OPTION_LIST_T * l)
 {
   if (l != NO_OPTION_LIST) {
     free_option_list (NEXT (l));
-    a68_free (STR (l));
-    a68_free (l);
+    a68g_free (STR (l));
+    a68g_free (l);
   }
 }
 
@@ -243,7 +243,7 @@ void free_option_list (OPTION_LIST_T * l)
 
 void init_options (void)
 {
-  A68 (options) = (OPTIONS_T *) a68_alloc ((size_t) SIZE_ALIGNED (OPTIONS_T), __func__, __LINE__);
+  A68 (options) = (OPTIONS_T *) a68g_alloc ((size_t) SIZE_ALIGNED (OPTIONS_T), __func__, __LINE__);
   OPTION_LIST (&A68_JOB) = NO_OPTION_LIST;
 }
 
@@ -272,7 +272,7 @@ void prune_echoes (OPTION_LIST_T * i)
           char *car = strchr (p, '=');
           if (car != NO_TEXT) {
             io_close_tty_line ();
-            ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "%s", &car[1]) >= 0);
+            ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "%s", &car[1]) >= 0);
             WRITE (A68_STDOUT, A68 (output_line));
           } else {
             FORWARD (i);
@@ -282,14 +282,14 @@ void prune_echoes (OPTION_LIST_T * i)
               }
               if (i != NO_OPTION_LIST) {
                 io_close_tty_line ();
-                ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "%s", STR (i)) >= 0);
+                ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "%s", STR (i)) >= 0);
                 WRITE (A68_STDOUT, A68 (output_line));
               }
             }
           }
         }
       }
-      a68_free (p);
+      a68g_free (p);
     }
     if (i != NO_OPTION_LIST) {
       FORWARD (i);
@@ -385,34 +385,34 @@ int fetch_integral (char *p, OPTION_LIST_T ** i, BOOL_T * error)
 static void tech_stuff (void)
 {
   state_version (A68_STDOUT);
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "sizeof (A68_REF) = %u", (unt) sizeof (A68_REF)) >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "sizeof (A68_REF) = %u", (unt) sizeof (A68_REF)) >= 0);
   WRITELN (A68_STDOUT, A68 (output_line));
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "sizeof (A68_PROCEDURE) = %u", (unt) sizeof (A68_PROCEDURE)) >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "sizeof (A68_PROCEDURE) = %u", (unt) sizeof (A68_PROCEDURE)) >= 0);
   WRITELN (A68_STDOUT, A68 (output_line));
 #if (A68_LEVEL >= 3)
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "sizeof (DOUBLE_T) = %u", (unt) sizeof (DOUBLE_T)) >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "sizeof (DOUBLE_T) = %u", (unt) sizeof (DOUBLE_T)) >= 0);
   WRITELN (A68_STDOUT, A68 (output_line));
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "sizeof (DOUBLE_NUM_T) = %u", (unt) sizeof (DOUBLE_NUM_T)) >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "sizeof (DOUBLE_NUM_T) = %u", (unt) sizeof (DOUBLE_NUM_T)) >= 0);
   WRITELN (A68_STDOUT, A68 (output_line));
 #endif
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "sizeof (A68_INT) = %u", (unt) sizeof (A68_INT)) >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "sizeof (A68_INT) = %u", (unt) sizeof (A68_INT)) >= 0);
   WRITELN (A68_STDOUT, A68 (output_line));
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "sizeof (A68_REAL) = %u", (unt) sizeof (A68_REAL)) >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "sizeof (A68_REAL) = %u", (unt) sizeof (A68_REAL)) >= 0);
   WRITELN (A68_STDOUT, A68 (output_line));
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "sizeof (A68_BOOL) = %u", (unt) sizeof (A68_BOOL)) >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "sizeof (A68_BOOL) = %u", (unt) sizeof (A68_BOOL)) >= 0);
   WRITELN (A68_STDOUT, A68 (output_line));
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "sizeof (A68_CHAR) = %u", (unt) sizeof (A68_CHAR)) >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "sizeof (A68_CHAR) = %u", (unt) sizeof (A68_CHAR)) >= 0);
   WRITELN (A68_STDOUT, A68 (output_line));
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "sizeof (A68_BITS) = %u", (unt) sizeof (A68_BITS)) >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "sizeof (A68_BITS) = %u", (unt) sizeof (A68_BITS)) >= 0);
   WRITELN (A68_STDOUT, A68 (output_line));
 #if (A68_LEVEL >= 3)
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "sizeof (A68_LONG_REAL) = %u", (unt) sizeof (A68_LONG_REAL)) >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "sizeof (A68_LONG_REAL) = %u", (unt) sizeof (A68_LONG_REAL)) >= 0);
   WRITELN (A68_STDOUT, A68 (output_line));
 #else
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "sizeof (A68_LONG_REAL) = %u", (unt) size_mp ()) >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "sizeof (A68_LONG_REAL) = %u", (unt) size_mp ()) >= 0);
   WRITELN (A68_STDOUT, A68 (output_line));
 #endif
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "sizeof (A68_LONG_LONG_REAL) = %u", (unt) size_long_mp ()) >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "sizeof (A68_LONG_LONG_REAL) = %u", (unt) size_long_mp ()) >= 0);
   WRITELN (A68_STDOUT, A68 (output_line));
   WRITELN (A68_STDOUT, "");
   exit (EXIT_SUCCESS);
@@ -429,7 +429,7 @@ BOOL_T need_library (OPTION_LIST_T *i)
 #else
     io_close_tty_line ();
     WRITE (A68_STDERR, "plugin compiler required - exiting graciously");
-    a68_exit (EXIT_SUCCESS);
+    a68g_exit (EXIT_SUCCESS);
 #endif
   }
   if (eq (q, "curl")) {
@@ -438,7 +438,7 @@ BOOL_T need_library (OPTION_LIST_T *i)
 #else
     io_close_tty_line ();
     WRITE (A68_STDERR, "curl library required - exiting graciously");
-    a68_exit (EXIT_SUCCESS);
+    a68g_exit (EXIT_SUCCESS);
 #endif
   }
   if (eq (q, "curses")) {
@@ -447,7 +447,7 @@ BOOL_T need_library (OPTION_LIST_T *i)
 #else
     io_close_tty_line ();
     WRITE (A68_STDERR, "curses required - exiting graciously");
-    a68_exit (EXIT_SUCCESS);
+    a68g_exit (EXIT_SUCCESS);
 #endif
   }
   if (eq (q, "gsl")) {
@@ -456,14 +456,14 @@ BOOL_T need_library (OPTION_LIST_T *i)
 #else
     io_close_tty_line ();
     WRITE (A68_STDERR, "GNU Scientific Library required - exiting graciously");
-    a68_exit (EXIT_SUCCESS);
+    a68g_exit (EXIT_SUCCESS);
 #endif
   }
   if (eq (q, "http")) {
 #if !defined (HAVE_CURL)
     io_close_tty_line ();
     WRITELN (A68_STDERR, "curl required - exiting graciously");
-    a68_exit (EXIT_SUCCESS);
+    a68g_exit (EXIT_SUCCESS);
 #else
     return (A68_TRUE);
 #endif
@@ -474,7 +474,7 @@ BOOL_T need_library (OPTION_LIST_T *i)
 #else
     io_close_tty_line ();
     WRITE (A68_STDERR, "IEEE required - exiting graciously");
-    a68_exit (EXIT_SUCCESS);
+    a68g_exit (EXIT_SUCCESS);
 #endif
   }
   if (eq (q, "linux")) {
@@ -483,7 +483,7 @@ BOOL_T need_library (OPTION_LIST_T *i)
 #else
     io_close_tty_line ();
     WRITE (A68_STDERR, "linux required - exiting graciously");
-    a68_exit (EXIT_SUCCESS);
+    a68g_exit (EXIT_SUCCESS);
 #endif
   }
   if (eq (q, "mathlib")) {
@@ -492,7 +492,7 @@ BOOL_T need_library (OPTION_LIST_T *i)
 #else
     io_close_tty_line ();
     WRITE (A68_STDERR, "R mathlib required - exiting graciously");
-    a68_exit (EXIT_SUCCESS);
+    a68g_exit (EXIT_SUCCESS);
 #endif
   }
   if (eq (q, "mpfr")) {
@@ -501,7 +501,7 @@ BOOL_T need_library (OPTION_LIST_T *i)
 #else
     io_close_tty_line ();
     WRITE (A68_STDERR, "GNU MPFR required - exiting graciously");
-    a68_exit (EXIT_SUCCESS);
+    a68g_exit (EXIT_SUCCESS);
 #endif
   }
   if (eq (q, "plotutils")) {
@@ -510,7 +510,7 @@ BOOL_T need_library (OPTION_LIST_T *i)
 #else
     io_close_tty_line ();
     WRITE (A68_STDERR, "GNU plotutils required - exiting graciously");
-    a68_exit (EXIT_SUCCESS);
+    a68g_exit (EXIT_SUCCESS);
 #endif
   }
   if (eq (q, "postgresql")) {
@@ -519,7 +519,7 @@ BOOL_T need_library (OPTION_LIST_T *i)
 #else
     io_close_tty_line ();
     WRITE (A68_STDERR, "postgresql required - exiting graciously");
-    a68_exit (EXIT_SUCCESS);
+    a68g_exit (EXIT_SUCCESS);
 #endif
   }
   if (eq (q, "threads")) {
@@ -528,7 +528,7 @@ BOOL_T need_library (OPTION_LIST_T *i)
 #else
     io_close_tty_line ();
     WRITE (A68_STDERR, "POSIX threads required - exiting graciously");
-    a68_exit (EXIT_SUCCESS);
+    a68g_exit (EXIT_SUCCESS);
 #endif
   }
   return A68_FALSE;
@@ -647,7 +647,7 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
             FORWARD (i);
           }
           if (i != NO_OPTION_LIST) {
-            ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "%s verification \"%s\" does not match script verification \"%s\"", A68 (a68_cmd_name), PACKAGE_STRING, STR (i)) >= 0);
+            ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "%s verification \"%s\" does not match script verification \"%s\"", A68 (a68g_cmd_name), PACKAGE_STRING, STR (i)) >= 0);
             ABEND (strcmp (PACKAGE_STRING, STR (i)) != 0, new_string (A68 (output_line), __func__), "outdated script");
           } else {
             option_error (start_l, start_c, "missing argument in");
@@ -664,7 +664,7 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
           } else {
             apropos (A68_STDOUT, NO_TEXT, "options");
           }
-          a68_exit (EXIT_SUCCESS);
+          a68g_exit (EXIT_SUCCESS);
         }
 // ECHO is treated later.
         else if (eq (p, "ECHO")) {
@@ -689,9 +689,9 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
             if (!error) {
               BUFFER name, new_name;
               int s_errno = errno;
-              a68_bufcpy (name, HIDDEN_TEMP_FILE_NAME, BUFFER_SIZE);
-              a68_bufcat (name, ".a68", BUFFER_SIZE);
-              FILE *f = a68_fopen (name, "w", new_name);
+              a68g_bufcpy (name, HIDDEN_TEMP_FILE_NAME, BUFFER_SIZE);
+              a68g_bufcat (name, ".a68", BUFFER_SIZE);
+              FILE *f = a68g_fopen (name, "w", new_name);
               ABEND (f == NO_FILE, ERROR_ACTION, __func__);
               errno = s_errno;
               if (eq (p, "Execute") || eq (p, "X")) {
@@ -966,6 +966,8 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
         else if (eq (p, "Version")) {
           OPTION_VERSION (&A68_JOB) = A68_TRUE;
         } else if (eq (p, "MODular-arithmetic")) {
+// MODULAR-ARITHMETIC makes A68G permissive towards BITS values corresponding
+// to negative INT values. RR forbids these BITS values.
           OPTION_NODEMASK (&A68_JOB) |= MODULAR_MASK;
         } else if (eq (p, "NOMODular-arithmetic")) {
           OPTION_NODEMASK (&A68_JOB) &= ~MODULAR_MASK;
@@ -1117,7 +1119,7 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
 // Unrecognised.
           option_error (start_l, start_c, "unrecognised");
         }
-        a68_free (stale);
+        a68g_free (stale);
       }
 // Go processing next item, if present.
       if (i != NO_OPTION_LIST) {
