@@ -33,29 +33,29 @@
 
 //! @brief Safely get dir name from path.
 
-char *a68_dirname (char *src)
+char *a68g_dirname (char *src)
 {
   int len = (int) strlen (src) + 1;
   char *cpy = (char *) get_fixed_heap_space (len + 1);
   char *dst = (char *) get_fixed_heap_space (len + 1);
   ABEND (cpy == NO_TEXT, ERROR_OUT_OF_CORE, __func__);
   ABEND (dst == NO_TEXT, ERROR_OUT_OF_CORE, __func__);
-  a68_bufcpy (cpy, src, len);
-  a68_bufcpy (dst, dirname (cpy), len);
+  a68g_bufcpy (cpy, src, len);
+  a68g_bufcpy (dst, dirname (cpy), len);
   return dst;
 }
 
 //! @brief Safely get basename from path.
 
-char *a68_basename (char *src)
+char *a68g_basename (char *src)
 {
   int len = (int) strlen (src) + 1;
   char *cpy = (char *) get_fixed_heap_space (len + 1);
   char *dst = (char *) get_fixed_heap_space (len + 1);
   ABEND (cpy == NO_TEXT, ERROR_OUT_OF_CORE, __func__);
   ABEND (dst == NO_TEXT, ERROR_OUT_OF_CORE, __func__);
-  a68_bufcpy (cpy, src, len);
-  a68_bufcpy (dst, basename (cpy), len);
+  a68g_bufcpy (cpy, src, len);
+  a68g_bufcpy (dst, basename (cpy), len);
   return dst;
 }
 
@@ -107,7 +107,7 @@ static char *win32_realpath (char *name, char *resolved)
 
 #endif
 
-char *a68_relpath (char *p1, char *p2, char *fn)
+char *a68g_relpath (char *p1, char *p2, char *fn)
 {
   char q[PATH_MAX + 1];
   ASSERT (p1 != NO_TEXT);
@@ -115,30 +115,30 @@ char *a68_relpath (char *p1, char *p2, char *fn)
   ASSERT (fn != NO_TEXT);
 #if defined (BUILD_WIN32)
   if (p2[0] == '\\') {
-    a68_bufcpy (q, p2, PATH_MAX);
+    a68g_bufcpy (q, p2, PATH_MAX);
   } else {
-    a68_bufcpy (q, p1, PATH_MAX);
-    a68_bufcat (q, "\\", PATH_MAX);
-    a68_bufcat (q, p2, PATH_MAX);
+    a68g_bufcpy (q, p1, PATH_MAX);
+    a68g_bufcat (q, "\\", PATH_MAX);
+    a68g_bufcat (q, p2, PATH_MAX);
   }
-  a68_bufcat (q, "\\", PATH_MAX);
-  a68_bufcat (q, fn, PATH_MAX);
+  a68g_bufcat (q, "\\", PATH_MAX);
+  a68g_bufcat (q, fn, PATH_MAX);
 #else
   if (p2[0] == '/') {
 // Absolute path starting at root.
-    a68_bufcpy (q, p2, PATH_MAX);
+    a68g_bufcpy (q, p2, PATH_MAX);
   } else if (p2[0] == '~') {
 // "~" is a shell extension, not Unix.
 // We handle it anyway, as a courtesy.
-    a68_bufcpy (q, getenv("HOME"), PATH_MAX);
-    a68_bufcat (q, &p2[1], PATH_MAX);
+    a68g_bufcpy (q, getenv("HOME"), PATH_MAX);
+    a68g_bufcat (q, &p2[1], PATH_MAX);
   } else {
-    a68_bufcpy (q, p1, PATH_MAX);
-    a68_bufcat (q, "/", PATH_MAX);
-    a68_bufcat (q, p2, PATH_MAX);
+    a68g_bufcpy (q, p1, PATH_MAX);
+    a68g_bufcat (q, "/", PATH_MAX);
+    a68g_bufcat (q, p2, PATH_MAX);
   }
-  a68_bufcat (q, "/", PATH_MAX);
-  a68_bufcat (q, fn, PATH_MAX);
+  a68g_bufcat (q, "/", PATH_MAX);
+  a68g_bufcat (q, fn, PATH_MAX);
 #endif
 // Error handling in the caller!
   errno = 0;
@@ -151,7 +151,7 @@ char *a68_relpath (char *p1, char *p2, char *fn)
     size_t len = strlen (r) + 1;
     char *rc = (char *) get_fixed_heap_space (len);
     ABEND (rc == NO_TEXT, ERROR_OUT_OF_CORE, __func__);
-    a68_bufcpy (rc, r, len);
+    a68g_bufcpy (rc, r, len);
     free (r);
     return rc;
   } else {
