@@ -91,11 +91,12 @@
 
 GLOBALS_T common;
 
-#define EXTENSIONS 11
+#define EXTENSIONS 13
 static char *extensions[EXTENSIONS] = {
   NO_TEXT,
   ".a68", ".A68",
   ".a68g", ".A68G",
+  ".alg", ".ALG",
   ".algol", ".ALGOL",
   ".algol68", ".ALGOL68",
   ".algol68g", ".ALGOL68G"
@@ -119,25 +120,25 @@ void verbosity (void)
 void state_license (FILE_T f)
 {
 #define PR(s)\
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "%s\n", (s)) >= 0);\
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "%s\n", (s)) >= 0);\
   WRITE (f, A68 (output_line));
   if (f == A68_STDOUT) {
     io_close_tty_line ();
   }
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "Algol 68 Genie %s\n", PACKAGE_VERSION) >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "Algol 68 Genie %s\n", PACKAGE_VERSION) >= 0);
   WRITE (f, A68 (output_line));
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "Copyright 2001-2025 %s.\n", PACKAGE_BUGREPORT) >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "Copyright 2001-2025 %s.\n", PACKAGE_BUGREPORT) >= 0);
   WRITE (f, A68 (output_line));
   PR ("");
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "This is free software covered by the GNU General Public License.\n") >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "This is free software covered by the GNU General Public License.\n") >= 0);
   WRITE (f, A68 (output_line));
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "There is ABSOLUTELY NO WARRANTY for Algol 68 Genie;\n") >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "There is ABSOLUTELY NO WARRANTY for Algol 68 Genie;\n") >= 0);
   WRITE (f, A68 (output_line));
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n") >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n") >= 0);
   WRITE (f, A68 (output_line));
   PR ("See the GNU General Public License for more details.");
   PR ("");
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "Please report bugs to %s.\n", PACKAGE_BUGREPORT) >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "Please report bugs to %s.\n", PACKAGE_BUGREPORT) >= 0);
   WRITE (f, A68 (output_line));
 #undef PR
 }
@@ -147,7 +148,7 @@ void state_license (FILE_T f)
 void state_version (FILE_T f)
 {
 #define PR(s)\
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "%s\n", (s)) >= 0);\
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "%s\n", (s)) >= 0);\
   WRITE (f, A68 (output_line));
   if (f == A68_STDOUT) {
     io_close_tty_line ();
@@ -155,74 +156,74 @@ void state_version (FILE_T f)
   state_license (f);
   PR ("");
 #if defined (BUILD_WIN32)
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "WIN32 executable\n") >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "WIN32 executable\n") >= 0);
   WRITE (f, A68 (output_line));
   WRITELN (f, "");
 #endif
 #if (A68_LEVEL >= 3)
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "With hardware support for long modes\n") >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "With hardware support for long modes\n") >= 0);
   WRITE (f, A68 (output_line));
 #endif
 #if defined (BUILD_A68_COMPILER)
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "With plugin-compilation support\n") >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "With plugin-compilation support\n") >= 0);
   WRITE (f, A68 (output_line));
 #endif
 #if defined (BUILD_PARALLEL_CLAUSE)
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "With parallel-clause support\n") >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "With parallel-clause support\n") >= 0);
   WRITE (f, A68 (output_line));
 #endif
 #if defined (HAVE_POSTGRESQL)
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "With PostgreSQL support\n") >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "With PostgreSQL support\n") >= 0);
   WRITE (f, A68 (output_line));
 #endif
 #if defined (HAVE_CURL)
   curl_version_info_data *data = curl_version_info(CURLVERSION_NOW);
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "With curl %s\n", data->version) >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "With curl %s\n", data->version) >= 0);
   WRITE (f, A68 (output_line));
 #endif
 #if defined (HAVE_GNU_MPFR)
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "With GNU MP %s\n", gmp_version) >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "With GNU MP %s\n", gmp_version) >= 0);
   WRITE (f, A68 (output_line));
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "With GNU MPFR %s\n", mpfr_get_version ()) >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "With GNU MPFR %s\n", mpfr_get_version ()) >= 0);
   WRITE (f, A68 (output_line));
 #endif
 #if defined (HAVE_MATHLIB)
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "With mathlib from R %s\n", R_VERSION_STRING) >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "With mathlib from R %s\n", R_VERSION_STRING) >= 0);
   WRITE (f, A68 (output_line));
 #endif
 #if defined (HAVE_GSL)
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "With GNU Scientific Library %s\n", GSL_VERSION) >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "With GNU Scientific Library %s\n", GSL_VERSION) >= 0);
   WRITE (f, A68 (output_line));
 #endif
 #if defined (HAVE_GNU_PLOTUTILS)
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "With GNU plotutils %s\n", PL_LIBPLOT_VER_STRING) >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "With GNU plotutils %s\n", PL_LIBPLOT_VER_STRING) >= 0);
   WRITE (f, A68 (output_line));
 #endif
 #if defined (HAVE_CURSES)
   #if defined (NCURSES_VERSION)
-    ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "With ncurses %s\n", NCURSES_VERSION) >= 0);
+    ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "With ncurses %s\n", NCURSES_VERSION) >= 0);
   #else
-    ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "With curses support\n") >= 0);
+    ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "With curses support\n") >= 0);
   #endif
   WRITE (f, A68 (output_line));
 #endif
 #if defined (_CS_GNU_LIBC_VERSION) && defined (BUILD_UNIX)
   if (confstr (_CS_GNU_LIBC_VERSION, A68 (input_line), BUFFER_SIZE) > (size_t) 0) {
-    ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "GNU libc version %s\n", A68 (input_line)) >= 0);
+    ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "GNU libc version %s\n", A68 (input_line)) >= 0);
     WRITE (f, A68 (output_line));
   }
 #if (defined (BUILD_PARALLEL_CLAUSE) && defined (_CS_GNU_LIBPTHREAD_VERSION))
   if (confstr (_CS_GNU_LIBPTHREAD_VERSION, A68 (input_line), BUFFER_SIZE) > (size_t) 0) {
-    ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "GNU libpthread version %s\n", A68 (input_line)) >= 0);
+    ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "GNU libpthread version %s\n", A68 (input_line)) >= 0);
     WRITE (f, A68 (output_line));
   }
 #endif
 #endif
 #define RSIZE(n) (unt) (sizeof (n) / sizeof (int))
 #if defined (BUILD_A68_COMPILER) && defined (C_COMPILER)
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "Build level %d.%x%x%x%x %s %s\n", A68_LEVEL, RSIZE (INT_T), RSIZE (REAL_T), RSIZE (MP_INT_T), RSIZE (MP_REAL_T), C_COMPILER, __DATE__) >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "Build level %d.%x%x%x%x %s %s\n", A68_LEVEL, RSIZE (INT_T), RSIZE (REAL_T), RSIZE (MP_INT_T), RSIZE (MP_REAL_T), C_COMPILER, __DATE__) >= 0);
 #else
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "Build level %d.%x%x%x%x %s\n", A68_LEVEL, RSIZE (INT_T), RSIZE (REAL_T), RSIZE (MP_INT_T), RSIZE (MP_REAL_T), __DATE__) >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "Build level %d.%x%x%x%x %s\n", A68_LEVEL, RSIZE (INT_T), RSIZE (REAL_T), RSIZE (MP_INT_T), RSIZE (MP_REAL_T), __DATE__) >= 0);
 #endif
 #undef RSIZE
 WRITE (f, A68 (output_line));
@@ -237,9 +238,9 @@ void online_help (FILE_T f)
     io_close_tty_line ();
   }
   state_license (f);
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "Usage: %s [options | filename]", A68 (a68_cmd_name)) >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "Usage: %s [options | filename]", A68 (a68g_cmd_name)) >= 0);
   WRITELN (f, A68 (output_line));
-  ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "For help: %s --apropos [keyword]", A68 (a68_cmd_name)) >= 0);
+  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "For help: %s --apropos [keyword]", A68 (a68g_cmd_name)) >= 0);
   WRITELN (f, A68 (output_line));
 }
 
@@ -248,7 +249,7 @@ void online_help (FILE_T f)
 void announce_phase (char *t)
 {
   if (OPTION_VERBOSE (&A68_JOB)) {
-    ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "%s: %s", A68 (a68_cmd_name), t) >= 0);
+    ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "%s: %s", A68 (a68g_cmd_name), t) >= 0);
     io_close_tty_line ();
     WRITE (A68_STDOUT, A68 (output_line));
   }
@@ -264,11 +265,11 @@ BOOL_T strip_extension (char *ext)
   int nlen = (int) strlen (FILE_SOURCE_NAME (&A68_JOB)), xlen = (int) strlen (ext);
   if (nlen > xlen && strcmp (&(FILE_SOURCE_NAME (&A68_JOB)[nlen - xlen]), ext) == 0) {
     char *fn = (char *) get_heap_space ((size_t) (nlen + 1));
-    a68_bufcpy (fn, FILE_SOURCE_NAME (&A68_JOB), nlen);
+    a68g_bufcpy (fn, FILE_SOURCE_NAME (&A68_JOB), nlen);
     fn[nlen - xlen] = NULL_CHAR;
-    a68_free (FILE_GENERIC_NAME (&A68_JOB));
+    a68g_free (FILE_GENERIC_NAME (&A68_JOB));
     FILE_GENERIC_NAME (&A68_JOB) = new_string (fn, NO_TEXT);
-    a68_free (fn);
+    a68g_free (fn);
     return A68_TRUE;
   } else {
     return A68_FALSE;
@@ -286,34 +287,34 @@ void open_with_extensions (void)
     if (extensions[k] == NO_TEXT) {
       len = (int) strlen (FILE_INITIAL_NAME (&A68_JOB)) + 1;
       fn = (char *) get_heap_space ((size_t) len);
-      a68_bufcpy (fn, FILE_INITIAL_NAME (&A68_JOB), len);
+      a68g_bufcpy (fn, FILE_INITIAL_NAME (&A68_JOB), len);
     } else {
       len = (int) strlen (FILE_INITIAL_NAME (&A68_JOB)) + (int) strlen (extensions[k]) + 1;
       fn = (char *) get_heap_space ((size_t) len);
-      a68_bufcpy (fn, FILE_INITIAL_NAME (&A68_JOB), len);
-      a68_bufcat (fn, extensions[k], len);
+      a68g_bufcpy (fn, FILE_INITIAL_NAME (&A68_JOB), len);
+      a68g_bufcat (fn, extensions[k], len);
     }
     FILE_SOURCE_FD (&A68_JOB) = open (fn, O_RDONLY | O_BINARY);
     if (FILE_SOURCE_FD (&A68_JOB) != -1) {
       BOOL_T cont = A68_TRUE;
-      a68_free (FILE_SOURCE_NAME (&A68_JOB));
-      a68_free (FILE_GENERIC_NAME (&A68_JOB));
+      a68g_free (FILE_SOURCE_NAME (&A68_JOB));
+      a68g_free (FILE_GENERIC_NAME (&A68_JOB));
       FILE_SOURCE_NAME (&A68_JOB) = new_string (fn, NO_TEXT);
-      FILE_GENERIC_NAME (&A68_JOB) = new_string (a68_basename (fn), NO_TEXT);
-      FILE_PATH (&A68_JOB) = new_string (a68_dirname (fn), NO_TEXT);
+      FILE_GENERIC_NAME (&A68_JOB) = new_string (a68g_basename (fn), NO_TEXT);
+      FILE_PATH (&A68_JOB) = new_string (a68g_dirname (fn), NO_TEXT);
       for (int l = 0; l < EXTENSIONS && cont; l++) {
         if (strip_extension (extensions[l])) {
           cont = A68_FALSE;
         }
       }
     }
-    a68_free (fn);
+    a68g_free (fn);
   }
 }
 
 //! @brief Remove a regular file.
 
-void a68_rm (char *fn)
+void a68g_rm (char *fn)
 {
   struct stat path_stat;
   if (stat (fn, &path_stat) == 0) {
@@ -338,7 +339,7 @@ void compiler_interpreter (void)
   A68 (new_genie_infos) = 0;
   A68 (symbol_table_count) = 0;
   A68 (mode_count) = 0;
-  A68 (node_register) = NO_VAR;
+  A68 (node_register) = NO_REF;
   init_postulates ();
   A68 (do_confirm_exit) = A68_TRUE;
   A68 (f_entry) = NO_NODE;
@@ -400,35 +401,35 @@ void compiler_interpreter (void)
 // Object file.
   int len = 1 + (int) strlen (FILE_GENERIC_NAME (&A68_JOB)) + (int) strlen (OBJECT_EXTENSION);
   FILE_OBJECT_NAME (&A68_JOB) = (char *) get_heap_space ((size_t) len);
-  a68_bufcpy (FILE_OBJECT_NAME (&A68_JOB), FILE_GENERIC_NAME (&A68_JOB), len);
-  a68_bufcat (FILE_OBJECT_NAME (&A68_JOB), OBJECT_EXTENSION, len);
+  a68g_bufcpy (FILE_OBJECT_NAME (&A68_JOB), FILE_GENERIC_NAME (&A68_JOB), len);
+  a68g_bufcat (FILE_OBJECT_NAME (&A68_JOB), OBJECT_EXTENSION, len);
 // Binary.
   len = 1 + (int) strlen (FILE_GENERIC_NAME (&A68_JOB)) + (int) strlen (PLUGIN_EXTENSION);
   FILE_BINARY_NAME (&A68_JOB) = (char *) get_heap_space ((size_t) len);
-  a68_bufcpy (FILE_BINARY_NAME (&A68_JOB), FILE_GENERIC_NAME (&A68_JOB), len);
-  a68_bufcat (FILE_BINARY_NAME (&A68_JOB), BINARY_EXTENSION, len);
+  a68g_bufcpy (FILE_BINARY_NAME (&A68_JOB), FILE_GENERIC_NAME (&A68_JOB), len);
+  a68g_bufcat (FILE_BINARY_NAME (&A68_JOB), BINARY_EXTENSION, len);
 // Library file.
   len = 1 + (int) strlen (FILE_GENERIC_NAME (&A68_JOB)) + (int) strlen (PLUGIN_EXTENSION);
   FILE_PLUGIN_NAME (&A68_JOB) = (char *) get_heap_space ((size_t) len);
-  a68_bufcpy (FILE_PLUGIN_NAME (&A68_JOB), FILE_GENERIC_NAME (&A68_JOB), len);
-  a68_bufcat (FILE_PLUGIN_NAME (&A68_JOB), PLUGIN_EXTENSION, len);
+  a68g_bufcpy (FILE_PLUGIN_NAME (&A68_JOB), FILE_GENERIC_NAME (&A68_JOB), len);
+  a68g_bufcat (FILE_PLUGIN_NAME (&A68_JOB), PLUGIN_EXTENSION, len);
 // Listing file.
   len = 1 + (int) strlen (FILE_GENERIC_NAME (&A68_JOB)) + (int) strlen (LISTING_EXTENSION);
   FILE_LISTING_NAME (&A68_JOB) = (char *) get_heap_space ((size_t) len);
-  a68_bufcpy (FILE_LISTING_NAME (&A68_JOB), FILE_GENERIC_NAME (&A68_JOB), len);
-  a68_bufcat (FILE_LISTING_NAME (&A68_JOB), LISTING_EXTENSION, len);
+  a68g_bufcpy (FILE_LISTING_NAME (&A68_JOB), FILE_GENERIC_NAME (&A68_JOB), len);
+  a68g_bufcat (FILE_LISTING_NAME (&A68_JOB), LISTING_EXTENSION, len);
 // Pretty file.
   len = 1 + (int) strlen (FILE_GENERIC_NAME (&A68_JOB)) + (int) strlen (PRETTY_EXTENSION);
   FILE_PRETTY_NAME (&A68_JOB) = (char *) get_heap_space ((size_t) len);
-  a68_bufcpy (FILE_PRETTY_NAME (&A68_JOB), FILE_GENERIC_NAME (&A68_JOB), len);
-  a68_bufcat (FILE_PRETTY_NAME (&A68_JOB), PRETTY_EXTENSION, len);
+  a68g_bufcpy (FILE_PRETTY_NAME (&A68_JOB), FILE_GENERIC_NAME (&A68_JOB), len);
+  a68g_bufcat (FILE_PRETTY_NAME (&A68_JOB), PRETTY_EXTENSION, len);
 // Script file.
   len = 1 + (int) strlen (FILE_GENERIC_NAME (&A68_JOB)) + (int) strlen (SCRIPT_EXTENSION);
   FILE_SCRIPT_NAME (&A68_JOB) = (char *) get_heap_space ((size_t) len);
-  a68_bufcpy (FILE_SCRIPT_NAME (&A68_JOB), FILE_GENERIC_NAME (&A68_JOB), len);
-  a68_bufcat (FILE_SCRIPT_NAME (&A68_JOB), SCRIPT_EXTENSION, len);
+  a68g_bufcpy (FILE_SCRIPT_NAME (&A68_JOB), FILE_GENERIC_NAME (&A68_JOB), len);
+  a68g_bufcat (FILE_SCRIPT_NAME (&A68_JOB), SCRIPT_EXTENSION, len);
 // Parser.
-  a68_parser ();
+  a68g_parser ();
   if (TOP_NODE (&A68_JOB) == NO_NODE) {
     errno = ECANCELED;
     ABEND (A68_TRUE, ERROR_SOURCE_FILE_EMPTY, NO_TEXT);
@@ -495,7 +496,7 @@ void compiler_interpreter (void)
 // Normal end of program.
     diagnostics_to_terminal (TOP_LINE (&A68_JOB), A68_RUNTIME_ERROR);
     if (OPTION_DEBUG (&A68_JOB) || OPTION_TRACE (&A68_JOB) || OPTION_CLOCK (&A68_JOB)) {
-      ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "\nGenie finished in %.2f seconds\n", seconds () - A68 (cputime_0)) >= 0);
+      ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "\nGenie finished in %.2f seconds\n", seconds () - A68 (cputime_0)) >= 0);
       WRITE (A68_STDOUT, A68 (output_line));
     }
     verbosity ();
@@ -534,7 +535,7 @@ void compiler_interpreter (void)
 
 //! @brief Exit a68g in an orderly manner.
 
-void a68_exit (int code)
+void a68g_exit (int code)
 {
   announce_phase ("exit");
 #if defined (HAVE_GNU_MPFR)
@@ -557,29 +558,29 @@ void a68_exit (int code)
 // Clean up stale things.
   free_syntax_tree (TOP_NODE (&A68_JOB));
   free_option_list (OPTION_LIST (&A68_JOB));
-  a68_free (A68 (node_register));
-  a68_free (A68 (options));
+  a68g_free (A68 (node_register));
+  a68g_free (A68 (options));
   discard_heap ();
-  a68_free (FILE_PATH (&A68_JOB));
-  a68_free (FILE_INITIAL_NAME (&A68_JOB));
-  a68_free (FILE_GENERIC_NAME (&A68_JOB));
-  a68_free (FILE_SOURCE_NAME (&A68_JOB));
-  a68_free (FILE_LISTING_NAME (&A68_JOB));
-  a68_free (FILE_OBJECT_NAME (&A68_JOB));
-  a68_free (FILE_PLUGIN_NAME (&A68_JOB));
-  a68_free (FILE_BINARY_NAME (&A68_JOB));
-  a68_free (FILE_PRETTY_NAME (&A68_JOB));
-  a68_free (FILE_SCRIPT_NAME (&A68_JOB));
-  a68_free (FILE_DIAGS_NAME (&A68_JOB));
-  a68_free (A68_MP (mp_one));
-  a68_free (A68_MP (mp_pi));
-  a68_free (A68_MP (mp_half_pi));
-  a68_free (A68_MP (mp_two_pi));
-  a68_free (A68_MP (mp_sqrt_two_pi));
-  a68_free (A68_MP (mp_sqrt_pi));
-  a68_free (A68_MP (mp_ln_pi));
-  a68_free (A68_MP (mp_180_over_pi));
-  a68_free (A68_MP (mp_pi_over_180));
+  a68g_free (FILE_PATH (&A68_JOB));
+  a68g_free (FILE_INITIAL_NAME (&A68_JOB));
+  a68g_free (FILE_GENERIC_NAME (&A68_JOB));
+  a68g_free (FILE_SOURCE_NAME (&A68_JOB));
+  a68g_free (FILE_LISTING_NAME (&A68_JOB));
+  a68g_free (FILE_OBJECT_NAME (&A68_JOB));
+  a68g_free (FILE_PLUGIN_NAME (&A68_JOB));
+  a68g_free (FILE_BINARY_NAME (&A68_JOB));
+  a68g_free (FILE_PRETTY_NAME (&A68_JOB));
+  a68g_free (FILE_SCRIPT_NAME (&A68_JOB));
+  a68g_free (FILE_DIAGS_NAME (&A68_JOB));
+  a68g_free (A68_MP (mp_one));
+  a68g_free (A68_MP (mp_pi));
+  a68g_free (A68_MP (mp_half_pi));
+  a68g_free (A68_MP (mp_two_pi));
+  a68g_free (A68_MP (mp_sqrt_two_pi));
+  a68g_free (A68_MP (mp_sqrt_pi));
+  a68g_free (A68_MP (mp_ln_pi));
+  a68g_free (A68_MP (mp_180_over_pi));
+  a68g_free (A68_MP (mp_pi_over_180));
   exit (code);
 }
 
@@ -593,21 +594,21 @@ int main (int argc, char *argv[])
   A68 (close_tty_on_exit) = A68_TRUE;
   FILE_DIAGS_FD (&A68_JOB) = -1;
 // Get command name and discard path.
-  a68_bufcpy (A68 (a68_cmd_name), argv[0], BUFFER_SIZE);
-  for (int k = (int) strlen (A68 (a68_cmd_name)) - 1; k >= 0; k--) {
+  a68g_bufcpy (A68 (a68g_cmd_name), argv[0], BUFFER_SIZE);
+  for (int k = (int) strlen (A68 (a68g_cmd_name)) - 1; k >= 0; k--) {
 #if defined (BUILD_WIN32)
     char delim = '\\';
 #else
     char delim = '/';
 #endif
-    if (A68 (a68_cmd_name)[k] == delim) {
-      MOVE (&A68 (a68_cmd_name)[0], &A68 (a68_cmd_name)[k + 1], (int) strlen (A68 (a68_cmd_name)) - k + 1);
+    if (A68 (a68g_cmd_name)[k] == delim) {
+      MOVE (&A68 (a68g_cmd_name)[0], &A68 (a68g_cmd_name)[k + 1], (int) strlen (A68 (a68g_cmd_name)) - k + 1);
       k = -1;
     }
   }
 // Try to read maximum line width on the terminal,
 // used to pretty print diagnostics to same.
-  a68_getty (&A68 (term_heigth), &A68 (term_width));
+  a68g_getty (&A68 (term_heigth), &A68 (term_width));
 // Determine clock resolution.
   {
     clock_t t0 = clock (), t1;
@@ -653,13 +654,13 @@ int main (int argc, char *argv[])
 // Posix copies arguments from the command line.
     if (argc <= 1) {
       online_help (A68_STDOUT);
-      a68_exit (EXIT_FAILURE);
+      a68g_exit (EXIT_FAILURE);
     }
     for (int k = 1; k < argc; k++) {
       add_option_list (&(OPTION_LIST (&A68_JOB)), argv[k], NO_LINE);
     }
     if (!set_options (OPTION_LIST (&A68_JOB), A68_TRUE)) {
-      a68_exit (EXIT_FAILURE);
+      a68g_exit (EXIT_FAILURE);
     }
 // State license.
     if (OPTION_LICENSE (&A68_JOB)) {
@@ -683,11 +684,11 @@ int main (int argc, char *argv[])
     } else {
       compiler_interpreter ();
     }
-    a68_exit (ERROR_COUNT (&A68_JOB) == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
+    a68g_exit (ERROR_COUNT (&A68_JOB) == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
     return EXIT_SUCCESS;
   } else {
     diagnostics_to_terminal (TOP_LINE (&A68_JOB), A68_ALL_DIAGNOSTICS);
-    a68_exit (EXIT_FAILURE);
+    a68g_exit (EXIT_FAILURE);
     return EXIT_FAILURE;
   }
 }
