@@ -36,24 +36,24 @@
 
 // Infinity.
 
-DOUBLE_T a68_div_double (DOUBLE_T x, DOUBLE_T y)
+DOUBLE_T a68g_div_double (DOUBLE_T x, DOUBLE_T y)
 {
   return x / y;
 }
 
-DOUBLE_T a68_posinf_double (void)
+DOUBLE_T a68g_posinf_double (void)
 {
-  return a68_div_double (+1.0, 0.0);
+  return a68g_div_double (+1.0, 0.0);
 }
 
-DOUBLE_T a68_neginf_double (void)
+DOUBLE_T a68g_neginf_double (void)
 {
-  return a68_div_double (-1.0, 0.0);
+  return a68g_div_double (-1.0, 0.0);
 }
 
 //! @brief PROC (LONG REAL, LONG REAL) LONG REAL long hypot
 
-DOUBLE_T a68_hypot_double (DOUBLE_T x, DOUBLE_T y)
+DOUBLE_T a68g_hypot_double (DOUBLE_T x, DOUBLE_T y)
 {
 // Sqrt (x^2 + y^2) that does not needlessly overflow.
   DOUBLE_T xabs = ABSQ (x), yabs = ABSQ (y), min, max;
@@ -74,7 +74,7 @@ DOUBLE_T a68_hypot_double (DOUBLE_T x, DOUBLE_T y)
 
 //! @brief PROC (LONG REAL, LONG REAL, LONG REAL) LONG REAL long beta inc
 
-DOUBLE_T a68_beta_inc_double (DOUBLE_T s, DOUBLE_T t, DOUBLE_T x)
+DOUBLE_T a68g_beta_inc_double (DOUBLE_T s, DOUBLE_T t, DOUBLE_T x)
 {
 // Incomplete beta function I{x}(s, t) by continued fraction,
 // see dlmf.nist.gov/8.17; Lentz's algorithm.
@@ -86,7 +86,7 @@ DOUBLE_T a68_beta_inc_double (DOUBLE_T s, DOUBLE_T t, DOUBLE_T x)
 // Rapid convergence when x <= (s+1)/(s+t+2) or else recursion.
     if (x > (s + 1.0q) / (s + t + 2.0q)) {
 // B{x}(s, t) = 1 - B{1-x}(t, s)
-      return 1.0q - a68_beta_inc_double (s, t, 1.0q - x);
+      return 1.0q - a68g_beta_inc_double (s, t, 1.0q - x);
     }
 // Lentz's algorithm for continued fraction.
     DOUBLE_T W = 1.0q, F = 1.0q, c = 1.0q, d = 0.0q;
@@ -120,7 +120,7 @@ DOUBLE_T a68_beta_inc_double (DOUBLE_T s, DOUBLE_T t, DOUBLE_T x)
 
 //! @brief PROC (LONG REAL) LONG REAL long csc
 
-DOUBLE_T a68_csc_double (DOUBLE_T x)
+DOUBLE_T a68g_csc_double (DOUBLE_T x)
 {
   DOUBLE_T z = sin_double (x);
   A68_OVERFLOW (z == 0.0q);
@@ -129,7 +129,7 @@ DOUBLE_T a68_csc_double (DOUBLE_T x)
 
 //! @brief PROC (LONG REAL) LONG REAL long acsc
 
-DOUBLE_T a68_acsc_double (DOUBLE_T x)
+DOUBLE_T a68g_acsc_double (DOUBLE_T x)
 {
   A68_OVERFLOW (x == 0.0q);
   return asin_double (1.0q / x);
@@ -137,7 +137,7 @@ DOUBLE_T a68_acsc_double (DOUBLE_T x)
 
 //! @brief PROC (LONG REAL) LONG REAL long sec
 
-DOUBLE_T a68_sec_double (DOUBLE_T x)
+DOUBLE_T a68g_sec_double (DOUBLE_T x)
 {
   DOUBLE_T z = cos_double (x);
   A68_OVERFLOW (z == 0.0q);
@@ -146,7 +146,7 @@ DOUBLE_T a68_sec_double (DOUBLE_T x)
 
 //! @brief PROC (LONG REAL) LONG REAL long asec
 
-DOUBLE_T a68_asec_double (DOUBLE_T x)
+DOUBLE_T a68g_asec_double (DOUBLE_T x)
 {
   A68_OVERFLOW (x == 0.0q);
   return acos_double (1.0q / x);
@@ -154,7 +154,7 @@ DOUBLE_T a68_asec_double (DOUBLE_T x)
 
 //! @brief PROC (LONG REAL) LONG REAL long cot
 
-DOUBLE_T a68_cot_double (DOUBLE_T x)
+DOUBLE_T a68g_cot_double (DOUBLE_T x)
 {
   DOUBLE_T z = sin_double (x);
   A68_OVERFLOW (z == 0.0q);
@@ -163,7 +163,7 @@ DOUBLE_T a68_cot_double (DOUBLE_T x)
 
 //! @brief PROC (LONG REAL) LONG REAL long acot
 
-DOUBLE_T a68_acot_double (DOUBLE_T x)
+DOUBLE_T a68g_acot_double (DOUBLE_T x)
 {
   A68_OVERFLOW (x == 0.0q);
   return atan_double (1 / x);
@@ -171,7 +171,7 @@ DOUBLE_T a68_acot_double (DOUBLE_T x)
 
 //! brief PROC (LONG REAL) LONG REAL long cas
 
-DOUBLE_T a68_cas_double (DOUBLE_T x)
+DOUBLE_T a68g_cas_double (DOUBLE_T x)
 {
 // Hartley kernel, which Hartley named cas (cosine and sine).
   return cos_double (x) + sin_double (x);
@@ -179,99 +179,99 @@ DOUBLE_T a68_cas_double (DOUBLE_T x)
 
 //! brief PROC (LONG REAL) LONG REAL long sindg
 
-DOUBLE_T a68_sindg_double (DOUBLE_T x)
+DOUBLE_T a68g_sindg_double (DOUBLE_T x)
 {
   return sin_double (x * CONST_PI_OVER_180_Q);
 }
 
 //! brief PROC (LONG REAL) LONG REAL long cosdg
 
-DOUBLE_T a68_cosdg_double (DOUBLE_T x)
+DOUBLE_T a68g_cosdg_double (DOUBLE_T x)
 {
   return cos_double (x * CONST_PI_OVER_180_Q);
 }
 
 //! brief PROC (LONG REAL) LONG REAL long tandg
 
-DOUBLE_T a68_tandg_double (DOUBLE_T x)
+DOUBLE_T a68g_tandg_double (DOUBLE_T x)
 {
   return tan_double (x * CONST_PI_OVER_180_Q);
 }
 
 //! brief PROC (LONG REAL) LONG REAL long asindg
 
-DOUBLE_T a68_asindg_double (DOUBLE_T x)
+DOUBLE_T a68g_asindg_double (DOUBLE_T x)
 {
   return asin_double (x) * CONST_180_OVER_PI_Q;
 }
 
 //! brief PROC (LONG REAL) LONG REAL long acosdg
 
-DOUBLE_T a68_acosdg_double (DOUBLE_T x)
+DOUBLE_T a68g_acosdg_double (DOUBLE_T x)
 {
   return acos_double (x) * CONST_180_OVER_PI_Q;
 }
 
 //! brief PROC (LONG REAL) LONG REAL long atandg
 
-DOUBLE_T a68_atandg_double (DOUBLE_T x)
+DOUBLE_T a68g_atandg_double (DOUBLE_T x)
 {
   return atan_double (x) * CONST_180_OVER_PI_Q;
 }
 //! @brief PROC (LONG REAL) LONG REAL long cscdg
 
-DOUBLE_T a68_cscdg_double (DOUBLE_T x)
+DOUBLE_T a68g_cscdg_double (DOUBLE_T x)
 {
-  DOUBLE_T z = a68_sindg_double (x);
+  DOUBLE_T z = a68g_sindg_double (x);
   A68_OVERFLOW (z == 0.0q);
   return 1.0q / z;
 }
 
 //! @brief PROC (LONG REAL) LONG REAL long acscdg
 
-DOUBLE_T a68_acscdg_double (DOUBLE_T x)
+DOUBLE_T a68g_acscdg_double (DOUBLE_T x)
 {
   A68_OVERFLOW (x == 0.0q);
-  return a68_asindg_double (1.0q / x);
+  return a68g_asindg_double (1.0q / x);
 }
 
 //! @brief PROC (LONG REAL) LONG REAL long secdg
 
-DOUBLE_T a68_secdg_double (DOUBLE_T x)
+DOUBLE_T a68g_secdg_double (DOUBLE_T x)
 {
-  DOUBLE_T z = a68_cosdg_double (x);
+  DOUBLE_T z = a68g_cosdg_double (x);
   A68_OVERFLOW (z == 0.0q);
   return 1.0q / z;
 }
 
 //! @brief PROC (LONG REAL) LONG REAL long asecdg
 
-DOUBLE_T a68_asecdg_double (DOUBLE_T x)
+DOUBLE_T a68g_asecdg_double (DOUBLE_T x)
 {
   A68_OVERFLOW (x == 0.0q);
-  return a68_acosdg_double (1.0q / x);
+  return a68g_acosdg_double (1.0q / x);
 }
 
 // PROC (LONG REAL) LONG REAL long cotdg
 
-DOUBLE_T a68_cotdg_double (DOUBLE_T x)
+DOUBLE_T a68g_cotdg_double (DOUBLE_T x)
 {
-  DOUBLE_T z = a68_sindg_double (x);
+  DOUBLE_T z = a68g_sindg_double (x);
   A68_OVERFLOW (z == 0);
-  return a68_cosdg_double (x) / z;
+  return a68g_cosdg_double (x) / z;
 }
 
 // PROC (LONG REAL) LONG REAL long acotdg
 
-DOUBLE_T a68_acotdg_double (DOUBLE_T z)
+DOUBLE_T a68g_acotdg_double (DOUBLE_T z)
 {
   A68_OVERFLOW (z == 0);
-  return a68_atandg_double (1 / z);
+  return a68g_atandg_double (1 / z);
 }
 
 // @brief PROC (LONG REAL) LONG REAL long sinpi
 
-DOUBLE_T a68_sinpi_double (DOUBLE_T x)
+DOUBLE_T a68g_sinpi_double (DOUBLE_T x)
 {
   x = fmod_double (x, 2.0q);
   if (x <= -1.0q) {
@@ -294,7 +294,7 @@ DOUBLE_T a68_sinpi_double (DOUBLE_T x)
 
 // @brief PROC (LONG REAL) LONG REAL long cospi
 
-DOUBLE_T a68_cospi_double (DOUBLE_T x)
+DOUBLE_T a68g_cospi_double (DOUBLE_T x)
 {
   x = fmod_double (fabs_double (x), 2.0q);
 // x in [0, 2>.
@@ -311,7 +311,7 @@ DOUBLE_T a68_cospi_double (DOUBLE_T x)
 
 // @brief PROC (LONG REAL) LONG REAL long tanpi
 
-DOUBLE_T a68_tanpi_double (DOUBLE_T x)
+DOUBLE_T a68g_tanpi_double (DOUBLE_T x)
 {
   x = fmod_double (x, 1.0q);
   if (x <= -0.5q) {
@@ -328,13 +328,13 @@ DOUBLE_T a68_tanpi_double (DOUBLE_T x)
   } else if (x == 0.25q) {
     return 1.0q;
   } else {
-    return a68_sinpi_double (x) / a68_cospi_double (x);
+    return a68g_sinpi_double (x) / a68g_cospi_double (x);
   }
 }
 
 // @brief PROC (LONG REAL) LONG REAL long cotpi
 
-DOUBLE_T a68_cotpi_double (DOUBLE_T x)
+DOUBLE_T a68g_cotpi_double (DOUBLE_T x)
 {
   x = fmod_double (x, 1.0q);
   if (x <= -0.5q) {
@@ -351,7 +351,7 @@ DOUBLE_T a68_cotpi_double (DOUBLE_T x)
   } else if (x == 0.5q) {
     return 0.0q;
   } else {
-    return a68_cospi_double (x) / a68_sinpi_double (x);
+    return a68g_cospi_double (x) / a68g_sinpi_double (x);
   }
 }
 
