@@ -136,7 +136,7 @@ DOUBLE_NUM_T double_strtou (NODE_T * p, char *s)
 {
   errno = 0;
   char *radix = NO_TEXT;
-  int base = (int) a68_strtou (s, &radix, 10);
+  int base = (int) a68g_strtou (s, &radix, 10);
   if (base < 2 || base > 16) {
     diagnostic (A68_RUNTIME_ERROR, p, ERROR_INVALID_RADIX, base);
     exit_genie (p, A68_RUNTIME_ERROR);
@@ -419,7 +419,7 @@ DOUBLE_T inverf_double (DOUBLE_T z)
 // Newton-Raphson.
     DOUBLE_T f = sqrt_double (M_PIq) / 2, g, x = z;
     int its = 10;
-    x = dble (a68_inverf_real ((REAL_T) x)).f;
+    x = dble (a68g_inverf_real ((REAL_T) x)).f;
     do {
       g = x;
       x -= f * (erf_double (x) - z) / exp_double (-(x * x));
@@ -1441,7 +1441,7 @@ void genie_abs_double_compl (NODE_T * p)
 {
   A68_LONG_REAL re, im;
   POP_LONG_COMPLEX (p, &re, &im);
-  PUSH_VALUE (p, dble (a68_hypot_double (VALUE (&re).f, VALUE (&im).f)), A68_LONG_REAL);
+  PUSH_VALUE (p, dble (a68g_hypot_double (VALUE (&re).f, VALUE (&im).f)), A68_LONG_REAL);
 }
 
 //! @brief OP ARG = (LONG COMPLEX) LONG REAL
@@ -1661,29 +1661,29 @@ CD_FUNCTION (genie_erf_double, erf_double);
 CD_FUNCTION (genie_erfc_double, erfc_double);
 CD_FUNCTION (genie_lngamma_double, lgamma_double);
 CD_FUNCTION (genie_gamma_double, tgamma_double);
-CD_FUNCTION (genie_csc_double, a68_csc_double);
-CD_FUNCTION (genie_cscdg_double, a68_cscdg_double);
-CD_FUNCTION (genie_acsc_double, a68_acsc_double);
-CD_FUNCTION (genie_acscdg_double, a68_acscdg_double);
-CD_FUNCTION (genie_sec_double, a68_sec_double);
-CD_FUNCTION (genie_secdg_double, a68_secdg_double);
-CD_FUNCTION (genie_asec_double, a68_asec_double);
-CD_FUNCTION (genie_asecdg_double, a68_asecdg_double);
-CD_FUNCTION (genie_cot_double, a68_cot_double);
-CD_FUNCTION (genie_acot_double, a68_acot_double);
-CD_FUNCTION (genie_sindg_double, a68_sindg_double);
-CD_FUNCTION (genie_cas_double, a68_cas_double);
-CD_FUNCTION (genie_cosdg_double, a68_cosdg_double);
-CD_FUNCTION (genie_tandg_double, a68_tandg_double);
-CD_FUNCTION (genie_asindg_double, a68_asindg_double);
-CD_FUNCTION (genie_acosdg_double, a68_acosdg_double);
-CD_FUNCTION (genie_atandg_double, a68_atandg_double);
-CD_FUNCTION (genie_cotdg_double, a68_cotdg_double);
-CD_FUNCTION (genie_acotdg_double, a68_acotdg_double);
-CD_FUNCTION (genie_sinpi_double, a68_sinpi_double);
-CD_FUNCTION (genie_cospi_double, a68_cospi_double);
-CD_FUNCTION (genie_tanpi_double, a68_tanpi_double);
-CD_FUNCTION (genie_cotpi_double, a68_cotpi_double);
+CD_FUNCTION (genie_csc_double, a68g_csc_double);
+CD_FUNCTION (genie_cscdg_double, a68g_cscdg_double);
+CD_FUNCTION (genie_acsc_double, a68g_acsc_double);
+CD_FUNCTION (genie_acscdg_double, a68g_acscdg_double);
+CD_FUNCTION (genie_sec_double, a68g_sec_double);
+CD_FUNCTION (genie_secdg_double, a68g_secdg_double);
+CD_FUNCTION (genie_asec_double, a68g_asec_double);
+CD_FUNCTION (genie_asecdg_double, a68g_asecdg_double);
+CD_FUNCTION (genie_cot_double, a68g_cot_double);
+CD_FUNCTION (genie_acot_double, a68g_acot_double);
+CD_FUNCTION (genie_sindg_double, a68g_sindg_double);
+CD_FUNCTION (genie_cas_double, a68g_cas_double);
+CD_FUNCTION (genie_cosdg_double, a68g_cosdg_double);
+CD_FUNCTION (genie_tandg_double, a68g_tandg_double);
+CD_FUNCTION (genie_asindg_double, a68g_asindg_double);
+CD_FUNCTION (genie_acosdg_double, a68g_acosdg_double);
+CD_FUNCTION (genie_atandg_double, a68g_atandg_double);
+CD_FUNCTION (genie_cotdg_double, a68g_cotdg_double);
+CD_FUNCTION (genie_acotdg_double, a68g_acotdg_double);
+CD_FUNCTION (genie_sinpi_double, a68g_sinpi_double);
+CD_FUNCTION (genie_cospi_double, a68g_cospi_double);
+CD_FUNCTION (genie_tanpi_double, a68g_tanpi_double);
+CD_FUNCTION (genie_cotpi_double, a68g_cotpi_double);
 
 //! @brief PROC long arctan2 = (LONG REAL) LONG REAL
 
@@ -1694,7 +1694,7 @@ void genie_atan2_double (NODE_T * p)
   POP_OBJECT (p, &x, A68_LONG_REAL);
   errno = 0;
   PRELUDE_ERROR (VALUE (&x).f == 0.0q && VALUE (&y).f == 0.0q, p, ERROR_INVALID_ARGUMENT, M_LONG_REAL);
-  VALUE (&x).f = a68_atan2_real (VALUE (&y).f, VALUE (&x).f);
+  VALUE (&x).f = a68g_atan2_real (VALUE (&y).f, VALUE (&x).f);
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);
   PUSH_OBJECT (p, x, A68_LONG_REAL);
 }
@@ -1708,7 +1708,7 @@ void genie_atan2dg_double (NODE_T * p)
   POP_OBJECT (p, &x, A68_LONG_REAL);
   errno = 0;
   PRELUDE_ERROR (VALUE (&x).f == 0.0q && VALUE (&y).f == 0.0q, p, ERROR_INVALID_ARGUMENT, M_LONG_REAL);
-  VALUE (&x).f = CONST_180_OVER_PI_Q * a68_atan2_real (VALUE (&y).f, VALUE (&x).f);
+  VALUE (&x).f = CONST_180_OVER_PI_Q * a68g_atan2_real (VALUE (&y).f, VALUE (&x).f);
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);
   PUSH_OBJECT (p, x, A68_LONG_REAL);
 }
@@ -1884,7 +1884,7 @@ DOUBLE_T string_to_double (char *s, char **end)
   for (int i = 0; i < A68_DOUBLE_DIG; i++) {
     y[i] = 0.0q;
   }
-  if (end != NO_VAR) {
+  if (end != NO_REF) {
     (*end) = &(s[0]);
   }
   while (IS_SPACE (s[0])) {
@@ -1918,7 +1918,7 @@ DOUBLE_T string_to_double (char *s, char **end)
   while (IS_DIGIT (s[pos])) {
     pos++;
   }
-  if (end != NO_VAR) {
+  if (end != NO_REF) {
     (*end) = &(s[pos]);
   }
 // Sum from low to high to preserve precision.
@@ -1957,7 +1957,7 @@ void genie_beta_inc_cf_double (NODE_T * p)
   POP_OBJECT (p, &t, A68_LONG_REAL);
   POP_OBJECT (p, &s, A68_LONG_REAL);
   errno = 0;
-  PUSH_VALUE (p, dble (a68_beta_inc_double (VALUE (&s).f, VALUE (&t).f, VALUE (&x).f)), A68_LONG_REAL);
+  PUSH_VALUE (p, dble (a68g_beta_inc_double (VALUE (&s).f, VALUE (&t).f, VALUE (&x).f)), A68_LONG_REAL);
   MATH_RTE (p, errno != 0, M_LONG_REAL, NO_TEXT);
 }
 
@@ -1985,14 +1985,14 @@ void genie_ln_beta_double (NODE_T * p)
 
 void genie_infinity_double (NODE_T * p)
 {
-  PUSH_VALUE (p, dble (a68_posinf_real ()), A68_LONG_REAL);
+  PUSH_VALUE (p, dble (a68g_posinf_real ()), A68_LONG_REAL);
 }
 
 // LONG REAL minus infinity
 
 void genie_minus_infinity_double (NODE_T * p)
 {
-  PUSH_VALUE (p, dble (a68_neginf_double ()), A68_LONG_REAL);
+  PUSH_VALUE (p, dble (a68g_neginf_double ()), A68_LONG_REAL);
 }
 
 #endif
