@@ -42,7 +42,7 @@ void genie_directory (NODE_T * p)
   A68_REF name;
   POP_REF (p, &name);
   CHECK_INIT (p, INITIALISED (&name), M_STRING);
-  char *buffer = (char *) a68_alloc ((size_t) (1 + a68_string_size (p, name)), __func__, __LINE__);
+  char *buffer = (char *) a68g_alloc ((size_t) (1 + a68g_string_size (p, name)), __func__, __LINE__);
   if (buffer == NO_TEXT) {
     diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
     exit_genie (p, A68_RUNTIME_ERROR);
@@ -87,7 +87,7 @@ void genie_directory (NODE_T * p)
       exit_genie (p, A68_RUNTIME_ERROR);
     }
     PUSH_REF (p, z);
-    a68_free (buffer);
+    a68g_free (buffer);
   }
 }
 
@@ -170,10 +170,10 @@ void genie_argc (NODE_T * p)
 void genie_argv (NODE_T * p)
 {
   errno = 0;
-  A68_INT a68_index;
-  POP_OBJECT (p, &a68_index, A68_INT);
-  if (VALUE (&a68_index) >= 1 && VALUE (&a68_index) <= A68 (argc)) {
-    char *q = A68 (argv)[VALUE (&a68_index) - 1];
+  A68_INT a68g_index;
+  POP_OBJECT (p, &a68g_index, A68_INT);
+  if (VALUE (&a68g_index) >= 1 && VALUE (&a68g_index) <= A68 (argc)) {
+    char *q = A68 (argv)[VALUE (&a68g_index) - 1];
     int n = (int) strlen (q);
 // Allow for spaces ending in # to have A68 comment syntax with '#!'.
     while (n > 0 && (IS_SPACE (q[n - 1]) || q[n - 1] == '#')) {
@@ -215,14 +215,14 @@ void genie_a68g_argc (NODE_T * p)
   PUSH_VALUE (p, A68 (argc) - find_good_arg (), A68_INT);
 }
 
-//! @brief PROC (INT) STRING a68_argv
+//! @brief PROC (INT) STRING a68g_argv
 
 void genie_a68g_argv (NODE_T * p)
 {
   errno = 0;
-  A68_INT a68_index;
-  POP_OBJECT (p, &a68_index, A68_INT);
-  int k = VALUE (&a68_index);
+  A68_INT a68g_index;
+  POP_OBJECT (p, &a68g_index, A68_INT);
+  int k = VALUE (&a68g_index);
   if (k > 1) {
     k += find_good_arg ();
   }
@@ -248,7 +248,7 @@ void genie_pwd (NODE_T * p)
   BOOL_T cont = A68_TRUE;
   size_t size = BUFFER_SIZE;
   while (cont) {
-    buffer = (char *) a68_alloc (size, __func__, __LINE__);
+    buffer = (char *) a68g_alloc (size, __func__, __LINE__);
     if (buffer == NO_TEXT) {
       diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
       exit_genie (p, A68_RUNTIME_ERROR);
@@ -256,14 +256,14 @@ void genie_pwd (NODE_T * p)
     if (getcwd (buffer, size) == buffer) {
       cont = A68_FALSE;
     } else {
-      a68_free (buffer);
+      a68g_free (buffer);
       cont = (BOOL_T) (errno == 0);
       size *= 2;
     }
   }
   if (buffer != NO_TEXT && errno == 0) {
     PUSH_REF (p, c_to_a_string (p, buffer, DEFAULT_WIDTH));
-    a68_free (buffer);
+    a68g_free (buffer);
   } else {
     PUSH_REF (p, empty_string (p));
   }
@@ -277,7 +277,7 @@ void genie_cd (NODE_T * p)
   A68_REF dir;
   POP_REF (p, &dir);
   CHECK_INIT (p, INITIALISED (&dir), M_STRING);
-  char *buffer = (char *) a68_alloc ((size_t) (1 + a68_string_size (p, dir)), __func__, __LINE__);
+  char *buffer = (char *) a68g_alloc ((size_t) (1 + a68g_string_size (p, dir)), __func__, __LINE__);
   if (buffer == NO_TEXT) {
     diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
     exit_genie (p, A68_RUNTIME_ERROR);
@@ -289,7 +289,7 @@ void genie_cd (NODE_T * p)
       diagnostic (A68_RUNTIME_ERROR, p, ERROR_FILE_ACCESS);
       exit_genie (p, A68_RUNTIME_ERROR);
     }
-    a68_free (buffer);
+    a68g_free (buffer);
   }
 }
 
@@ -301,7 +301,7 @@ void genie_file_mode (NODE_T * p)
   A68_REF name;
   POP_REF (p, &name);
   CHECK_INIT (p, INITIALISED (&name), M_STRING);
-  char *buffer = (char *) a68_alloc ((size_t) (1 + a68_string_size (p, name)), __func__, __LINE__);
+  char *buffer = (char *) a68g_alloc ((size_t) (1 + a68g_string_size (p, name)), __func__, __LINE__);
   if (buffer == NO_TEXT) {
     diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
     exit_genie (p, A68_RUNTIME_ERROR);
@@ -312,7 +312,7 @@ void genie_file_mode (NODE_T * p)
     } else {
       PUSH_VALUE (p, 0x0, A68_BITS);
     }
-    a68_free (buffer);
+    a68g_free (buffer);
   }
 }
 
@@ -324,7 +324,7 @@ void genie_file_is_block_device (NODE_T * p)
   A68_REF name;
   POP_REF (p, &name);
   CHECK_INIT (p, INITIALISED (&name), M_STRING);
-  char *buffer = (char *) a68_alloc ((size_t) (1 + a68_string_size (p, name)), __func__, __LINE__);
+  char *buffer = (char *) a68g_alloc ((size_t) (1 + a68g_string_size (p, name)), __func__, __LINE__);
   if (buffer == NO_TEXT) {
     diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
     exit_genie (p, A68_RUNTIME_ERROR);
@@ -335,7 +335,7 @@ void genie_file_is_block_device (NODE_T * p)
     } else {
       PUSH_VALUE (p, A68_FALSE, A68_BOOL);
     }
-    a68_free (buffer);
+    a68g_free (buffer);
   }
 }
 
@@ -347,7 +347,7 @@ void genie_file_is_char_device (NODE_T * p)
   A68_REF name;
   POP_REF (p, &name);
   CHECK_INIT (p, INITIALISED (&name), M_STRING);
-  char *buffer = (char *) a68_alloc ((size_t) (1 + a68_string_size (p, name)), __func__, __LINE__);
+  char *buffer = (char *) a68g_alloc ((size_t) (1 + a68g_string_size (p, name)), __func__, __LINE__);
   if (buffer == NO_TEXT) {
     diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
     exit_genie (p, A68_RUNTIME_ERROR);
@@ -358,7 +358,7 @@ void genie_file_is_char_device (NODE_T * p)
     } else {
       PUSH_VALUE (p, A68_FALSE, A68_BOOL);
     }
-    a68_free (buffer);
+    a68g_free (buffer);
   }
 }
 
@@ -370,7 +370,7 @@ void genie_file_is_directory (NODE_T * p)
   A68_REF name;
   POP_REF (p, &name);
   CHECK_INIT (p, INITIALISED (&name), M_STRING);
-  char *buffer = (char *) a68_alloc ((size_t) (1 + a68_string_size (p, name)), __func__, __LINE__);
+  char *buffer = (char *) a68g_alloc ((size_t) (1 + a68g_string_size (p, name)), __func__, __LINE__);
   if (buffer == NO_TEXT) {
     diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
     exit_genie (p, A68_RUNTIME_ERROR);
@@ -381,7 +381,7 @@ void genie_file_is_directory (NODE_T * p)
     } else {
       PUSH_VALUE (p, A68_FALSE, A68_BOOL);
     }
-    a68_free (buffer);
+    a68g_free (buffer);
   }
 }
 
@@ -393,7 +393,7 @@ void genie_file_is_regular (NODE_T * p)
   A68_REF name;
   POP_REF (p, &name);
   CHECK_INIT (p, INITIALISED (&name), M_STRING);
-  char *buffer = (char *) a68_alloc ((size_t) (1 + a68_string_size (p, name)), __func__, __LINE__);
+  char *buffer = (char *) a68g_alloc ((size_t) (1 + a68g_string_size (p, name)), __func__, __LINE__);
   if (buffer == NO_TEXT) {
     diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
     exit_genie (p, A68_RUNTIME_ERROR);
@@ -404,7 +404,7 @@ void genie_file_is_regular (NODE_T * p)
     } else {
       PUSH_VALUE (p, A68_FALSE, A68_BOOL);
     }
-    a68_free (buffer);
+    a68g_free (buffer);
   }
 }
 
@@ -418,7 +418,7 @@ void genie_file_is_fifo (NODE_T * p)
   A68_REF name;
   POP_REF (p, &name);
   CHECK_INIT (p, INITIALISED (&name), M_STRING);
-  char *buffer = (char *) a68_alloc ((size_t) (1 + a68_string_size (p, name)), __func__, __LINE__);
+  char *buffer = (char *) a68g_alloc ((size_t) (1 + a68g_string_size (p, name)), __func__, __LINE__);
   if (buffer == NO_TEXT) {
     diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
     exit_genie (p, A68_RUNTIME_ERROR);
@@ -429,7 +429,7 @@ void genie_file_is_fifo (NODE_T * p)
     } else {
       PUSH_VALUE (p, A68_FALSE, A68_BOOL);
     }
-    a68_free (buffer);
+    a68g_free (buffer);
   }
 }
 
@@ -445,7 +445,7 @@ void genie_file_is_link (NODE_T * p)
   A68_REF name;
   POP_REF (p, &name);
   CHECK_INIT (p, INITIALISED (&name), M_STRING);
-  char *buffer = (char *) a68_alloc ((size_t) (1 + a68_string_size (p, name)), __func__, __LINE__);
+  char *buffer = (char *) a68g_alloc ((size_t) (1 + a68g_string_size (p, name)), __func__, __LINE__);
   if (buffer == NO_TEXT) {
     diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
     exit_genie (p, A68_RUNTIME_ERROR);
@@ -456,7 +456,7 @@ void genie_file_is_link (NODE_T * p)
     } else {
       PUSH_VALUE (p, A68_FALSE, A68_BOOL);
     }
-    a68_free (buffer);
+    a68g_free (buffer);
   }
 }
 
@@ -475,10 +475,10 @@ void convert_string_vector (NODE_T * p, char *vec[], A68_REF row)
     BOOL_T done = A68_FALSE;
     initialise_internal_index (tup, DIM (arr));
     while (!done) {
-      ADDR_T a68_index = calculate_internal_index (tup, DIM (arr));
-      ADDR_T elem_addr = (a68_index + SLICE_OFFSET (arr)) * ELEM_SIZE (arr) + FIELD_OFFSET (arr);
+      ADDR_T a68g_index = calculate_internal_index (tup, DIM (arr));
+      ADDR_T elem_addr = (a68g_index + SLICE_OFFSET (arr)) * ELEM_SIZE (arr) + FIELD_OFFSET (arr);
       BYTE_T *elem = &base_addr[elem_addr];
-      int size = a68_string_size (p, *(A68_REF *) elem);
+      int size = a68g_string_size (p, *(A68_REF *) elem);
       CHECK_INIT (p, INITIALISED ((A68_REF *) elem), M_STRING);
       vec[k] = (char *) get_heap_space ((size_t) (1 + size));
       ASSERT (a_to_c_string (p, vec[k], *(A68_REF *) elem) != NO_TEXT);
@@ -501,7 +501,7 @@ void free_vector (char *vec[])
 {
   int k = 0;
   while (vec[k] != NO_TEXT) {
-    a68_free (vec[k]);
+    a68g_free (vec[k]);
     k++;
   }
 }
@@ -576,13 +576,13 @@ void genie_getenv (NODE_T * p)
   A68_REF a_env;
   POP_REF (p, &a_env);
   CHECK_INIT (p, INITIALISED (&a_env), M_STRING);
-  char *z_env = (char *) get_heap_space ((size_t) (1 + a68_string_size (p, a_env)));
+  char *z_env = (char *) get_heap_space ((size_t) (1 + a68g_string_size (p, a_env)));
   char *z = a_to_c_string (p, z_env, a_env);
   char *val = getenv (z);
   if (val == NO_TEXT) {
     a_env = empty_string (p);
   } else {
-    a_env = tmp_to_a68_string (p, val);
+    a_env = tmp_to_a68g_string (p, val);
   }
   PUSH_REF (p, a_env);
 }
@@ -611,7 +611,7 @@ void genie_exec (NODE_T * p)
   POP_REF (p, &a_args);
   POP_REF (p, &a_prog);
 // Convert strings and hasta el infinito.
-  char *prog = (char *) get_heap_space ((size_t) (1 + a68_string_size (p, a_prog)));
+  char *prog = (char *) get_heap_space ((size_t) (1 + a68g_string_size (p, a_prog)));
   ASSERT (a_to_c_string (p, prog, a_prog) != NO_TEXT);
   char *argv[VECTOR_SIZE], *envp[VECTOR_SIZE];
   convert_string_vector (p, argv, a_args);
@@ -624,7 +624,7 @@ void genie_exec (NODE_T * p)
 // execve only returns if it fails.
   free_vector (argv);
   free_vector (envp);
-  a68_free (prog);
+  a68g_free (prog);
   PUSH_VALUE (p, ret, A68_INT);
 }
 
@@ -650,7 +650,7 @@ void genie_exec_sub (NODE_T * p)
     PUSH_VALUE (p, -1, A68_INT);
   } else if (pid == 0) {
 // Child process.
-    char *prog = (char *) get_heap_space ((size_t) (1 + a68_string_size (p, a_prog)));
+    char *prog = (char *) get_heap_space ((size_t) (1 + a68g_string_size (p, a_prog)));
     ASSERT (a_to_c_string (p, prog, a_prog) != NO_TEXT);
     char *argv[VECTOR_SIZE], *envp[VECTOR_SIZE];
     convert_string_vector (p, argv, a_args);
@@ -661,7 +661,7 @@ void genie_exec_sub (NODE_T * p)
     }
     (void) execve (prog, argv, envp);
 // execve only returns if it fails - end child process.
-    a68_exit (EXIT_FAILURE);
+    a68g_exit (EXIT_FAILURE);
     PUSH_VALUE (p, 0, A68_INT);
   } else {
 // parent process.
@@ -708,7 +708,7 @@ void genie_exec_sub_pipeline (NODE_T * p)
   if (pid == 0) {
 // Child process.
 // Convert  strings.
-    char *prog = (char *) get_heap_space ((size_t) (1 + a68_string_size (p, a_prog)));
+    char *prog = (char *) get_heap_space ((size_t) (1 + a68g_string_size (p, a_prog)));
     ASSERT (a_to_c_string (p, prog, a_prog) != NO_TEXT);
     char *argv[VECTOR_SIZE], *envp[VECTOR_SIZE];
     convert_string_vector (p, argv, a_args);
@@ -726,7 +726,7 @@ void genie_exec_sub_pipeline (NODE_T * p)
     }
     (void) execve (prog, argv, envp);
 // execve only returns if it fails - end child process.
-    a68_exit (EXIT_FAILURE);
+    a68g_exit (EXIT_FAILURE);
     genie_mkpipe (p, -1, -1, -1);
   } else {
 // Parent process.
@@ -773,7 +773,7 @@ void genie_exec_sub_output (NODE_T * p)
     return;
   }
   if (pid == 0) {
-    char *prog = (char *) get_heap_space ((size_t) (1 + a68_string_size (p, a_prog)));
+    char *prog = (char *) get_heap_space ((size_t) (1 + a68g_string_size (p, a_prog)));
     ASSERT (a_to_c_string (p, prog, a_prog) != NO_TEXT);
     char *argv[VECTOR_SIZE], *envp[VECTOR_SIZE];
     convert_string_vector (p, argv, a_args);
@@ -791,7 +791,7 @@ void genie_exec_sub_output (NODE_T * p)
     }
     (void) execve (prog, argv, envp);
 // execve only returns if it fails - end child process.
-    a68_exit (EXIT_FAILURE);
+    a68g_exit (EXIT_FAILURE);
     PUSH_VALUE (p, -1, A68_INT);
   } else {
 // Parent process.
@@ -807,7 +807,7 @@ void genie_exec_sub_output (NODE_T * p)
       }
     } while (pipe_read > 0);
     do {
-      ret = (int) waitpid ((a68_pid_t) pid, &status, 0);
+      ret = (int) waitpid ((a68g_pid_t) pid, &status, 0);
     } while (ret == -1 && errno == EINTR);
     if (ret != pid) {
       status = -1;
@@ -840,6 +840,6 @@ void genie_waitpid (NODE_T * p)
   A68_INT k;
   POP_OBJECT (p, &k, A68_INT);
 #if defined (BUILD_UNIX)
-  ASSERT (waitpid ((a68_pid_t) VALUE (&k), NULL, 0) != -1);
+  ASSERT (waitpid ((a68g_pid_t) VALUE (&k), NULL, 0) != -1);
 #endif
 }
