@@ -370,7 +370,7 @@ void genie (void *compile_plugin)
   }
   io_close_tty_line ();
   if (OPTION_TRACE (&A68_JOB)) {
-    ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "genie: frame stack %uk, expression stack %uk, heap %uk, handles %uk\n", A68 (frame_stack_size) / KILOBYTE, A68 (expr_stack_size) / KILOBYTE, A68 (heap_size) / KILOBYTE, A68 (handle_pool_size) / KILOBYTE) >= 0);
+    ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "genie: frame stack %uk, expression stack %uk, heap %uk, handles %uk\n", A68 (frame_stack_size) / KILOBYTE, A68 (expr_stack_size) / KILOBYTE, A68 (heap_size) / KILOBYTE, A68 (handle_pool_size) / KILOBYTE) >= 0);
     WRITE (A68_STDOUT, A68 (output_line));
   }
   install_signal_handlers ();
@@ -411,7 +411,7 @@ void genie (void *compile_plugin)
     A68 (in_execution) = A68_TRUE;
     A68 (f_entry) = TOP_NODE (&A68_JOB);
 #if defined (BUILD_UNIX)
-    (void) a68_alarm (INTERRUPT_INTERVAL);
+    (void) a68g_alarm (INTERRUPT_INTERVAL);
 #endif
     if (OPTION_TRACE (&A68_JOB)) {
       WIS (TOP_NODE (&A68_JOB));
@@ -428,14 +428,14 @@ void genie (void *compile_plugin)
     } else if (A68 (ret_code) == A68_RUNTIME_ERROR) {
       if (OPTION_BACKTRACE (&A68_JOB)) {
         int printed = 0;
-        ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "\nStack backtrace") >= 0);
+        ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "\nStack backtrace") >= 0);
         WRITE (A68_STDOUT, A68 (output_line));
         stack_dump (A68_STDOUT, A68_FP, 16, &printed);
         WRITE (A68_STDOUT, NEWLINE_STRING);
       }
       if (FILE_LISTING_OPENED (&A68_JOB)) {
         int printed = 0;
-        ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "\nStack backtrace") >= 0);
+        ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "\nStack backtrace") >= 0);
         WRITE (FILE_LISTING_FD (&A68_JOB), A68 (output_line));
         stack_dump (FILE_LISTING_FD (&A68_JOB), A68_FP, 32, &printed);
       }
