@@ -197,7 +197,7 @@ void mp_strtou (NODE_T * p, MP_T * z, char *str, MOID_T * m)
 {
   errno = 0;
   char *radix = NO_TEXT;
-  int base = (int) a68_strtou (str, &radix, 10);
+  int base = (int) a68g_strtou (str, &radix, 10);
   if (radix != NO_TEXT && TO_UPPER (radix[0]) == TO_UPPER (RADIX_CHAR) && errno == 0) {
     int digits = DIGITS (m);
     ADDR_T pop_sp = A68_SP;
