@@ -444,7 +444,7 @@ void mp_romberg_iterations
     (void) div_mp (q, trm, trm, pow2, digs);
     (void) half_mp (q, trm, trm, digs);
     (void) add_mp (q, xx, x, trm, digs);
-//  sum += exp (-mu * xx + (p - 1) * a68_ln_real (xx) - sigma);
+//  sum += exp (-mu * xx + (p - 1) * a68g_ln_real (xx) - sigma);
     (void) ln_mp (q, trn, xx, digs);
     (void) minus_one_mp (q, trm, p, digs);
     (void) mul_mp (q, trm, trm, trn, digs);
@@ -537,7 +537,7 @@ void mp_romberg_estimate (NODE_T *q, MP_T * rho, MP_T * sigma, MP_T *x, MP_T *y,
 // save Romberg estimate and free memory
 // rho = R[adr0 + (n - 1)];
   (void) move_mp (rho, &R[IX (adr0 + n - 1, digs)], digs);
-  a68_free (R);
+  a68g_free (R);
   A68_SP = pop_sp;
 }
 
@@ -586,7 +586,7 @@ void Dgamic_mp (NODE_T *q, MP_T * rho, MP_T * sigma, MP_T *x, MP_T *y, MP_T *mu,
   MP_T *mux = nil_mp (q, digs);
   MP_T *muy = nil_mp (q, digs);
 // Initialization
-// nx = (a68_isinf_real (x) ? a68_neginf_double_real () : -mu * x + p * ln (x));
+// nx = (a68g_isinf_real (x) ? a68g_neginf_double_real () : -mu * x + p * ln (x));
   if (PLUS_INF_MP (x)) {
     SET_MP_ZERO (mx, digs);
     MP_STATUS (nx) = (UNSIGNED_T) MP_STATUS (nx) | MINUS_INF_MASK;
@@ -597,7 +597,7 @@ void Dgamic_mp (NODE_T *q, MP_T * rho, MP_T * sigma, MP_T *x, MP_T *y, MP_T *mu,
     (void) mul_mp (q, nx, p, nx, digs);
     (void) sub_mp (q, nx, nx, mux, digs);
   }
-// ny = (a68_isinf_real (y) ? a68_neginf_double_real () : -mu * y + p * ln (y));
+// ny = (a68g_isinf_real (y) ? a68g_neginf_double_real () : -mu * y + p * ln (y));
   if (PLUS_INF_MP (y)) {
     SET_MP_ZERO (my, digs);
     MP_STATUS (ny) = (UNSIGNED_T) MP_STATUS (ny) | MINUS_INF_MASK;
