@@ -38,14 +38,14 @@ MP_T *mp_pi (NODE_T * p, MP_T * api, int mod, int digs)
 //
 // J. M. Borwein, P. B. Borwein. "Pi and the AGM – A Study in Analytic Number
 // Theory and Computational Complexity", Wiley, New York, 1987.
-    a68_free (A68_MP (mp_pi));
-    a68_free (A68_MP (mp_half_pi));
-    a68_free (A68_MP (mp_two_pi));
-    a68_free (A68_MP (mp_sqrt_two_pi));
-    a68_free (A68_MP (mp_sqrt_pi));
-    a68_free (A68_MP (mp_ln_pi));
-    a68_free (A68_MP (mp_180_over_pi));
-    a68_free (A68_MP (mp_pi_over_180));
+    a68g_free (A68_MP (mp_pi));
+    a68g_free (A68_MP (mp_half_pi));
+    a68g_free (A68_MP (mp_two_pi));
+    a68g_free (A68_MP (mp_sqrt_two_pi));
+    a68g_free (A68_MP (mp_sqrt_pi));
+    a68g_free (A68_MP (mp_ln_pi));
+    a68g_free (A68_MP (mp_180_over_pi));
+    a68g_free (A68_MP (mp_pi_over_180));
     ADDR_T pop_sp = A68_SP;
     MP_T *pi_g = nil_mp (p, gdigs);
     MP_T *two = lit_mp (p, 2, 0, gdigs);
