@@ -66,7 +66,11 @@ int serial_or_collateral (NODE_T * p)
     return SERIAL_CLAUSE;
   } else {
 // Heuristic guess to give intelligible error message.
-    return (semis + exits) >= (commas ? SERIAL_CLAUSE : COLLATERAL_CLAUSE);
+    if (semis + exits >= commas) {
+      return SERIAL_CLAUSE;
+    } else {
+      return COLLATERAL_CLAUSE;
+    }
   }
 }
 
@@ -93,7 +97,7 @@ void pad_node (NODE_T * p, int a)
 
 //! @brief Diagnose extensions.
 
-void a68_extension (NODE_T * p)
+void a68g_extension (NODE_T * p)
 {
   if (OPTION_PORTCHECK (&A68_JOB)) {
     diagnostic (A68_WARNING | A68_FORCE_DIAGNOSTICS, p, WARNING_EXTENSION);
@@ -133,7 +137,7 @@ void strange_tokens (NODE_T * p)
 void strange_separator (NODE_T * p)
 {
   NODE_T *q = ((p != NO_NODE && NEXT (p) != NO_NODE) ? NEXT (p) : p);
-  diagnostic (A68_SYNTAX_ERROR, q, ERROR_SYNTAX_STRANGE_SEPARATOR);
+  diagnostic (A68_SYNTAX_ERROR, q, ERROR_SYNTAX_STRANGE_TOKENS);
 }
 
 //! @brief If match then reduce a sentence, the core BU parser routine.
@@ -177,7 +181,7 @@ void reduce (NODE_T * p, void (*a) (NODE_T *), BOOL_T * z, ...)
   if (head != NO_NODE && OPTION_REDUCTIONS (&A68_JOB) && LINE_NUMBER (head) > 0) {
     A68_PARSER (reductions)++;
     WIS (head);
-    ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, "\nReduction %d: %s<-", A68_PARSER (reductions), non_terminal_string (A68 (edit_line), result)) >= 0);
+    ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "\nReduction %d: %s<-", A68_PARSER (reductions), non_terminal_string (A68 (edit_line), result)) >= 0);
     WRITE (A68_STDOUT, A68 (output_line));
     int count = 0;
     for (NODE_T *q = head; q != NO_NODE && tail != NO_NODE && q != NEXT (tail); FORWARD (q), count++) {
@@ -189,7 +193,7 @@ void reduce (NODE_T * p, void (*a) (NODE_T *), BOOL_T * z, ...)
       if (str != NO_TEXT) {
         WRITE (A68_STDOUT, str);
         if (gatt == IDENTIFIER || gatt == OPERATOR || gatt == DENOTATION || gatt == INDICANT) {
-          ASSERT (a68_bufprt (A68 (output_line), SNPRINTF_SIZE, " \"%s\"", NSYMBOL (q)) >= 0);
+          ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, " \"%s\"", NSYMBOL (q)) >= 0);
           WRITE (A68_STDOUT, A68 (output_line));
         }
       } else {
@@ -1102,13 +1106,13 @@ void reduce_format_texts (NODE_T * p)
   }
   ambiguous_patterns (p);
   for (NODE_T *q = p; q != NO_NODE; FORWARD (q)) {
-    reduce (q, a68_extension, NO_TICK, A68_PATTERN, BITS_C_PATTERN, STOP);
-    reduce (q, a68_extension, NO_TICK, A68_PATTERN, CHAR_C_PATTERN, STOP);
-    reduce (q, a68_extension, NO_TICK, A68_PATTERN, FIXED_C_PATTERN, STOP);
-    reduce (q, a68_extension, NO_TICK, A68_PATTERN, FLOAT_C_PATTERN, STOP);
-    reduce (q, a68_extension, NO_TICK, A68_PATTERN, GENERAL_C_PATTERN, STOP);
-    reduce (q, a68_extension, NO_TICK, A68_PATTERN, INTEGRAL_C_PATTERN, STOP);
-    reduce (q, a68_extension, NO_TICK, A68_PATTERN, STRING_C_PATTERN, STOP);
+    reduce (q, a68g_extension, NO_TICK, A68_PATTERN, BITS_C_PATTERN, STOP);
+    reduce (q, a68g_extension, NO_TICK, A68_PATTERN, CHAR_C_PATTERN, STOP);
+    reduce (q, a68g_extension, NO_TICK, A68_PATTERN, FIXED_C_PATTERN, STOP);
+    reduce (q, a68g_extension, NO_TICK, A68_PATTERN, FLOAT_C_PATTERN, STOP);
+    reduce (q, a68g_extension, NO_TICK, A68_PATTERN, GENERAL_C_PATTERN, STOP);
+    reduce (q, a68g_extension, NO_TICK, A68_PATTERN, INTEGRAL_C_PATTERN, STOP);
+    reduce (q, a68g_extension, NO_TICK, A68_PATTERN, STRING_C_PATTERN, STOP);
     reduce (q, NO_NOTE, NO_TICK, A68_PATTERN, BITS_PATTERN, STOP);
     reduce (q, NO_NOTE, NO_TICK, A68_PATTERN, BOOLEAN_PATTERN, STOP);
     reduce (q, NO_NOTE, NO_TICK, A68_PATTERN, CHOICE_PATTERN, STOP);
@@ -1285,10 +1289,10 @@ void reduce_tertiaries (NODE_T * p)
       reduce (q, NO_NOTE, &siga, ROW_FUNCTION, ROW_SYMBOL, TERTIARY, STOP);
     }
     for (NODE_T *q = p; q != NO_NODE; FORWARD (q)) {
-      reduce (q, a68_extension, &siga, TERTIARY, TRANSPOSE_FUNCTION, STOP);
-      reduce (q, a68_extension, &siga, TERTIARY, DIAGONAL_FUNCTION, STOP);
-      reduce (q, a68_extension, &siga, TERTIARY, COLUMN_FUNCTION, STOP);
-      reduce (q, a68_extension, &siga, TERTIARY, ROW_FUNCTION, STOP);
+      reduce (q, a68g_extension, &siga, TERTIARY, TRANSPOSE_FUNCTION, STOP);
+      reduce (q, a68g_extension, &siga, TERTIARY, DIAGONAL_FUNCTION, STOP);
+      reduce (q, a68g_extension, &siga, TERTIARY, COLUMN_FUNCTION, STOP);
+      reduce (q, a68g_extension, &siga, TERTIARY, ROW_FUNCTION, STOP);
     }
   }
   for (NODE_T *q = p; q != NO_NODE; FORWARD (q)) {
@@ -1315,8 +1319,8 @@ void reduce_units (NODE_T * p)
   for (NODE_T *q = p; q != NO_NODE; FORWARD (q)) {
     reduce (q, NO_NOTE, NO_TICK, UNIT, ASSIGNATION, STOP);
     reduce (q, NO_NOTE, NO_TICK, UNIT, IDENTITY_RELATION, STOP);
-    reduce (q, a68_extension, NO_TICK, UNIT, AND_FUNCTION, STOP);
-    reduce (q, a68_extension, NO_TICK, UNIT, OR_FUNCTION, STOP);
+    reduce (q, a68g_extension, NO_TICK, UNIT, AND_FUNCTION, STOP);
+    reduce (q, a68g_extension, NO_TICK, UNIT, OR_FUNCTION, STOP);
     reduce (q, NO_NOTE, NO_TICK, UNIT, ROUTINE_TEXT, STOP);
     reduce (q, NO_NOTE, NO_TICK, UNIT, JUMP, STOP);
     reduce (q, NO_NOTE, NO_TICK, UNIT, SKIP, STOP);
@@ -1851,7 +1855,7 @@ void recover_from_error (NODE_T * p, int expect, BOOL_T suppress)
   if (p == NO_NODE) {
     return;
   }
-  if (expect == SOME_CLAUSE) {
+  if (expect == 0) {
     expect = serial_or_collateral (p);
   }
   if (!suppress) {
@@ -1863,7 +1867,7 @@ void recover_from_error (NODE_T * p, int expect, BOOL_T suppress)
         diagnostic (A68_SYNTAX_ERROR, w, ERROR_SYNTAX_EXPECTED, expect);
       }
     } else {
-      diagnostic (A68_SYNTAX_ERROR, w, ERROR_INVALID_SEQUENCE, seq, expect);
+      diagnostic (A68_SYNTAX_ERROR, w, ERROR_SYNTAX_SENTENCE, seq);
     }
     if (ERROR_COUNT (&A68_JOB) >= MAX_ERRORS) {
       longjmp (A68_PARSER (bottom_up_crash_exit), 1);
