@@ -37,11 +37,11 @@ void bracket_check_error (char *txt, int n, char *bra, char *ket)
   if (n != 0) {
     BUFFER buf;
     BUFCLR (buf);
-    ASSERT (a68_bufprt (buf, SNPRINTF_SIZE, "\"%s\" without matching \"%s\"", (n > 0 ? bra : ket), (n > 0 ? ket : bra)) >= 0);
+    ASSERT (a68g_bufprt (buf, SNPRINTF_SIZE, "\"%s\" without matching \"%s\"", (n > 0 ? bra : ket), (n > 0 ? ket : bra)) >= 0);
     if (strlen (txt) > 0) {
-      a68_bufcat (txt, " or ", BUFFER_SIZE);
+      a68g_bufcat (txt, " or ", BUFFER_SIZE);
     }
-    a68_bufcat (txt, buf, BUFFER_SIZE);
+    a68g_bufcat (txt, buf, BUFFER_SIZE);
   }
 }
 
