@@ -247,7 +247,7 @@ void extract_priorities (NODE_T * p)
           if (len > 1 && NSYMBOL (q)[len - 1] == '=') {
             NODE_T *y = q;
             char *sym = (char *) get_temp_heap_space ((size_t) (len + 1));
-            a68_bufcpy (sym, NSYMBOL (q), len + 1);
+            a68g_bufcpy (sym, NSYMBOL (q), len + 1);
             sym[len - 1] = NULL_CHAR;
             NSYMBOL (q) = TEXT (add_token (&A68 (top_token), sym));
             if (len > 2 && NSYMBOL (q)[len - 2] == ':' && NSYMBOL (q)[len - 3] != '=') {
@@ -322,7 +322,7 @@ void extract_operators (NODE_T * p)
             int len = (int) strlen (NSYMBOL (q));
             if (len > 1 && NSYMBOL (q)[len - 1] == '=') {
               char *sym = (char *) get_temp_heap_space ((size_t) (len + 1));
-              a68_bufcpy (sym, NSYMBOL (q), len + 1);
+              a68g_bufcpy (sym, NSYMBOL (q), len + 1);
               sym[len - 1] = NULL_CHAR;
               NSYMBOL (q) = TEXT (add_token (&A68 (top_token), sym));
               if (len > 2 && NSYMBOL (q)[len - 2] == ':' && NSYMBOL (q)[len - 3] != '=') {
