@@ -120,9 +120,9 @@ void append_source_line (char *str, LINE_T ** ref_l, int *line_num, char *filena
 void unworthy (LINE_T * u, char *v, char ch)
 {
   if (IS_PRINT (ch)) {
-    ASSERT (a68_bufprt (A68 (edit_line), SNPRINTF_SIZE, "*%s", ERROR_UNWORTHY_CHARACTER) >= 0);
+    ASSERT (a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "*%s", ERROR_UNWORTHY_CHARACTER) >= 0);
   } else {
-    ASSERT (a68_bufprt (A68 (edit_line), SNPRINTF_SIZE, "*%s %s", ERROR_UNWORTHY_CHARACTER, ctrl_char (ch)) >= 0);
+    ASSERT (a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "*%s %s", ERROR_UNWORTHY_CHARACTER, ctrl_char (ch)) >= 0);
   }
   scan_error (u, v, A68 (edit_line));
 }
@@ -143,8 +143,8 @@ void concatenate_lines (LINE_T * top)
       z[len - 2] = NULL_CHAR;
       len += (int) strlen (STRING (NEXT (q)));
       z = (char *) get_fixed_heap_space ((size_t) (len + 1));
-      a68_bufcpy (z, STRING (q), len + 1);
-      a68_bufcat (z, STRING (NEXT (q)), len + 1);
+      a68g_bufcpy (z, STRING (q), len + 1);
+      a68g_bufcat (z, STRING (NEXT (q)), len + 1);
       STRING (NEXT (q))[0] = NULL_CHAR;
       STRING (q) = z;
     }
@@ -476,19 +476,19 @@ void include_files (LINE_T * top)
         SCAN_ERROR (n == 0, start_l, start_c, ERROR_INCORRECT_FILENAME);
 // Make the name relative to the position of the source file (C preprocessor standard).
         if (FILENAME (u) != NO_TEXT) {
-          fn = a68_relpath (a68_dirname (FILENAME (u)), a68_dirname (fnb), a68_basename (fnb));
+          fn = a68g_relpath (a68g_dirname (FILENAME (u)), a68g_dirname (fnb), a68g_basename (fnb));
         } else {
-          fn = a68_relpath (FILE_PATH (&A68_JOB), a68_dirname (fnb), a68_basename (fnb));
+          fn = a68g_relpath (FILE_PATH (&A68_JOB), a68g_dirname (fnb), a68g_basename (fnb));
         }
 // Do not check errno, since errno may be undefined here after a successful call.
         if (fn != NO_TEXT) {
-          a68_bufcpy (fnb, fn, BUFFER_SIZE);
+          a68g_bufcpy (fnb, fn, BUFFER_SIZE);
         } else {
           SCAN_ERROR_INFO (A68_TRUE, NO_LINE, NO_TEXT, ERROR_SOURCE_FILE_INCLUDE_OPEN, fnb);
         }
         fnwid = (int) strlen (fnb) + 1;
         fn = (char *) get_fixed_heap_space ((size_t) fnwid);
-        a68_bufcpy (fn, fnb, fnwid);
+        a68g_bufcpy (fn, fnb, fnwid);
 // Ignore the file when included more than once.
         for (t = top; t != NO_LINE; t = NEXT (t)) {
           if (strcmp (FILENAME (t), fn) == 0) {
@@ -614,7 +614,7 @@ BOOL_T read_script_file (void)
       ASSERT (io_read (source, &ch, 1) == 1);
     }
     linenum[k] = NULL_CHAR;
-    num = (int) strtol (linenum, NO_VAR, 10);
+    num = (int) strtol (linenum, NO_REF, 10);
     ABEND (errno == ERANGE, ERROR_INTERNAL_CONSISTENCY, __func__);
 // COPY original line into buffer.
     ASSERT (io_read (source, &ch, 1) == 1);
@@ -633,7 +633,7 @@ BOOL_T read_script_file (void)
 
 //! @brief match first non-white characters in string.
 
-BOOL_T a68_start(char *u, char *v, char **end)
+BOOL_T a68g_start(char *u, char *v, char **end)
 {
   *end = NO_TEXT;
   while (v[0] != NULL_CHAR) {
@@ -679,11 +679,11 @@ BOOL_T read_source_file (void)
   char *pr1 = "'PR'QUOTESTROPPING'PR'";
   char *pr2 = "'PRAGMAT'QUOTESTROPPING'PRAGMAT'";
   char *end = NO_TEXT;
-  if (a68_start (text, pr1, &end)) {
+  if (a68g_start (text, pr1, &end)) {
     OPTION_STROPPING (&A68_JOB) = QUOTE_STROPPING;
     buffer = end;
     A68_PARSER (source_file_size) = strlen (buffer);
-  } else if (a68_start (text, pr2, &end)) {
+  } else if (a68g_start (text, pr2, &end)) {
     OPTION_STROPPING (&A68_JOB) = QUOTE_STROPPING;
     buffer = end;
     A68_PARSER (source_file_size) = strlen (buffer);
@@ -698,7 +698,7 @@ BOOL_T read_source_file (void)
     prelude_start = quote_prelude_start;
     postlude = quote_postlude;
   } else {
-    prelude_start = postlude = NO_VAR;
+    prelude_start = postlude = NO_REF;
   }
   append_environ (prelude_start, &ref_l, &line_num, "prelude");
 // Link all lines into the list.
@@ -1408,7 +1408,7 @@ void tokenise_source (NODE_T ** root, int level, BOOL_T in_format, LINE_T ** l,
 {
   char *lpr = NO_TEXT;
   int lprt = 0;
-  while (l != NO_VAR && !A68_PARSER (stop_scanner)) {
+  while (l != NO_REF && !A68_PARSER (stop_scanner)) {
     int att = 0;
     get_next_token (in_format, l, s, start_l, start_c, &att);
     if (A68_PARSER (scan_buf)[0] == STOP_CHAR) {
@@ -1460,8 +1460,8 @@ void tokenise_source (NODE_T ** root, int level, BOOL_T in_format, LINE_T ** l,
             } else {
               char *stale = lpr;
               lpr = new_string (lpr, "\n\n", nlpr, NO_TEXT);
-              a68_free (nlpr);
-              a68_free (stale);
+              a68g_free (nlpr);
+              a68g_free (stale);
             }
             lprt = att;
             make_node = A68_FALSE;
@@ -1472,8 +1472,8 @@ void tokenise_source (NODE_T ** root, int level, BOOL_T in_format, LINE_T ** l,
             } else {
               char *stale = lpr;
               lpr = new_string (lpr, "\n\n", nlpr, NO_TEXT);
-              a68_free (nlpr);
-              a68_free (stale);
+              a68g_free (nlpr);
+              a68g_free (stale);
             }
             lprt = att;
             if (!A68_PARSER (stop_scanner)) {
