@@ -74,7 +74,7 @@ TUPLE_T scope_make_tuple (int e, int t)
 
 void scope_add (SCOPE_T ** sl, NODE_T * p, TUPLE_T tup)
 {
-  if (sl != NO_VAR) {
+  if (sl != NO_REF) {
     SCOPE_T *ns = (SCOPE_T *) get_temp_heap_space ((unt) SIZE_ALIGNED (SCOPE_T));
     WHERE (ns) = p;
     TUPLE (ns) = tup;
@@ -272,7 +272,7 @@ void scope_bounds (NODE_T * p)
 {
   for (; p != NO_NODE; FORWARD (p)) {
     if (IS (p, UNIT)) {
-      scope_statement (p, NO_VAR);
+      scope_statement (p, NO_REF);
     } else {
       scope_bounds (SUB (p));
     }
@@ -437,12 +437,12 @@ void scope_coercion (NODE_T * p, SCOPE_T ** s)
 {
   if (is_coercion (p)) {
     if (IS (p, VOIDING)) {
-      scope_coercion (SUB (p), NO_VAR);
+      scope_coercion (SUB (p), NO_REF);
     } else if (IS (p, DEREFERENCING)) {
 // Leave this to the dynamic scope checker.
-      scope_coercion (SUB (p), NO_VAR);
+      scope_coercion (SUB (p), NO_REF);
     } else if (IS (p, DEPROCEDURING)) {
-      scope_coercion (SUB (p), NO_VAR);
+      scope_coercion (SUB (p), NO_REF);
     } else if (IS (p, ROWING)) {
       SCOPE_T *z = NO_SCOPE;
       scope_coercion (SUB (p), &z);
@@ -729,7 +729,7 @@ void scope_serial_clause (NODE_T * p, SCOPE_T ** s, BOOL_T terminator)
       if (terminator) {
         scope_statement (p, s);
       } else {
-        scope_statement (p, NO_VAR);
+        scope_statement (p, NO_REF);
       }
     }
   }
@@ -763,7 +763,7 @@ void scope_collateral_clause (NODE_T * p, SCOPE_T ** s)
 
 void scope_conditional_clause (NODE_T * p, SCOPE_T ** s)
 {
-  scope_serial_clause (NEXT_SUB (p), NO_VAR, A68_TRUE);
+  scope_serial_clause (NEXT_SUB (p), NO_REF, A68_TRUE);
   FORWARD (p);
   scope_serial_clause (NEXT_SUB (p), s, A68_TRUE);
   if ((FORWARD (p)) != NO_NODE) {
@@ -803,21 +803,21 @@ void scope_loop_clause (NODE_T * p)
     if (IS (p, FOR_PART)) {
       scope_loop_clause (NEXT (p));
     } else if (is_one_of (p, FROM_PART, BY_PART, TO_PART, STOP)) {
-      scope_statement (NEXT_SUB (p), NO_VAR);
+      scope_statement (NEXT_SUB (p), NO_REF);
       scope_loop_clause (NEXT (p));
     } else if (IS (p, WHILE_PART)) {
-      scope_serial_clause (NEXT_SUB (p), NO_VAR, A68_TRUE);
+      scope_serial_clause (NEXT_SUB (p), NO_REF, A68_TRUE);
       scope_loop_clause (NEXT (p));
     } else if (is_one_of (p, DO_PART, ALT_DO_PART, STOP)) {
       NODE_T *do_p = NEXT_SUB (p), *un_p;
       if (IS (do_p, SERIAL_CLAUSE)) {
-        scope_serial_clause (do_p, NO_VAR, A68_TRUE);
+        scope_serial_clause (do_p, NO_REF, A68_TRUE);
         un_p = NEXT (do_p);
       } else {
         un_p = do_p;
       }
       if (un_p != NO_NODE && IS (un_p, UNTIL_PART)) {
-        scope_serial_clause (NEXT_SUB (un_p), NO_VAR, A68_TRUE);
+        scope_serial_clause (NEXT_SUB (un_p), NO_REF, A68_TRUE);
       }
     }
   }
@@ -892,5 +892,5 @@ void scope_checker (NODE_T * p)
 // PROC and FORMAT identities can now be assigned a scope.
   bind_scope_to_tags (p);
 // Now check evertyhing else.
-  scope_enclosed_clause (SUB (p), NO_VAR);
+  scope_enclosed_clause (SUB (p), NO_REF);
 }
