@@ -55,77 +55,6 @@ void substitute_brackets (NODE_T * p)
   }
 }
 
-//! @brief Intelligible diagnostic from syntax tree branch.
-
-char *phrase_to_text (NODE_T * p, NODE_T ** w)
-{
-#define MAX_TERMINALS 8
-  int count = 0, line = -1;
-  static BUFFER buffer;
-  for (buffer[0] = NULL_CHAR; p != NO_NODE && count < MAX_TERMINALS; FORWARD (p)) {
-    if (LINE_NUMBER (p) > 0) {
-      int gatt = get_good_attribute (p);
-      char *z = non_terminal_string (A68 (input_line), gatt);
-// Where to put the error message? Bob Uzgalis noted that actual content of a 
-// diagnostic is not as important as accurately indicating *were* the problem is! 
-      if (w != NO_VAR) {
-        if (count == 0 || (*w) == NO_NODE) {
-          *w = p;
-        } else if (dont_mark_here (*w)) {
-          *w = p;
-        }
-      }
-// Add initiation.
-      if (count == 0) {
-        if (w != NO_VAR) {
-          a68_bufcat (buffer, "construct beginning with", BUFFER_SIZE);
-        }
-      } else if (count == 1) {
-        a68_bufcat (buffer, " followed by", BUFFER_SIZE);
-      } else if (count == 2) {
-        a68_bufcat (buffer, " and then", BUFFER_SIZE);
-      } else if (count >= 3) {
-        a68_bufcat (buffer, " and", BUFFER_SIZE);
-      }
-// Attribute or symbol.
-      if (z != NO_TEXT && SUB (p) != NO_NODE) {
-        if (gatt == IDENTIFIER || gatt == OPERATOR || gatt == DENOTATION) {
-          ASSERT (a68_bufprt (A68 (edit_line), SNPRINTF_SIZE, " \"%s\"", NSYMBOL (p)) >= 0);
-          a68_bufcat (buffer, A68 (edit_line), BUFFER_SIZE);
-        } else {
-          if (strchr ("aeio", z[0]) != NO_TEXT) {
-            a68_bufcat (buffer, " an", BUFFER_SIZE);
-          } else {
-            a68_bufcat (buffer, " a", BUFFER_SIZE);
-          }
-          ASSERT (a68_bufprt (A68 (edit_line), SNPRINTF_SIZE, " %s", z) >= 0);
-          a68_bufcat (buffer, A68 (edit_line), BUFFER_SIZE);
-        }
-      } else if (z != NO_TEXT && SUB (p) == NO_NODE) {
-        ASSERT (a68_bufprt (A68 (edit_line), SNPRINTF_SIZE, " \"%s\"", NSYMBOL (p)) >= 0);
-        a68_bufcat (buffer, A68 (edit_line), BUFFER_SIZE);
-      } else if (NSYMBOL (p) != NO_TEXT) {
-        ASSERT (a68_bufprt (A68 (edit_line), SNPRINTF_SIZE, " \"%s\"", NSYMBOL (p)) >= 0);
-        a68_bufcat (buffer, A68 (edit_line), BUFFER_SIZE);
-      }
-// Add "starting in line nn".
-      if (z != NO_TEXT && line != LINE_NUMBER (p)) {
-        line = LINE_NUMBER (p);
-        if (gatt == SERIAL_CLAUSE || gatt == ENQUIRY_CLAUSE || gatt == INITIALISER_SERIES) {
-          a68_bufcat (buffer, " starting", BUFFER_SIZE);
-        }
-        ASSERT (a68_bufprt (A68 (edit_line), SNPRINTF_SIZE, " in line %d", line) >= 0);
-        a68_bufcat (buffer, A68 (edit_line), BUFFER_SIZE);
-      }
-      count++;
-    }
-  }
-  if (p != NO_NODE && count == MAX_TERMINALS) {
-    a68_bufcat (buffer, " etcetera", BUFFER_SIZE);
-  }
-  return buffer;
-}
-
 // Next is a top-down parser that branches out the basic blocks.
 // After this we can assign symbol tables to basic blocks.
 // This renders the two-level grammar LALR.
