@@ -312,15 +312,122 @@ int get_good_attribute (NODE_T * p)
   case UNIT:
   case TERTIARY:
   case SECONDARY:
-  case PRIMARY: {
+  case PRIMARY:
+  case ENCLOSED_CLAUSE: {
       return get_good_attribute (SUB (p));
     }
+  case DECLARER: {
+    if (IS (SUB (p), INDICANT)) {
+      return ATTRIBUTE (SUB_SUB (p));
+    } else {
+      return DECLARER;
+    }
+  }
+  case DECLARATION_LIST: {
+    if (SUB (p) != NO_NODE) {
+      return ATTRIBUTE (SUB (p));
+    } else {
+      return ATTRIBUTE (p);
+    }
+  }
   default: {
       return ATTRIBUTE (p);
     }
   }
 }
 
+//! @brief Intelligible diagnostic from syntax tree branch.
+
+char *phrase_to_text (NODE_T * p, NODE_T ** w)
+{
+#define MAX_TERMINALS 10
+  int count = 0;
+  BOOL_T put_space = A68_FALSE;
+  static BUFFER buffer;
+  buffer[0] = NULL_CHAR;
+  while (p != NO_NODE && count < MAX_TERMINALS) {
+    if (LINE_NUMBER (p) > 0) {
+      int gatt = get_good_attribute (p);
+      char *z = non_terminal_string (A68 (input_line), gatt);
+// Where to put the error message? 
+// The actual content of a  diagnostic is not as important 
+// as accurately indicating *were* the problem is! 
+      if (w != NO_REF) {
+        if (count == 0 || (*w) == NO_NODE) {
+          *w = p;
+        } else if (dont_mark_here (*w)) {
+          *w = p;
+        }
+      }
+      switch (gatt) {
+        case SEMI_SYMBOL:
+        case COMMA_SYMBOL:
+        case CLOSE_SYMBOL:
+        case BUS_SYMBOL: {
+          // Next symbol may have leading space.
+          put_space = A68_TRUE;
+          break;
+        }
+        case OPEN_SYMBOL:
+        case SUB_SYMBOL: {
+          if (put_space) {
+            a68g_bufcat (buffer, " ", BUFFER_SIZE);
+          }
+          // Next symbol has no leading space.
+          put_space = A68_FALSE;
+          break;              
+        }
+        default: {
+          if (put_space) {
+            a68g_bufcat (buffer, " ", BUFFER_SIZE);
+          }
+          // Next symbol may have leading space.
+          put_space = A68_TRUE;
+          break;
+        }
+      }
+// Attribute or symbol.
+      if (z != NO_TEXT) {
+        switch (gatt) {
+          case DENOTATION:
+          case IDENTIFIER: {
+            ASSERT (a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "%s '%s'", z, NSYMBOL (p)) >= 0);
+            break;
+          }
+          case OPERATOR: {
+            ASSERT (a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "%s", NSYMBOL (p)) >= 0);
+            break;
+          }
+          case DECLARER:
+          case COLON_SYMBOL: {
+            ASSERT (a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "%s", z) >= 0);
+            break;
+          }
+          default: {
+            if (SUB (p) == NO_NODE && NSYMBOL (p) != NO_TEXT) {
+              ASSERT (a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "%s", NSYMBOL (p)) >= 0);
+            } else {
+              ASSERT (a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "%s", z) >= 0);
+            }
+            break;
+          }
+        }
+      } else if (NSYMBOL (p) != NO_TEXT) {
+        ASSERT (a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "%s", NSYMBOL (p)) >= 0);
+      } else {
+        ASSERT (a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "...") >= 0);
+      }
+      a68g_bufcat (buffer, A68 (edit_line), BUFFER_SIZE);
+      count++;
+    }
+    FORWARD (p);
+  }
+  if (p != NO_NODE && count == MAX_TERMINALS) {
+    a68g_bufcat (buffer, " ... ", BUFFER_SIZE);
+  }
+  return buffer;
+}
+
 //! @brief Preferably don't put intelligible diagnostic here.
 
 BOOL_T dont_mark_here (NODE_T * p)
@@ -434,7 +541,7 @@ BOOL_T dont_mark_here (NODE_T * p)
   return A68_FALSE;
 }
 
-void a68_parser (void)
+void a68g_parser (void)
 {
 // Tokeniser.
   FILE_SOURCE_OPENED (&A68_JOB) = A68_TRUE;
@@ -481,7 +588,7 @@ void a68_parser (void)
 // Final initialisations.
   if (ERROR_COUNT (&A68_JOB) == 0) {
     if (OPTION_REGRESSION_TEST (&A68_JOB)) {
-      a68_bufcpy (A68 (a68_cmd_name), "a68g", BUFFER_SIZE);
+      a68g_bufcpy (A68 (a68g_cmd_name), "a68g", BUFFER_SIZE);
       io_close_tty_line ();
       WRITE (A68_STDERR, "[");
       WRITE (A68_STDERR, FILE_INITIAL_NAME (&A68_JOB));
