@@ -40,7 +40,7 @@ void plugin_driver_code (void)
     int num = 0;
     renumber_nodes (TOP_NODE (&A68_JOB), &num);
     A68 (node_register) = (NODE_T **) get_heap_space ((size_t) num * sizeof (NODE_T));
-    ABEND (A68 (node_register) == NO_VAR, ERROR_ACTION, __func__);
+    ABEND (A68 (node_register) == NO_REF, ERROR_ACTION, __func__);
     register_nodes (TOP_NODE (&A68_JOB));
     FILE_OBJECT_FD (&A68_JOB) = open (FILE_OBJECT_NAME (&A68_JOB), O_WRONLY | O_CREAT | O_TRUNC, A68_PROTECTION);
     ABEND (FILE_OBJECT_FD (&A68_JOB) == -1, ERROR_ACTION, FILE_OBJECT_NAME (&A68_JOB));
@@ -67,26 +67,26 @@ void plugin_driver_compile (void)
     if (OPTION_RERUN (&A68_JOB) == A68_FALSE) {
       announce_phase ("plugin compiler");
       errno = 0;
-      ASSERT (a68_bufprt (options, SNPRINTF_SIZE, "%s %s", optimisation_option (), A68_GCC_OPTIONS) >= 0);
+      ASSERT (a68g_bufprt (options, SNPRINTF_SIZE, "%s %s", optimisation_option (), A68_GCC_OPTIONS) >= 0);
 #if defined (HAVE_PIC)
-      a68_bufcat (options, " ", BUFFER_SIZE);
-      a68_bufcat (options, HAVE_PIC, BUFFER_SIZE);
+      a68g_bufcat (options, " ", BUFFER_SIZE);
+      a68g_bufcat (options, HAVE_PIC, BUFFER_SIZE);
 #endif
 
 // Before Apple Silicon Mac:
 //
-//    ASSERT (a68_bufprt (cmd, SNPRINTF_SIZE, "%s -I%s %s -c -o \"%s\" \"%s\"", C_COMPILER, INCLUDE_DIR, options, FILE_BINARY_NAME (&A68_JOB), FILE_OBJECT_NAME (&A68_JOB)) >= 0);
+//    ASSERT (a68g_bufprt (cmd, SNPRINTF_SIZE, "%s -I%s %s -c -o \"%s\" \"%s\"", C_COMPILER, INCLUDE_DIR, options, FILE_BINARY_NAME (&A68_JOB), FILE_OBJECT_NAME (&A68_JOB)) >= 0);
 //    ABEND (system (cmd) != 0, ERROR_ACTION, cmd);
-//    ASSERT (a68_bufprt (cmd, SNPRINTF_SIZE, "ld -export-dynamic -shared -o \"%s\" \"%s\"", FILE_PLUGIN_NAME (&A68_JOB), FILE_BINARY_NAME (&A68_JOB)) >= 0);
+//    ASSERT (a68g_bufprt (cmd, SNPRINTF_SIZE, "ld -export-dynamic -shared -o \"%s\" \"%s\"", FILE_PLUGIN_NAME (&A68_JOB), FILE_BINARY_NAME (&A68_JOB)) >= 0);
 //    ABEND (system (cmd) != 0, ERROR_ACTION, cmd);
 //
 // Apple Silicon Mac patches kindly provided by Neil Matthew.
 
-      ASSERT (a68_bufprt (cmd, SNPRINTF_SIZE, "%s %s %s -c -o \"%s\" \"%s\"", C_COMPILER, INCLUDE_DIR, options, FILE_BINARY_NAME (&A68_JOB), FILE_OBJECT_NAME (&A68_JOB)) >= 0); 
+      ASSERT (a68g_bufprt (cmd, SNPRINTF_SIZE, "%s %s %s -c -o \"%s\" \"%s\"", C_COMPILER, INCLUDE_DIR, options, FILE_BINARY_NAME (&A68_JOB), FILE_OBJECT_NAME (&A68_JOB)) >= 0); 
       ABEND (system (cmd) != 0, ERROR_ACTION, cmd);
-      ASSERT (a68_bufprt (cmd, SNPRINTF_SIZE, "ld %s -o \"%s\" \"%s\"", EXPORT_DYNAMIC_FLAGS, FILE_PLUGIN_NAME (&A68_JOB), FILE_BINARY_NAME (&A68_JOB)) >= 0);
+      ASSERT (a68g_bufprt (cmd, SNPRINTF_SIZE, "ld %s -o \"%s\" \"%s\"", EXPORT_DYNAMIC_FLAGS, FILE_PLUGIN_NAME (&A68_JOB), FILE_BINARY_NAME (&A68_JOB)) >= 0);
       ABEND (system (cmd) != 0, ERROR_ACTION, cmd);
-      a68_rm (FILE_BINARY_NAME (&A68_JOB));
+      a68g_rm (FILE_BINARY_NAME (&A68_JOB));
     }
   }
 #endif
@@ -103,15 +103,15 @@ void plugin_driver_genie (void)
   void *compile_plugin = NULL;
   if (OPTION_OPT_LEVEL (&A68_JOB) > 0) {
     char plugin_name[BUFFER_SIZE];
-    void *a68_plugin;
+    void *a68g_plugin;
     struct stat srcstat, objstat;
     int ret;
     announce_phase ("plugin dynamic linker");
-    ASSERT (a68_bufprt (plugin_name, SNPRINTF_SIZE, "%s", FILE_PLUGIN_NAME (&A68_JOB)) >= 0);
+    ASSERT (a68g_bufprt (plugin_name, SNPRINTF_SIZE, "%s", FILE_PLUGIN_NAME (&A68_JOB)) >= 0);
 // Correction when pwd is outside LD_PLUGIN_PATH.
 // The DL cannot be loaded if it is.
-    if (strcmp (plugin_name, a68_basename (plugin_name)) == 0) {
-      ASSERT (a68_bufprt (plugin_name, SNPRINTF_SIZE, "./%s", FILE_PLUGIN_NAME (&A68_JOB)) >= 0);
+    if (strcmp (plugin_name, a68g_basename (plugin_name)) == 0) {
+      ASSERT (a68g_bufprt (plugin_name, SNPRINTF_SIZE, "./%s", FILE_PLUGIN_NAME (&A68_JOB)) >= 0);
     }
 // Check whether we are doing something rash.
     ret = stat (FILE_SOURCE_NAME (&A68_JOB), &srcstat);
@@ -122,8 +122,8 @@ void plugin_driver_genie (void)
       ABEND (ST_MTIME (&srcstat) > ST_MTIME (&objstat), "plugin outdates source", "cannot RERUN");
     }
 // First load a68g itself so compiler code can resolve a68g symbols.
-    a68_plugin = dlopen (NULL, RTLD_NOW | RTLD_GLOBAL);
-    ABEND (a68_plugin == NULL, ERROR_CANNOT_OPEN_PLUGIN, dlerror ());
+    a68g_plugin = dlopen (NULL, RTLD_NOW | RTLD_GLOBAL);
+    ABEND (a68g_plugin == NULL, ERROR_CANNOT_OPEN_PLUGIN, dlerror ());
 // Then load compiler code.
     compile_plugin = dlopen (plugin_name, RTLD_NOW | RTLD_GLOBAL);
     ABEND (compile_plugin == NULL, ERROR_CANNOT_OPEN_PLUGIN, dlerror ());
@@ -145,36 +145,36 @@ void plugin_driver_clean (int emitted)
   announce_phase ("clean up intermediate files");
   if (OPTION_OPT_LEVEL (&A68_JOB) >= OPTIMISE_0 && OPTION_REGRESSION_TEST (&A68_JOB) && !OPTION_KEEP (&A68_JOB)) {
     if (emitted) {
-      a68_rm (FILE_OBJECT_NAME (&A68_JOB));
+      a68g_rm (FILE_OBJECT_NAME (&A68_JOB));
     }
-    a68_rm (FILE_PLUGIN_NAME (&A68_JOB));
+    a68g_rm (FILE_PLUGIN_NAME (&A68_JOB));
   }
   if (OPTION_RUN_SCRIPT (&A68_JOB) && !OPTION_KEEP (&A68_JOB)) {
     if (emitted) {
-      a68_rm (FILE_OBJECT_NAME (&A68_JOB));
+      a68g_rm (FILE_OBJECT_NAME (&A68_JOB));
     }
-    a68_rm (FILE_SOURCE_NAME (&A68_JOB));
-    a68_rm (FILE_PLUGIN_NAME (&A68_JOB));
+    a68g_rm (FILE_SOURCE_NAME (&A68_JOB));
+    a68g_rm (FILE_PLUGIN_NAME (&A68_JOB));
   } else if (OPTION_COMPILE (&A68_JOB)) {
     build_script ();
     if (!OPTION_KEEP (&A68_JOB)) {
       if (emitted) {
-        a68_rm (FILE_OBJECT_NAME (&A68_JOB));
+        a68g_rm (FILE_OBJECT_NAME (&A68_JOB));
       }
-      a68_rm (FILE_PLUGIN_NAME (&A68_JOB));
+      a68g_rm (FILE_PLUGIN_NAME (&A68_JOB));
     }
   } else if (OPTION_OPT_LEVEL (&A68_JOB) == OPTIMISE_0 && !OPTION_KEEP (&A68_JOB)) {
     if (emitted) {
-      a68_rm (FILE_OBJECT_NAME (&A68_JOB));
+      a68g_rm (FILE_OBJECT_NAME (&A68_JOB));
     }
-    a68_rm (FILE_PLUGIN_NAME (&A68_JOB));
+    a68g_rm (FILE_PLUGIN_NAME (&A68_JOB));
   } else if (OPTION_OPT_LEVEL (&A68_JOB) > OPTIMISE_0 && !OPTION_KEEP (&A68_JOB)) {
     if (emitted) {
-      a68_rm (FILE_OBJECT_NAME (&A68_JOB));
+      a68g_rm (FILE_OBJECT_NAME (&A68_JOB));
     }
   } else if (OPTION_RERUN (&A68_JOB) && !OPTION_KEEP (&A68_JOB)) {
     if (emitted) {
-      a68_rm (FILE_OBJECT_NAME (&A68_JOB));
+      a68g_rm (FILE_OBJECT_NAME (&A68_JOB));
     }
   }
 #else
