@@ -41,8 +41,8 @@ TRANSLATION monadics_nocheck[] = {
   {genie_abs_real, "fabs"},
   {genie_sign_int, "SIGN"},
   {genie_sign_real, "SIGN"},
-  {genie_entier_real, "a68_entier"},
-  {genie_round_real, "a68_round"},
+  {genie_entier_real, "a68g_entier"},
+  {genie_round_real, "a68g_round"},
   {genie_not_bool, "!"},
   {genie_abs_bool, "(int) "},
   {genie_abs_bits, "(INT_T) "},
@@ -50,12 +50,12 @@ TRANSLATION monadics_nocheck[] = {
   {genie_not_bits, "~"},
   {genie_abs_char, "TO_UCHAR"},
   {genie_repr_char, ""},
-  {genie_re_complex, "a68_re_complex"},
-  {genie_im_complex, "a68_im_complex"},
-  {genie_minus_complex, "a68_min_realus_complex"},
-  {genie_abs_complex, "a68_abs_real_complex"},
-  {genie_arg_complex, "a68_arg_complex"},
-  {genie_conj_complex, "a68_conj_complex"},
+  {genie_re_complex, "a68g_re_complex"},
+  {genie_im_complex, "a68g_im_complex"},
+  {genie_minus_complex, "a68g_min_realus_complex"},
+  {genie_abs_complex, "a68g_abs_real_complex"},
+  {genie_arg_complex, "a68g_arg_complex"},
+  {genie_conj_complex, "a68g_conj_complex"},
   {genie_idle, ""},
   {NO_GPROC, NO_TEXT}
 };
@@ -74,12 +74,12 @@ TRANSLATION monadics_check[] = {
   {genie_not_bits, "~"},
   {genie_abs_char, "TO_UCHAR"},
   {genie_repr_char, ""},
-  {genie_re_complex, "a68_re_complex"},
-  {genie_im_complex, "a68_im_complex"},
-  {genie_minus_complex, "a68_min_realus_complex"},
-  {genie_abs_complex, "a68_abs_real_complex"},
-  {genie_arg_complex, "a68_arg_complex"},
-  {genie_conj_complex, "a68_conj_complex"},
+  {genie_re_complex, "a68g_re_complex"},
+  {genie_im_complex, "a68g_im_complex"},
+  {genie_minus_complex, "a68g_min_realus_complex"},
+  {genie_abs_complex, "a68g_abs_real_complex"},
+  {genie_arg_complex, "a68g_arg_complex"},
+  {genie_conj_complex, "a68g_conj_complex"},
   {genie_idle, ""},
   {NO_GPROC, NO_TEXT}
 };
@@ -89,34 +89,34 @@ TRANSLATION dyadics_nocheck[] = {
   {genie_sub_int, "-"},
   {genie_mul_int, "*"},
   {genie_over_int, "/"},
-  {genie_mod_int, "a68_mod_int"},
-  {genie_div_int, "a68_div_int"},
+  {genie_mod_int, "a68g_mod_int"},
+  {genie_div_int, "a68g_div_int"},
   {genie_eq_int, "=="},
   {genie_ne_int, "!="},
   {genie_lt_int, "<"},
   {genie_gt_int, ">"},
   {genie_le_int, "<="},
   {genie_ge_int, ">="},
-  {genie_plusab_int, "a68_plusab_int"},
-  {genie_minusab_int, "a68_min_realusab_int"},
-  {genie_timesab_int, "a68_timesab_int"},
-  {genie_overab_int, "a68_overab_int"},
+  {genie_plusab_int, "a68g_plusab_int"},
+  {genie_minusab_int, "a68g_min_realusab_int"},
+  {genie_timesab_int, "a68g_timesab_int"},
+  {genie_overab_int, "a68g_overab_int"},
   {genie_add_real, "+"},
   {genie_sub_real, "-"},
   {genie_mul_real, "*"},
   {genie_div_real, "/"},
-  {genie_pow_real, "a68_x_up_y"},
-  {genie_pow_real_int, "a68_x_up_n_real"},
+  {genie_pow_real, "a68g_x_up_y"},
+  {genie_pow_real_int, "a68g_x_up_n_real"},
   {genie_eq_real, "=="},
   {genie_ne_real, "!="},
   {genie_lt_real, "<"},
   {genie_gt_real, ">"},
   {genie_le_real, "<="},
   {genie_ge_real, ">="},
-  {genie_plusab_real, "a68_plusab_real"},
-  {genie_minusab_real, "a68_min_realusab_real"},
-  {genie_timesab_real, "a68_timesab_real"},
-  {genie_divab_real, "a68_divab_real"},
+  {genie_plusab_real, "a68g_plusab_real"},
+  {genie_minusab_real, "a68g_min_realusab_real"},
+  {genie_timesab_real, "a68g_timesab_real"},
+  {genie_divab_real, "a68g_divab_real"},
   {genie_eq_char, "=="},
   {genie_ne_char, "!="},
   {genie_lt_char, "<"},
@@ -133,32 +133,32 @@ TRANSLATION dyadics_nocheck[] = {
   {genie_ne_bits, "!="},
   {genie_shl_bits, "<<"},
   {genie_shr_bits, ">>"},
-  {genie_i_complex, "a68_i_complex"},
-  {genie_i_int_complex, "a68_i_complex"},
-  {genie_abs_complex, "a68_abs_real_complex"},
-  {genie_arg_complex, "a68_arg_complex"},
-  {genie_add_complex, "a68_add_complex"},
-  {genie_sub_complex, "a68_sub_complex"},
-  {genie_mul_complex, "a68_mul_complex"},
-  {genie_div_complex, "a68_div_complex"},
-  {genie_eq_complex, "a68_eq_complex"},
-  {genie_ne_complex, "a68_ne_complex"},
+  {genie_i_complex, "a68g_i_complex"},
+  {genie_i_int_complex, "a68g_i_complex"},
+  {genie_abs_complex, "a68g_abs_real_complex"},
+  {genie_arg_complex, "a68g_arg_complex"},
+  {genie_add_complex, "a68g_add_complex"},
+  {genie_sub_complex, "a68g_sub_complex"},
+  {genie_mul_complex, "a68g_mul_complex"},
+  {genie_div_complex, "a68g_div_complex"},
+  {genie_eq_complex, "a68g_eq_complex"},
+  {genie_ne_complex, "a68g_ne_complex"},
   {NO_GPROC, NO_TEXT}
 };
 
 TRANSLATION dyadics_check[] = {
-  {genie_add_int, "a68_add_int"},
-  {genie_sub_int, "a68_sub_int"},
-  {genie_mul_int, "a68_mul_int"},
-  {genie_over_int, "a68_over_int"},
-  {genie_mod_int, "a68_mod_int"},
-  {genie_div_int, "a68_div_int"},
+  {genie_add_int, "a68g_add_int"},
+  {genie_sub_int, "a68g_sub_int"},
+  {genie_mul_int, "a68g_mul_int"},
+  {genie_over_int, "a68g_over_int"},
+  {genie_mod_int, "a68g_mod_int"},
+  {genie_div_int, "a68g_div_int"},
   {genie_add_real, "+"},
   {genie_sub_real, "-"},
   {genie_mul_real, "*"},
   {genie_div_real, "/"},
-  {genie_pow_real, "a68_x_up_y"},
-  {genie_pow_real_int, "a68_x_up_n_real"},
+  {genie_pow_real, "a68g_x_up_y"},
+  {genie_pow_real_int, "a68g_x_up_n_real"},
   {genie_eq_int, "=="},
   {genie_ne_int, "!="},
   {genie_lt_int, "<"},
@@ -185,23 +185,23 @@ TRANSLATION dyadics_check[] = {
   {genie_or_bits, "|"},
   {genie_eq_bits, "=="},
   {genie_ne_bits, "!="},
-  {genie_i_complex, "a68_i_complex"},
-  {genie_i_int_complex, "a68_i_complex"},
-  {genie_abs_complex, "a68_abs_real_complex"},
-  {genie_arg_complex, "a68_arg_complex"},
-  {genie_add_complex, "a68_add_complex"},
-  {genie_sub_complex, "a68_sub_complex"},
-  {genie_mul_complex, "a68_mul_complex"},
-  {genie_div_complex, "a68_div_complex"},
-  {genie_eq_complex, "a68_eq_complex"},
-  {genie_ne_complex, "a68_ne_complex"},
+  {genie_i_complex, "a68g_i_complex"},
+  {genie_i_int_complex, "a68g_i_complex"},
+  {genie_abs_complex, "a68g_abs_real_complex"},
+  {genie_arg_complex, "a68g_arg_complex"},
+  {genie_add_complex, "a68g_add_complex"},
+  {genie_sub_complex, "a68g_sub_complex"},
+  {genie_mul_complex, "a68g_mul_complex"},
+  {genie_div_complex, "a68g_div_complex"},
+  {genie_eq_complex, "a68g_eq_complex"},
+  {genie_ne_complex, "a68g_ne_complex"},
   {NO_GPROC, NO_TEXT}
 };
 
 TRANSLATION functions_nocheck[] = {
   {genie_sqrt_real, "sqrt"},
   {genie_curt_real, "cbrt"},
-  {genie_exp_real, "a68_exp_real"},
+  {genie_exp_real, "a68g_exp_real"},
   {genie_ln_real, "log"},
   {genie_log_real, "log10"},
   {genie_sin_real, "sin"},
@@ -217,39 +217,39 @@ TRANSLATION functions_nocheck[] = {
   {genie_erf_real, "erf"},
   {genie_gamma_real, "tgamma"},
   {genie_ln_gamma_real, "lgamma"},
-  {genie_sindg_real, "a68_sindg_real"},
-  {genie_cosdg_real, "a68_cosdg_real"},
-  {genie_tandg_real, "a68_tandg_real"},
-  {genie_asindg_real, "a68_asindg_real"},
-  {genie_acosdg_real, "a68_acosdg_real"},
-  {genie_atandg_real, "a68_atandg_real"},
-  {genie_sqrt_complex, "a68_sqrt_complex"},
-  {genie_exp_complex, "a68_exp_real_complex"},
-  {genie_ln_complex, "a68_ln_complex"},
-  {genie_sin_complex, "a68_sin_complex"},
-  {genie_cos_complex, "a68_cos_complex"},
-  {genie_tan_complex, "a68_tan_complex"},
-  {genie_asin_complex, "a68_asin_complex"},
-  {genie_acos_complex, "a68_acos_complex"},
-  {genie_atan_complex, "a68_atan_complex"},
-  {genie_sinh_complex, "a68_sinh_complex"},
-  {genie_cosh_complex, "a68_cosh_complex"},
-  {genie_tanh_complex, "a68_tanh_complex"},
-  {genie_asinh_complex, "a68_asinh_real_complex"},
-  {genie_acosh_complex, "a68_acosh_real_complex"},
-  {genie_atanh_complex, "a68_atanh_real_complex"},
-  {genie_asinh_real, "a68_asinh_real"},
-  {genie_acosh_real, "a68_acosh_real"},
-  {genie_atanh_real, "a68_atanh_real"},
-  {genie_inverfc_real, "a68_inverfc_real"},
-  {genie_inverf_real, "a68_inverf_real"},
+  {genie_sindg_real, "a68g_sindg_real"},
+  {genie_cosdg_real, "a68g_cosdg_real"},
+  {genie_tandg_real, "a68g_tandg_real"},
+  {genie_asindg_real, "a68g_asindg_real"},
+  {genie_acosdg_real, "a68g_acosdg_real"},
+  {genie_atandg_real, "a68g_atandg_real"},
+  {genie_sqrt_complex, "a68g_sqrt_complex"},
+  {genie_exp_complex, "a68g_exp_real_complex"},
+  {genie_ln_complex, "a68g_ln_complex"},
+  {genie_sin_complex, "a68g_sin_complex"},
+  {genie_cos_complex, "a68g_cos_complex"},
+  {genie_tan_complex, "a68g_tan_complex"},
+  {genie_asin_complex, "a68g_asin_complex"},
+  {genie_acos_complex, "a68g_acos_complex"},
+  {genie_atan_complex, "a68g_atan_complex"},
+  {genie_sinh_complex, "a68g_sinh_complex"},
+  {genie_cosh_complex, "a68g_cosh_complex"},
+  {genie_tanh_complex, "a68g_tanh_complex"},
+  {genie_asinh_complex, "a68g_asinh_real_complex"},
+  {genie_acosh_complex, "a68g_acosh_real_complex"},
+  {genie_atanh_complex, "a68g_atanh_real_complex"},
+  {genie_asinh_real, "a68g_asinh_real"},
+  {genie_acosh_real, "a68g_acosh_real"},
+  {genie_atanh_real, "a68g_atanh_real"},
+  {genie_inverfc_real, "a68g_inverfc_real"},
+  {genie_inverf_real, "a68g_inverf_real"},
   {NO_GPROC, NO_TEXT}
 };
 
 TRANSLATION functions_check[] = {
   {genie_sqrt_real, "sqrt"},
   {genie_curt_real, "cbrt"},
-  {genie_exp_real, "a68_exp_real"},
+  {genie_exp_real, "a68g_exp_real"},
   {genie_ln_real, "log"},
   {genie_log_real, "log10"},
   {genie_sin_real, "sin"},
@@ -265,17 +265,17 @@ TRANSLATION functions_check[] = {
   {genie_erf_real, "erf"},
   {genie_gamma_real, "tgamma"},
   {genie_ln_gamma_real, "lgamma"},
-  {genie_sindg_real, "a68_sindg_real"},
-  {genie_cosdg_real, "a68_cosdg_real"},
-  {genie_tandg_real, "a68_tandg_real"},
-  {genie_asindg_real, "a68_asindg_real"},
-  {genie_acosdg_real, "a68_acosdg_real"},
-  {genie_atandg_real, "a68_atandg_real"},
-  {genie_asinh_real, "a68_asinh_real"},
-  {genie_acosh_real, "a68_acosh_real"},
-  {genie_atanh_real, "a68_atanh_real"},
-  {genie_inverfc_real, "a68_inverfc_real"},
-  {genie_inverf_real, "a68_inverf_real"},
+  {genie_sindg_real, "a68g_sindg_real"},
+  {genie_cosdg_real, "a68g_cosdg_real"},
+  {genie_tandg_real, "a68g_tandg_real"},
+  {genie_asindg_real, "a68g_asindg_real"},
+  {genie_acosdg_real, "a68g_acosdg_real"},
+  {genie_atandg_real, "a68g_atandg_real"},
+  {genie_asinh_real, "a68g_asinh_real"},
+  {genie_acosh_real, "a68g_acosh_real"},
+  {genie_atanh_real, "a68g_atanh_real"},
+  {genie_inverfc_real, "a68g_inverfc_real"},
+  {genie_inverf_real, "a68g_inverf_real"},
   {NO_GPROC, NO_TEXT}
 };
 
