@@ -398,7 +398,7 @@ void genie_bytespack (NODE_T * p)
   A68_REF z;
   POP_REF (p, &z);
   CHECK_REF (p, z, M_STRING);
-  PRELUDE_ERROR (a68_string_size (p, z) > A68_BYTES_WIDTH, p, ERROR_OUT_OF_BOUNDS, M_STRING);
+  PRELUDE_ERROR (a68g_string_size (p, z) > A68_BYTES_WIDTH, p, ERROR_OUT_OF_BOUNDS, M_STRING);
   A68_BYTES b;
   STATUS (&b) = INIT_MASK;
   ASSERT (a_to_c_string (p, VALUE (&b), z) != NO_TEXT);
@@ -412,7 +412,7 @@ void genie_add_bytes (NODE_T * p)
   A68_BYTES *i, *j;
   POP_OPERAND_ADDRESSES (p, i, j, A68_BYTES);
   PRELUDE_ERROR (((int) strlen (VALUE (i)) + (int) strlen (VALUE (j))) > A68_BYTES_WIDTH, p, ERROR_OUT_OF_BOUNDS, M_BYTES);
-  a68_bufcat (VALUE (i), VALUE (j), A68_BYTES_WIDTH);
+  a68g_bufcat (VALUE (i), VALUE (j), A68_BYTES_WIDTH);
 }
 
 //! @brief OP +:= = (REF BYTES, BYTES) REF BYTES
@@ -435,9 +435,9 @@ void genie_plusto_bytes (NODE_T * p)
   POP_OBJECT (p, &i, A68_BYTES);
   PRELUDE_ERROR (((int) strlen (VALUE (address)) + (int) strlen (VALUE (&i))) > A68_BYTES_WIDTH, p, ERROR_OUT_OF_BOUNDS, M_BYTES);
   A68_BYTES j;
-  a68_bufcpy (VALUE (&j), VALUE (&i), A68_BYTES_WIDTH);
-  a68_bufcat (VALUE (&j), VALUE (address), A68_BYTES_WIDTH);
-  a68_bufcpy (VALUE (address), VALUE (&j), A68_BYTES_WIDTH);
+  a68g_bufcpy (VALUE (&j), VALUE (&i), A68_BYTES_WIDTH);
+  a68g_bufcat (VALUE (&j), VALUE (address), A68_BYTES_WIDTH);
+  a68g_bufcpy (VALUE (address), VALUE (&j), A68_BYTES_WIDTH);
   PUSH_REF (p, z);
 }
 
@@ -472,7 +472,7 @@ A68_CMP_BYTES (genie_ge_bytes, >=);
 void genie_leng_bytes (NODE_T * p)
 {
   A68_LONG_BYTES a;
-  a68_bufset (VALUE (&a), 0, sizeof (VALUE (&a)));
+  a68g_bufset (VALUE (&a), 0, sizeof (VALUE (&a)));
   POP_OBJECT (p, (A68_BYTES *) &a, A68_BYTES);
   PUSH_LONG_BYTES (p, VALUE (&a));
 }
@@ -510,7 +510,7 @@ void genie_long_bytespack (NODE_T * p)
   A68_REF z;
   POP_REF (p, &z);
   CHECK_REF (p, z, M_STRING);
-  PRELUDE_ERROR (a68_string_size (p, z) > A68_LONG_BYTES_WIDTH, p, ERROR_OUT_OF_BOUNDS, M_STRING);
+  PRELUDE_ERROR (a68g_string_size (p, z) > A68_LONG_BYTES_WIDTH, p, ERROR_OUT_OF_BOUNDS, M_STRING);
   A68_LONG_BYTES b;
   STATUS (&b) = INIT_MASK;
   ASSERT (a_to_c_string (p, VALUE (&b), z) != NO_TEXT);
@@ -524,7 +524,7 @@ void genie_add_long_bytes (NODE_T * p)
   A68_LONG_BYTES *i, *j;
   POP_OPERAND_ADDRESSES (p, i, j, A68_LONG_BYTES);
   PRELUDE_ERROR (((int) strlen (VALUE (i)) + (int) strlen (VALUE (j))) > A68_LONG_BYTES_WIDTH, p, ERROR_OUT_OF_BOUNDS, M_LONG_BYTES);
-  a68_bufcat (VALUE (i), VALUE (j), A68_LONG_BYTES_WIDTH);
+  a68g_bufcat (VALUE (i), VALUE (j), A68_LONG_BYTES_WIDTH);
 }
 
 //! @brief OP +:= = (REF LONG BYTES, LONG BYTES) REF LONG BYTES
@@ -547,9 +547,9 @@ void genie_plusto_long_bytes (NODE_T * p)
   POP_OBJECT (p, &i, A68_LONG_BYTES);
   PRELUDE_ERROR (((int) strlen (VALUE (address)) + (int) strlen (VALUE (&i))) > A68_LONG_BYTES_WIDTH, p, ERROR_OUT_OF_BOUNDS, M_LONG_BYTES);
   A68_LONG_BYTES j;
-  a68_bufcpy (VALUE (&j), VALUE (&i), A68_LONG_BYTES_WIDTH);
-  a68_bufcat (VALUE (&j), VALUE (address), A68_LONG_BYTES_WIDTH);
-  a68_bufcpy (VALUE (address), VALUE (&j), A68_LONG_BYTES_WIDTH);
+  a68g_bufcpy (VALUE (&j), VALUE (&i), A68_LONG_BYTES_WIDTH);
+  a68g_bufcat (VALUE (&j), VALUE (address), A68_LONG_BYTES_WIDTH);
+  a68g_bufcpy (VALUE (address), VALUE (&j), A68_LONG_BYTES_WIDTH);
   PUSH_REF (p, z);
 }
 
