@@ -233,7 +233,7 @@ NODE_T *scan_format_pattern (NODE_T * p, A68_REF ref_file)
           COUNT (collitem) = 0; // This insertion is now done
         } else if (IS (picture, REPLICATOR) || IS (picture, COLLECTION)) {
           BOOL_T siga = A68_TRUE;
-          NODE_T *a68_select = NO_NODE;
+          NODE_T *a68g_select = NO_NODE;
           if (COUNT (collitem) == ITEM_NOT_USED) {
             if (IS (picture, REPLICATOR)) {
               COUNT (collitem) = get_replicator_value (SUB (p), A68_TRUE);
@@ -249,9 +249,9 @@ NODE_T *scan_format_pattern (NODE_T * p, A68_REF ref_file)
           while (siga) {
 // Get format item from collection. If collection is done, but repitition is not,
 // then re-initialise the collection and repeat.
-            a68_select = scan_format_pattern (NEXT_SUB (picture), ref_file);
-            if (a68_select != NO_NODE) {
-              return a68_select;
+            a68g_select = scan_format_pattern (NEXT_SUB (picture), ref_file);
+            if (a68g_select != NO_NODE) {
+              return a68g_select;
             } else {
               COUNT (collitem)--;
               siga = (BOOL_T) (COUNT (collitem) > 0);
@@ -614,7 +614,7 @@ void write_c_pattern (NODE_T * p, MOID_T * mode, BYTE_T * item, A68_REF ref_file
     if (att == GENERAL_C_PATTERN) {
       char *expch = strchr (str, EXPONENT_CHAR);
       if (expch != NO_TEXT) {
-        expval = (int) strtol (&(expch[1]), NO_VAR, 10);
+        expval = (int) strtol (&(expch[1]), NO_REF, 10);
       }
     }
     if ((att == FIXED_C_PATTERN) || (att == GENERAL_C_PATTERN && (expval > -4 && expval <= after))) {
@@ -856,7 +856,7 @@ void read_c_pattern (NODE_T * p, MOID_T * mode, BYTE_T * item, A68_REF ref_file)
       if (width == 0) {
         A68_FILE *file = FILE_DEREF (&ref_file);
         int ch;
-        ASSERT (a68_bufprt (str, (size_t) TRANSPUT_BUFFER_SIZE, "%dr", radix) >= 0);
+        ASSERT (a68g_bufprt (str, (size_t) TRANSPUT_BUFFER_SIZE, "%dr", radix) >= 0);
         set_transput_buffer_index (INPUT_BUFFER, (int) strlen (str));
         ch = char_scanner (file);
         while (ch != EOF_CHAR && (IS_SPACE (ch) || IS_NL_FF (ch))) {
@@ -872,7 +872,7 @@ void read_c_pattern (NODE_T * p, MOID_T * mode, BYTE_T * item, A68_REF ref_file)
         }
         unchar_scanner (p, file, (char) ch);
       } else {
-        ASSERT (a68_bufprt (str, (size_t) TRANSPUT_BUFFER_SIZE, "%dr", radix) >= 0);
+        ASSERT (a68g_bufprt (str, (size_t) TRANSPUT_BUFFER_SIZE, "%dr", radix) >= 0);
         set_transput_buffer_index (INPUT_BUFFER, (int) strlen (str));
         scan_n_chars (p, width, mode, ref_file);
       }
@@ -1788,8 +1788,8 @@ void genie_write_standard_format (NODE_T * p, MOID_T * mode, BYTE_T * item, A68_
       BOOL_T done = A68_FALSE;
       initialise_internal_index (tup, DIM (arr));
       while (!done) {
-        ADDR_T a68_index = calculate_internal_index (tup, DIM (arr));
-        ADDR_T elem_addr = ROW_ELEMENT (arr, a68_index);
+        ADDR_T a68g_index = calculate_internal_index (tup, DIM (arr));
+        ADDR_T elem_addr = ROW_ELEMENT (arr, a68g_index);
         BYTE_T *elem = &base_addr[elem_addr];
         genie_check_initialisation (p, elem, SUB (deflexed));
         genie_write_standard_format (p, SUB (deflexed), elem, ref_file, formats);
@@ -2281,7 +2281,7 @@ void read_bits_pattern (NODE_T * p, MOID_T * m, BYTE_T * item, A68_REF ref_file)
     exit_genie (p, A68_RUNTIME_ERROR);
   }
   char *z = get_transput_buffer (INPUT_BUFFER);
-  ASSERT (a68_bufprt (z, (size_t) TRANSPUT_BUFFER_SIZE, "%dr", radix) >= 0);
+  ASSERT (a68g_bufprt (z, (size_t) TRANSPUT_BUFFER_SIZE, "%dr", radix) >= 0);
   set_transput_buffer_index (INPUT_BUFFER, (int) strlen (z));
   read_integral_mould (NEXT_SUB (p), m, ref_file);
   genie_string_to_value (p, m, item, ref_file);
@@ -2479,8 +2479,8 @@ void genie_read_standard_format (NODE_T * p, MOID_T * mode, BYTE_T * item, A68_R
       BOOL_T done = A68_FALSE;
       initialise_internal_index (tup, DIM (arr));
       while (!done) {
-        ADDR_T a68_index = calculate_internal_index (tup, DIM (arr));
-        ADDR_T elem_addr = ROW_ELEMENT (arr, a68_index);
+        ADDR_T a68g_index = calculate_internal_index (tup, DIM (arr));
+        ADDR_T elem_addr = ROW_ELEMENT (arr, a68g_index);
         BYTE_T *elem = &base_addr[elem_addr];
         genie_read_standard_format (p, SUB (deflexed), elem, ref_file, formats);
         done = increment_internal_index (tup, DIM (arr));
