@@ -598,7 +598,7 @@ void genie_generator_field (NODE_T * p, BYTE_T ** faddr, NODE_T ** decl, ADDR_T
       MOID_T *fmoid = MOID (*decl);
       if (HAS_ROWS (fmoid) && ISNT (fmoid, UNION_SYMBOL)) {
         ADDR_T pop_sp = *cur_sp;
-        genie_generator_stowed (*decl, *faddr, NO_VAR, cur_sp);
+        genie_generator_stowed (*decl, *faddr, NO_REF, cur_sp);
         *top_sp = *cur_sp;
         *cur_sp = pop_sp;
       }
@@ -689,7 +689,7 @@ void genie_generator_stowed (NODE_T * p, BYTE_T * addr, NODE_T ** decl, ADDR_T *
       ARRAY (arr) = heap_generator (p, rmod, esiz);
       BYTE_T *elem = ADDRESS (&(ARRAY (arr)));
       if (alloc_sub) {
-        genie_generator_stowed (NEXT (p), &(elem[0]), NO_VAR, cur_sp);
+        genie_generator_stowed (NEXT (p), &(elem[0]), NO_REF, cur_sp);
         top_sp = *cur_sp;
       } else if (alloc_str) {
         *(A68_REF *) elem = empty_string (p);
@@ -702,7 +702,7 @@ void genie_generator_stowed (NODE_T * p, BYTE_T * addr, NODE_T ** decl, ADDR_T *
       for (int k = 0; k < rsiz; k++) {
         if (alloc_sub) {
           (*cur_sp) = pop_sp;
-          genie_generator_stowed (NEXT (p), &(elem[k * esiz]), NO_VAR, cur_sp);
+          genie_generator_stowed (NEXT (p), &(elem[k * esiz]), NO_REF, cur_sp);
           top_sp = *cur_sp;
         } else if (alloc_str) {
           *(A68_REF *) (&(elem[k * esiz])) = empty_string (p);
@@ -746,7 +746,7 @@ void genie_generator_internal (NODE_T * p, MOID_T * ref_mode, TAG_T * tag, LEAP_
   }
   if (HAS_ROWS (mode)) {
     ADDR_T cur_sp = sp;
-    genie_generator_stowed (p, ADDRESS (&name), NO_VAR, &cur_sp);
+    genie_generator_stowed (p, ADDRESS (&name), NO_REF, &cur_sp);
   }
   PUSH_REF (p, name);
 }
@@ -776,7 +776,7 @@ PROP_T genie_generator (NODE_T * p)
 
 void discard_heap (void)
 {
-  a68_free (A68_HEAP);
+  a68g_free (A68_HEAP);
   A68 (fixed_heap_pointer) = 0;
   A68 (temp_heap_pointer) = 0;
 }
