@@ -50,7 +50,7 @@ void restore_stacks (pthread_t);
   int size = (si);\
   if (size > 0) {\
     if (!((s != NULL) && (BYTES (s) > 0) && (size <= BYTES (s)))) {\
-      a68_free (SWAP (s));\
+      a68g_free (SWAP (s));\
       SWAP (s) = (BYTE_T *) get_heap_space ((size_t) size);\
       ABEND (SWAP (s) == NULL, ERROR_OUT_OF_CORE, __func__);\
     }\
@@ -60,7 +60,7 @@ void restore_stacks (pthread_t);
   } else {\
     START (s) = start;\
     BYTES (s) = 0;\
-    a68_free (SWAP (s));\
+    a68g_free (SWAP (s));\
     SWAP (s) = NO_BYTE;\
   }}
 
@@ -251,7 +251,7 @@ void start_parallel_units (NODE_T * p, pthread_t parent)
 // Set up a thread for this unit.
       if (A68_PAR (context_index) >= THREAD_MAX) {
         static BUFFER msg;
-        a68_bufprt (msg, SNPRINTF_SIZE, "platform supports %d parallel units", THREAD_MAX);
+        a68g_bufprt (msg, SNPRINTF_SIZE, "platform supports %d parallel units", THREAD_MAX);
         diagnostic (A68_RUNTIME_ERROR, p, ERROR_PARALLEL_OVERFLOW, msg);
         exit_genie (p, A68_RUNTIME_ERROR);
       }
@@ -401,7 +401,7 @@ PROP_T genie_parallel (NODE_T * p)
           exit_genie (p, A68_RUNTIME_ERROR);
         }
       }
-      a68_free (SWAP (&STACK (&(A68_PAR (context)[j]))));
+      a68g_free (SWAP (&STACK (&(A68_PAR (context)[j]))));
       SWAP (&STACK (&(A68_PAR (context)[j]))) = NO_BYTE;
     }
 // Now every thread should have ended.
@@ -496,7 +496,7 @@ void genie_down_sema (NODE_T * p)
         }
         UNLOCK_THREAD;
 // Waiting a bit relaxes overhead.
-        int ret = a68_usleep (10);
+        int ret = a68g_usleep (10);
         ASSERT (ret == 0 || errno == EINTR);
         LOCK_THREAD;
 // Garbage may be collected, so recalculate 'k'.
