@@ -82,7 +82,7 @@ void genie_make_device (NODE_T * p)
     exit_genie (p, A68_RUNTIME_ERROR);
   }
 // Fill in page_size.
-  int size = a68_string_size (p, ref_page);
+  int size = a68g_string_size (p, ref_page);
   if (INITIALISED (&(A68_PAGE_SIZE (&DEVICE (file)))) && !IS_NIL (A68_PAGE_SIZE (&DEVICE (file)))) {
     UNBLOCK_GC_HANDLE (&A68_PAGE_SIZE (&DEVICE (file)));
   }
@@ -90,7 +90,7 @@ void genie_make_device (NODE_T * p)
   BLOCK_GC_HANDLE (&A68_PAGE_SIZE (&DEVICE (file)));
   ASSERT (a_to_c_string (p, DEREF (char, &A68_PAGE_SIZE (&DEVICE (file))), ref_page) != NO_TEXT);
 // Fill in device.
-  size = a68_string_size (p, ref_device);
+  size = a68g_string_size (p, ref_device);
   if (INITIALISED (&(DEVICE (&DEVICE (file)))) && !IS_NIL (DEVICE (&DEVICE (file)))) {
     UNBLOCK_GC_HANDLE (&DEVICE (&DEVICE (file)));
   }
@@ -202,7 +202,7 @@ plPlotter *set_up_device (NODE_T * p, A68_FILE * f)
       diagnostic (A68_RUNTIME_ERROR, p, ERROR_DEVICE_CANNOT_ALLOCATE);
       exit_genie (p, A68_RUNTIME_ERROR);
     }
-    ASSERT (a68_bufprt (size, SNPRINTF_SIZE, "%dx%d", WINDOW_X_SIZE (&DEVICE (f)), WINDOW_Y_SIZE (&DEVICE (f))) >= 0);
+    ASSERT (a68g_bufprt (size, SNPRINTF_SIZE, "%dx%d", WINDOW_X_SIZE (&DEVICE (f)), WINDOW_Y_SIZE (&DEVICE (f))) >= 0);
     (void) pl_setplparam (PLOTTER_PARAMS (&DEVICE (f)), "BITMAPSIZE", size);
     (void) pl_setplparam (PLOTTER_PARAMS (&DEVICE (f)), "BG_COLOR", (void *) "black");
     (void) pl_setplparam (PLOTTER_PARAMS (&DEVICE (f)), "VANISH_ON_DELETE", (void *) "no");
@@ -264,7 +264,7 @@ plPlotter *set_up_device (NODE_T * p, A68_FILE * f)
       diagnostic (A68_RUNTIME_ERROR, p, ERROR_DEVICE_CANNOT_ALLOCATE);
       exit_genie (p, A68_RUNTIME_ERROR);
     }
-    ASSERT (a68_bufprt (size, SNPRINTF_SIZE, "%dx%d", WINDOW_X_SIZE (&DEVICE (f)), WINDOW_Y_SIZE (&DEVICE (f))) >= 0);
+    ASSERT (a68g_bufprt (size, SNPRINTF_SIZE, "%dx%d", WINDOW_X_SIZE (&DEVICE (f)), WINDOW_Y_SIZE (&DEVICE (f))) >= 0);
     (void) pl_setplparam (PLOTTER_PARAMS (&DEVICE (f)), "BITMAPSIZE", size);
     (void) pl_setplparam (PLOTTER_PARAMS (&DEVICE (f)), "BG_COLOR", (void *) "black");
     (void) pl_setplparam (PLOTTER_PARAMS (&DEVICE (f)), "GIF_ANIMATION", (void *) "no");
@@ -318,7 +318,7 @@ plPlotter *set_up_device (NODE_T * p, A68_FILE * f)
       DRAW_MOOD (f) = A68_TRUE;
     }
 // Set up plotter.
-    ASSERT (a68_bufprt (size, SNPRINTF_SIZE, "%dx%d", WINDOW_X_SIZE (&DEVICE (f)), WINDOW_Y_SIZE (&DEVICE (f))) >= 0);
+    ASSERT (a68g_bufprt (size, SNPRINTF_SIZE, "%dx%d", WINDOW_X_SIZE (&DEVICE (f)), WINDOW_Y_SIZE (&DEVICE (f))) >= 0);
     PLOTTER_PARAMS (&DEVICE (f)) = pl_newplparams ();
     if (PLOTTER_PARAMS (&DEVICE (f)) == NULL) {
       diagnostic (A68_RUNTIME_ERROR, p, ERROR_DEVICE_CANNOT_ALLOCATE);
@@ -386,7 +386,7 @@ plPlotter *set_up_device (NODE_T * p, A68_FILE * f)
       diagnostic (A68_RUNTIME_ERROR, p, ERROR_DEVICE_CANNOT_ALLOCATE);
       exit_genie (p, A68_RUNTIME_ERROR);
     }
-    ASSERT (a68_bufprt (size, SNPRINTF_SIZE, "%dx%d", WINDOW_X_SIZE (&DEVICE (f)), WINDOW_Y_SIZE (&DEVICE (f))) >= 0);
+    ASSERT (a68g_bufprt (size, SNPRINTF_SIZE, "%dx%d", WINDOW_X_SIZE (&DEVICE (f)), WINDOW_Y_SIZE (&DEVICE (f))) >= 0);
     (void) pl_setplparam (PLOTTER_PARAMS (&DEVICE (f)), "BITMAPSIZE", size);
     (void) pl_setplparam (PLOTTER_PARAMS (&DEVICE (f)), "BG_COLOR", (void *) "black");
     (void) pl_setplparam (PLOTTER_PARAMS (&DEVICE (f)), "GIF_ANIMATION", (void *) "no");
@@ -573,7 +573,7 @@ void genie_draw_colour_name (NODE_T * p)
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
   A68_FILE *f = FILE_DEREF (&ref_file);
-  A68_REF ref_name = heap_generator (p, M_C_STRING, 1 + a68_string_size (p, ref_c));
+  A68_REF ref_name = heap_generator (p, M_C_STRING, 1 + a68g_string_size (p, ref_c));
   char *name = DEREF (char, &ref_name);
   ASSERT (a_to_c_string (p, name, ref_c) != NO_TEXT);
   int k;
@@ -602,7 +602,7 @@ void genie_draw_background_colour_name (NODE_T * p)
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
   A68_FILE *f = FILE_DEREF (&ref_file);
-  A68_REF ref_name = heap_generator (p, M_C_STRING, 1 + a68_string_size (p, ref_c));
+  A68_REF ref_name = heap_generator (p, M_C_STRING, 1 + a68g_string_size (p, ref_c));
   char *name = DEREF (char, &ref_name);
   ASSERT (a_to_c_string (p, name, ref_c) != NO_TEXT);
   int k;
@@ -630,7 +630,7 @@ void genie_draw_linestyle (NODE_T * p)
   CHECK_REF (p, ref_file, M_REF_FILE);
   A68_FILE *f = FILE_DEREF (&ref_file);
   plPlotter *plotter = set_up_device (p, f);
-  int size = a68_string_size (p, txt);
+  int size = a68g_string_size (p, txt);
   A68_REF z_ref = heap_generator (p, M_C_STRING, 1 + size);
   char *z = DEREF (char, &z_ref);
   ASSERT (a_to_c_string (p, z, txt) != NO_TEXT);
@@ -798,7 +798,7 @@ void genie_draw_text (NODE_T * p)
   CHECK_REF (p, ref_file, M_REF_FILE);
   A68_FILE *f = FILE_DEREF (&ref_file);
   plPlotter *plotter = set_up_device (p, f);
-  int size = a68_string_size (p, txt);
+  int size = a68g_string_size (p, txt);
   A68_REF z_ref = heap_generator (p, M_C_STRING, 1 + size);
   char *z = DEREF (char, &z_ref);
   ASSERT (a_to_c_string (p, z, txt) != NO_TEXT);
@@ -815,7 +815,7 @@ void genie_draw_fontname (NODE_T * p)
   CHECK_REF (p, ref_file, M_REF_FILE);
   A68_FILE *f = FILE_DEREF (&ref_file);
   plPlotter *plotter = set_up_device (p, f);
-  int size = a68_string_size (p, txt);
+  int size = a68g_string_size (p, txt);
   A68_REF z_ref = heap_generator (p, M_C_STRING, 1 + size);
   char *z = DEREF (char, &z_ref);
   ASSERT (a_to_c_string (p, z, txt) != NO_TEXT);
