@@ -97,7 +97,7 @@ void genie_pq_connectdb (NODE_T * p)
   STREAM (&DEVICE (file)) = NULL;
   set_default_event_procedures (file);
 // Establish a connection.
-  A68_REF ref_z = heap_generator (p, M_C_STRING, 1 + a68_string_size (p, conninfo));
+  A68_REF ref_z = heap_generator (p, M_C_STRING, 1 + a68g_string_size (p, conninfo));
   CONNECTION (file) = PQconnectdb (a_to_c_string (p, DEREF (char, &ref_z), conninfo));
   RESULT (file) = NO_PGRESULT;
   if (CONNECTION (file) == NO_PGCONN) {
@@ -170,7 +170,7 @@ void genie_pq_exec (NODE_T * p)
   if (RESULT (file) != NO_PGRESULT) {
     PQclear (RESULT (file));
   }
-  A68_REF ref_z = heap_generator (p, M_C_STRING, 1 + a68_string_size (p, query));
+  A68_REF ref_z = heap_generator (p, M_C_STRING, 1 + a68g_string_size (p, query));
   RESULT (file) = PQexec (CONNECTION (file), a_to_c_string (p, DEREF (char, &ref_z), query));
   if ((PQresultStatus (RESULT (file)) != PGRES_TUPLES_OK)
       && (PQresultStatus (RESULT (file)) != PGRES_COMMAND_OK)) {
@@ -194,7 +194,7 @@ void genie_pq_parameterstatus (NODE_T * p)
     PUSH_PRIMAL (p, -1, INT);
     return;
   }
-  A68_REF ref_z = heap_generator (p, M_C_STRING, 1 + a68_string_size (p, parameter));
+  A68_REF ref_z = heap_generator (p, M_C_STRING, 1 + a68g_string_size (p, parameter));
   if (!IS_NIL (STRING (file))) {
     *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, (char *) PQparameterStatus (CONNECTION (file), a_to_c_string (p, DEREF (char, &ref_z), parameter)), DEFAULT_WIDTH);
     PUSH_PRIMAL (p, 0, INT);
@@ -299,9 +299,9 @@ void genie_pq_nfields (NODE_T * p)
 
 void genie_pq_fname (NODE_T * p)
 {
-  A68_INT a68_index; A68_REF ref_file;
-  POP_OBJECT (p, &a68_index, A68_INT);
-  CHECK_INIT (p, INITIALISED (&a68_index), M_INT);
+  A68_INT a68g_index; A68_REF ref_file;
+  POP_OBJECT (p, &a68g_index, A68_INT);
+  CHECK_INIT (p, INITIALISED (&a68g_index), M_INT);
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
   A68_FILE *file = FILE_DEREF (&ref_file);
@@ -315,12 +315,12 @@ void genie_pq_fname (NODE_T * p)
     return;
   }
   int upb = (PQresultStatus (RESULT (file)) == PGRES_TUPLES_OK ? PQnfields (RESULT (file)) : 0);
-  if (VALUE (&a68_index) < 1 || VALUE (&a68_index) > upb) {
+  if (VALUE (&a68g_index) < 1 || VALUE (&a68g_index) > upb) {
     diagnostic (A68_RUNTIME_ERROR, p, ERROR_INDEX_OUT_OF_BOUNDS);
     exit_genie (p, A68_RUNTIME_ERROR);
   }
   if (!IS_NIL (STRING (file))) {
-    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQfname (RESULT (file), VALUE (&a68_index) - 1), DEFAULT_WIDTH);
+    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQfname (RESULT (file), VALUE (&a68g_index) - 1), DEFAULT_WIDTH);
     STRPOS (file) = 0;
   }
   PUSH_PRIMAL (p, 0, INT);
@@ -344,7 +344,7 @@ void genie_pq_fnumber (NODE_T * p)
     PUSH_PRIMAL (p, -2, INT);
     return;
   }
-  A68_REF ref_z = heap_generator (p, M_C_STRING, 1 + a68_string_size (p, name));
+  A68_REF ref_z = heap_generator (p, M_C_STRING, 1 + a68g_string_size (p, name));
   int k = PQfnumber (RESULT (file), a_to_c_string (p, DEREF (char, &ref_z), name));
   if (k == -1) {
     PUSH_PRIMAL (p, -3, INT);
@@ -357,9 +357,9 @@ void genie_pq_fnumber (NODE_T * p)
 
 void genie_pq_fformat (NODE_T * p)
 {
-  A68_INT a68_index; A68_REF ref_file;
-  POP_OBJECT (p, &a68_index, A68_INT);
-  CHECK_INIT (p, INITIALISED (&a68_index), M_INT);
+  A68_INT a68g_index; A68_REF ref_file;
+  POP_OBJECT (p, &a68g_index, A68_INT);
+  CHECK_INIT (p, INITIALISED (&a68g_index), M_INT);
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
   A68_FILE *file = FILE_DEREF (&ref_file);
@@ -373,11 +373,11 @@ void genie_pq_fformat (NODE_T * p)
     return;
   }
   int upb = (PQresultStatus (RESULT (file)) == PGRES_TUPLES_OK ? PQnfields (RESULT (file)) : 0);
-  if (VALUE (&a68_index) < 1 || VALUE (&a68_index) > upb) {
+  if (VALUE (&a68g_index) < 1 || VALUE (&a68g_index) > upb) {
     diagnostic (A68_RUNTIME_ERROR, p, ERROR_INDEX_OUT_OF_BOUNDS);
     exit_genie (p, A68_RUNTIME_ERROR);
   }
-  PUSH_PRIMAL (p, PQfformat (RESULT (file), VALUE (&a68_index) - 1), INT);
+  PUSH_PRIMAL (p, PQfformat (RESULT (file), VALUE (&a68g_index) - 1), INT);
 }
 
 //! @brief PROC pq getvalue (REF FILE, INT, INT) INT
@@ -526,13 +526,13 @@ void genie_pq_errormessage (NODE_T * p)
   if (!IS_NIL (STRING (file))) {
     BUFFER str;
     if (PQerrorMessage (CONNECTION (file)) != NULL) {
-      a68_bufcpy (str, pq_edit (PQerrorMessage (CONNECTION (file))), BUFFER_SIZE);
+      a68g_bufcpy (str, pq_edit (PQerrorMessage (CONNECTION (file))), BUFFER_SIZE);
       int upb = (int) strlen (str);
       if (upb > 0 && str[upb - 1] == NEWLINE_CHAR) {
         str[upb - 1] = NULL_CHAR;
       }
     } else {
-      a68_bufcpy (str, "no error message available", BUFFER_SIZE);
+      a68g_bufcpy (str, "no error message available", BUFFER_SIZE);
     }
     *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, str, DEFAULT_WIDTH);
     STRPOS (file) = 0;
@@ -562,13 +562,13 @@ void genie_pq_resulterrormessage (NODE_T * p)
   if (!IS_NIL (STRING (file))) {
     BUFFER str;
     if (PQresultErrorMessage (RESULT (file)) != NULL) {
-      a68_bufcpy (str, pq_edit (PQresultErrorMessage (RESULT (file))), BUFFER_SIZE);
+      a68g_bufcpy (str, pq_edit (PQresultErrorMessage (RESULT (file))), BUFFER_SIZE);
       int upb = (int) strlen (str);
       if (upb > 0 && str[upb - 1] == NEWLINE_CHAR) {
         str[upb - 1] = NULL_CHAR;
       }
     } else {
-      a68_bufcpy (str, "no error message available", BUFFER_SIZE);
+      a68g_bufcpy (str, "no error message available", BUFFER_SIZE);
     }
     *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, str, DEFAULT_WIDTH);
     STRPOS (file) = 0;
