@@ -105,7 +105,7 @@ void print_internal_index (FILE_T f, A68_TUPLE * tup, int dim)
     A68_TUPLE *ref = &tup[k];
     BUFFER buf;
     BUFCLR (buf);
-    ASSERT (a68_bufprt (buf, SNPRINTF_SIZE, A68_LD, K (ref)) >= 0);
+    ASSERT (a68g_bufprt (buf, SNPRINTF_SIZE, A68_LD, K (ref)) >= 0);
     WRITE (f, buf);
     if (k < dim - 1) {
       WRITE (f, ", ");
@@ -146,7 +146,7 @@ A68_REF c_to_a_string (NODE_T * p, char *str, int width)
 
 //! @brief Size of a string.
 
-int a68_string_size (NODE_T * p, A68_REF row)
+int a68g_string_size (NODE_T * p, A68_REF row)
 {
   (void) p;
   if (INITIALISED (&row)) {
@@ -748,8 +748,8 @@ void genie_sort_row_string (NODE_T * p)
   int size = ROW_SIZE (tup);
   if (size > 0) {
     BYTE_T *base = ADDRESS (&ARRAY (arr));
-    char **ptrs = (char **) a68_alloc ((size_t) (size * (int) sizeof (char *)), __func__, __LINE__);
-    if (ptrs == NO_VAR) {
+    char **ptrs = (char **) a68g_alloc ((size_t) (size * (int) sizeof (char *)), __func__, __LINE__);
+    if (ptrs == NO_REF) {
       diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
       exit_genie (p, A68_RUNTIME_ERROR);
     }
@@ -758,7 +758,7 @@ void genie_sort_row_string (NODE_T * p)
       int addr = INDEX_1_DIM (arr, tup, k);
       A68_REF ref = *(A68_REF *) & (base[addr]);
       CHECK_REF (p, ref, M_STRING);
-      int len = A68_ALIGN (a68_string_size (p, ref) + 1);
+      int len = A68_ALIGN (a68g_string_size (p, ref) + 1);
       if (A68_SP + len > A68 (expr_stack_limit)) {
         diagnostic (A68_RUNTIME_ERROR, p, ERROR_STACK_OVERFLOW);
         exit_genie (p, A68_RUNTIME_ERROR);
@@ -775,7 +775,7 @@ void genie_sort_row_string (NODE_T * p)
     for (int k = 0; k < size; k++) {
       base_ref[k] = c_to_a_string (p, ptrs[k], DEFAULT_WIDTH);
     }
-    a68_free (ptrs);
+    a68g_free (ptrs);
     A68_SP = pop_sp;
     PUSH_REF (p, z);
   } else {
