@@ -75,7 +75,7 @@ int store_file_entry (NODE_T * p, FILE_T fd, char *idf, BOOL_T is_tmp)
       FD (fe) = fd;
       IDF (fe) = heap_generator (p, M_C_STRING, len);
       BLOCK_GC_HANDLE (&(IDF (fe)));
-      a68_bufcpy (DEREF (char, &IDF (fe)), idf, len);
+      a68g_bufcpy (DEREF (char, &IDF (fe)), idf, len);
       return k;
     }
   }
@@ -245,7 +245,7 @@ void enlarge_transput_buffer (NODE_T * p, int k, int size)
   set_transput_buffer_size (k, size);
   set_transput_buffer_index (k, n);
   sb_2 = get_transput_buffer (k);
-  a68_bufcpy (sb_2, sb_1, size);
+  a68g_bufcpy (sb_2, sb_1, size);
 }
 
 //! @brief Add char to transput buffer; if the buffer is full, make it larger.
@@ -613,7 +613,7 @@ void init_file (NODE_T * p, A68_REF * ref_file, A68_CHANNEL c, FILE_T s, BOOL_T
     int len = 1 + (int) strlen (filename);
     IDENTIFICATION (f) = heap_generator (p, M_C_STRING, len);
     BLOCK_GC_HANDLE (&(IDENTIFICATION (f)));
-    a68_bufcpy (DEREF (char, &IDENTIFICATION (f)), filename, len);
+    a68g_bufcpy (DEREF (char, &IDENTIFICATION (f)), filename, len);
     FD (f) = A68_NO_FILE;
     READ_MOOD (f) = A68_FALSE;
     WRITE_MOOD (f) = A68_FALSE;
@@ -704,7 +704,7 @@ void genie_make_term (NODE_T * p)
   ref_file = *(A68_REF *) STACK_TOP;
   A68_FILE *file = FILE_DEREF (&ref_file);
 // Don't check initialisation so we can "make term" before opening.
-  int size = a68_string_size (p, str);
+  int size = a68g_string_size (p, str);
   if (INITIALISED (&(TERMINATOR (file))) && !IS_NIL (TERMINATOR (file))) {
     UNBLOCK_GC_HANDLE (&(TERMINATOR (file)));
   }
@@ -833,7 +833,7 @@ void genie_open (NODE_T * p)
   CHAR_MOOD (file) = A68_FALSE;
   DRAW_MOOD (file) = A68_FALSE;
   TMP_FILE (file) = A68_FALSE;
-  int size = a68_string_size (p, ref_iden);
+  int size = a68g_string_size (p, ref_iden);
   if (INITIALISED (&(IDENTIFICATION (file))) && !IS_NIL (IDENTIFICATION (file))) {
     UNBLOCK_GC_HANDLE (&(IDENTIFICATION (file)));
   }
@@ -889,7 +889,7 @@ void genie_establish (NODE_T * p)
     diagnostic (A68_RUNTIME_ERROR, p, ERROR_CHANNEL_DOES_NOT_ALLOW, "putting");
     exit_genie (p, A68_RUNTIME_ERROR);
   }
-  int size = a68_string_size (p, ref_iden);
+  int size = a68g_string_size (p, ref_iden);
   if (INITIALISED (&(IDENTIFICATION (file))) && !IS_NIL (IDENTIFICATION (file))) {
     UNBLOCK_GC_HANDLE (&(IDENTIFICATION (file)));
   }
