@@ -219,7 +219,7 @@ void scan_string (NODE_T * p, char *term, A68_REF ref_file)
 
 //! @brief Make temp file name.
 
-BOOL_T a68_mkstemp (char *fn, int flags, mode_t permissions)
+BOOL_T a68g_mkstemp (char *fn, int flags, mode_t permissions)
 {
 // "tmpnam" is not safe, "mkstemp" is Unix, so a68g brings its own tmpnam.
 #define TMP_SIZE 32
@@ -230,21 +230,21 @@ BOOL_T a68_mkstemp (char *fn, int flags, mode_t permissions)
   BOOL_T good_file = A68_FALSE;
 // Next are prefixes to try.
 // First we try /tmp, and if that won't go, the current dir.
-  char *prefix[] = { "/tmp/a68_", "./a68_", NO_TEXT };
+  char *prefix[] = { "/tmp/a68g_", "./a68g_", NO_TEXT };
   for (int i = 0; prefix[i] != NO_TEXT; i++) {
     for (int k = 0; k < TRIALS && good_file == A68_FALSE; k++) {
-      a68_bufcpy (tfilename, prefix[i], BUFFER_SIZE);
+      a68g_bufcpy (tfilename, prefix[i], BUFFER_SIZE);
       for (int j = 0; j < TMP_SIZE; j++) {
         int cindex;
         do {
-          cindex = (int) (a68_unif_rand () * len);
+          cindex = (int) (a68g_unif_rand () * len);
         } while (cindex < 0 || cindex >= len);
         char chars[2];
         chars[0] = letters[cindex];
         chars[1] = NULL_CHAR;
-        a68_bufcat (tfilename, chars, BUFFER_SIZE);
+        a68g_bufcat (tfilename, chars, BUFFER_SIZE);
       }
-      a68_bufcat (tfilename, ".tmp", BUFFER_SIZE);
+      a68g_bufcat (tfilename, ".tmp", BUFFER_SIZE);
       errno = 0;
       FILE_T fd = open (tfilename, flags | O_EXCL, permissions);
       good_file = (BOOL_T) (fd != A68_NO_FILE && errno == 0);
@@ -254,7 +254,7 @@ BOOL_T a68_mkstemp (char *fn, int flags, mode_t permissions)
     }
   }
   if (good_file) {
-    a68_bufcpy (fn, tfilename, BUFFER_SIZE);
+    a68g_bufcpy (fn, tfilename, BUFFER_SIZE);
     return A68_TRUE;
   } else {
     return A68_FALSE;
@@ -294,7 +294,7 @@ FILE_T open_physical_file (NODE_T * p, A68_REF ref_file, int flags, mode_t permi
       BUFFER tfilename;
       int len;
       BUFCLR (tfilename);
-      if (!a68_mkstemp (tfilename, flags, permissions)) {
+      if (!a68g_mkstemp (tfilename, flags, permissions)) {
         diagnostic (A68_RUNTIME_ERROR, p, ERROR_FILE_NO_TEMP);
         exit_genie (p, A68_RUNTIME_ERROR);
       }
@@ -302,7 +302,7 @@ FILE_T open_physical_file (NODE_T * p, A68_REF ref_file, int flags, mode_t permi
       len = 1 + (int) strlen (tfilename);
       IDENTIFICATION (file) = heap_generator (p, M_C_STRING, len);
       BLOCK_GC_HANDLE (&(IDENTIFICATION (file)));
-      a68_bufcpy (DEREF (char, &IDENTIFICATION (file)), tfilename, len);
+      a68g_bufcpy (DEREF (char, &IDENTIFICATION (file)), tfilename, len);
       TRANSPUT_BUFFER (file) = get_unblocked_transput_buffer (p);
       reset_transput_buffer (TRANSPUT_BUFFER (file));
       END_OF_FILE (file) = A68_FALSE;
@@ -415,14 +415,14 @@ UNSIGNED_T bits_to_int (NODE_T * p, char *str)
 {
   errno = 0;
   char *radix = NO_TEXT, *end = NO_TEXT;
-  int base = (int) a68_strtou (str, &radix, 10);
+  int base = (int) a68g_strtou (str, &radix, 10);
   if (radix != NO_TEXT && TO_UPPER (radix[0]) == TO_UPPER (RADIX_CHAR) && errno == 0) {
     UNSIGNED_T bits = 0;
     if (base < 2 || base > 16) {
       diagnostic (A68_RUNTIME_ERROR, p, ERROR_INVALID_RADIX, base);
       exit_genie (p, A68_RUNTIME_ERROR);
     }
-    bits = a68_strtou (&(radix[1]), &end, base);
+    bits = a68g_strtou (&(radix[1]), &end, base);
     if (end != NO_TEXT && end[0] == NULL_CHAR && errno == 0) {
       return bits;
     }
@@ -444,7 +444,7 @@ BOOL_T genie_string_to_value_internal (NODE_T * p, MOID_T * m, char *a, BYTE_T *
   if (m == M_INT) {
     A68_INT *z = (A68_INT *) item;
     char *end;
-    VALUE (z) = (INT_T) a68_strtoi (a, &end, 10);
+    VALUE (z) = (INT_T) a68g_strtoi (a, &end, 10);
     if (end[0] == NULL_CHAR && errno == 0) {
       STATUS (z) = INIT_MASK;
       return A68_TRUE;
@@ -739,8 +739,8 @@ void genie_read_standard (NODE_T * p, MOID_T * mode, BYTE_T * item, A68_REF ref_
       BOOL_T done = A68_FALSE;
       initialise_internal_index (tup, DIM (arr));
       while (!done) {
-        ADDR_T a68_index = calculate_internal_index (tup, DIM (arr));
-        ADDR_T elem_addr = ROW_ELEMENT (arr, a68_index);
+        ADDR_T a68g_index = calculate_internal_index (tup, DIM (arr));
+        ADDR_T elem_addr = ROW_ELEMENT (arr, a68g_index);
         genie_read_standard (p, SUB (deflexed), &base_addr[elem_addr], ref_file);
         done = increment_internal_index (tup, DIM (arr));
       }
@@ -1084,8 +1084,8 @@ void genie_write_standard (NODE_T * p, MOID_T * mode, BYTE_T * item, A68_REF ref
       BOOL_T done = A68_FALSE;
       initialise_internal_index (tup, DIM (arr));
       while (!done) {
-        ADDR_T a68_index = calculate_internal_index (tup, DIM (arr));
-        ADDR_T elem_addr = ROW_ELEMENT (arr, a68_index);
+        ADDR_T a68g_index = calculate_internal_index (tup, DIM (arr));
+        ADDR_T elem_addr = ROW_ELEMENT (arr, a68g_index);
         BYTE_T *elem = &base_addr[elem_addr];
         genie_check_initialisation (p, elem, SUB (deflexed));
         genie_write_standard (p, SUB (deflexed), elem, ref_file);
@@ -1295,8 +1295,8 @@ void genie_read_bin_standard (NODE_T * p, MOID_T * mode, BYTE_T * item, A68_REF
       BOOL_T done = A68_FALSE;
       initialise_internal_index (tup, DIM (arr));
       while (!done) {
-        ADDR_T a68_index = calculate_internal_index (tup, DIM (arr));
-        ADDR_T elem_addr = ROW_ELEMENT (arr, a68_index);
+        ADDR_T a68g_index = calculate_internal_index (tup, DIM (arr));
+        ADDR_T elem_addr = ROW_ELEMENT (arr, a68g_index);
         genie_read_bin_standard (p, SUB (deflexed), &base_addr[elem_addr], ref_file);
         done = increment_internal_index (tup, DIM (arr));
       }
@@ -1454,8 +1454,8 @@ void genie_write_bin_standard (NODE_T * p, MOID_T * mode, BYTE_T * item, A68_REF
       BOOL_T done = A68_FALSE;
       initialise_internal_index (tup, DIM (arr));
       while (!done) {
-        ADDR_T a68_index = calculate_internal_index (tup, DIM (arr));
-        ADDR_T elem_addr = ROW_ELEMENT (arr, a68_index);
+        ADDR_T a68g_index = calculate_internal_index (tup, DIM (arr));
+        ADDR_T elem_addr = ROW_ELEMENT (arr, a68g_index);
         BYTE_T *elem = &base_addr[elem_addr];
         genie_check_initialisation (p, elem, SUB (deflexed));
         genie_write_bin_standard (p, SUB (deflexed), elem, ref_file);
@@ -1563,7 +1563,7 @@ char *error_chars (char *s, int n)
 
 //! @brief Convert temporary C string to A68 string.
 
-A68_REF tmp_to_a68_string (NODE_T * p, char *temp_string)
+A68_REF tmp_to_a68g_string (NODE_T * p, char *temp_string)
 {
 // no compaction allowed since temp_string might be up for garbage collecting ...
   return c_to_a_string (p, temp_string, DEFAULT_WIDTH);
@@ -1585,7 +1585,7 @@ char *string_plusab_char (char *str, char c, int strwid)
   char z[2];
   z[0] = c;
   z[1] = NULL_CHAR;
-  a68_bufcat (str, z, strwid);
+  a68g_bufcat (str, z, strwid);
   return str;
 }
 
@@ -1766,7 +1766,7 @@ char *whole (NODE_T * p)
     size += length;
     size = 8 + (size > VALUE (&width) ? size : VALUE (&width));
     char *s = stack_string (p, size);
-    a68_bufcpy (s, sub_whole (p, n, length), size);
+    a68g_bufcpy (s, sub_whole (p, n, length), size);
     if (length == 0 || strchr (s, ERROR_CHAR) != NO_TEXT) {
       (void) error_chars (s, VALUE (&width));
     } else {
@@ -1798,7 +1798,7 @@ char *whole (NODE_T * p)
     size += length;
     size = 8 + (size > VALUE (&width) ? size : VALUE (&width));
     char *s = stack_string (p, size);
-    a68_bufcpy (s, long_sub_whole_double (p, n, length), size);
+    a68g_bufcpy (s, long_sub_whole_double (p, n, length), size);
     if (length == 0 || strchr (s, ERROR_CHAR) != NO_TEXT) {
       (void) error_chars (s, VALUE (&width));
     } else {
@@ -1840,7 +1840,7 @@ char *whole (NODE_T * p)
     size += length;
     size = 8 + (size > VALUE (&width) ? size : VALUE (&width));
     char *s = stack_string (p, size);
-    a68_bufcpy (s, long_sub_whole (p, n, digits, length), size);
+    a68g_bufcpy (s, long_sub_whole (p, n, digits, length), size);
     if (length == 0 || strchr (s, ERROR_CHAR) != NO_TEXT) {
       (void) error_chars (s, VALUE (&width));
     } else {
@@ -2426,9 +2426,9 @@ char *real (NODE_T * p)
       char *t2 = whole (p);
       int strwid = 8 + (int) strlen (t1) + 1 + (int) strlen (t2);
       char *s = stack_string (p, strwid);
-      a68_bufcpy (s, t1, strwid);
+      a68g_bufcpy (s, t1, strwid);
       (void) string_plusab_char (s, EXPONENT_CHAR, strwid);
-      a68_bufcat (s, t2, strwid);
+      a68g_bufcat (s, t2, strwid);
       if (VALUE (&expo) == 0 || strchr (s, ERROR_CHAR) != NO_TEXT) {
         A68_SP = arg_sp;
         PUSH_VALUE (p, VALUE (&width), A68_INT);
@@ -2496,9 +2496,9 @@ char *real (NODE_T * p)
       char *t2 = whole (p);
       int strwid = 8 + (int) strlen (t1) + 1 + (int) strlen (t2);
       char *s = stack_string (p, strwid);
-      a68_bufcpy (s, t1, strwid);
+      a68g_bufcpy (s, t1, strwid);
       (void) string_plusab_char (s, EXPONENT_CHAR, strwid);
-      a68_bufcat (s, t2, strwid);
+      a68g_bufcat (s, t2, strwid);
       if (VALUE (&expo) == 0 || strchr (s, ERROR_CHAR) != NO_TEXT) {
         A68_SP = arg_sp;
         PUSH_VALUE (p, VALUE (&width), A68_INT);
@@ -2578,9 +2578,9 @@ char *real (NODE_T * p)
       char *t2 = whole (p);
       int strwid = 8 + (int) strlen (t1) + 1 + (int) strlen (t2);
       char *s = stack_string (p, strwid);
-      a68_bufcpy (s, t1, strwid);
+      a68g_bufcpy (s, t1, strwid);
       (void) string_plusab_char (s, EXPONENT_CHAR, strwid);
-      a68_bufcat (s, t2, strwid);
+      a68g_bufcat (s, t2, strwid);
       if (VALUE (&expo) == 0 || strchr (s, ERROR_CHAR) != NO_TEXT) {
         A68_SP = arg_sp;
         PUSH_VALUE (p, VALUE (&width), A68_INT);
@@ -2630,7 +2630,7 @@ void genie_whole (NODE_T * p)
   ADDR_T pop_sp = A68_SP;
   char *str = whole (p);
   A68_SP = pop_sp - SIZE (M_INT) - SIZE (M_NUMBER);
-  A68_REF ref = tmp_to_a68_string (p, str);
+  A68_REF ref = tmp_to_a68g_string (p, str);
   PUSH_REF (p, ref);
 }
 
@@ -2641,7 +2641,7 @@ void genie_bits (NODE_T * p)
   ADDR_T pop_sp = A68_SP;
   char *str = bits_to_string (p);
   A68_SP = pop_sp - 2 * SIZE (M_INT) - SIZE (M_HEX_NUMBER);
-  A68_REF ref = tmp_to_a68_string (p, str);
+  A68_REF ref = tmp_to_a68g_string (p, str);
   PUSH_REF (p, ref);
 }
 
@@ -2652,7 +2652,7 @@ void genie_fixed (NODE_T * p)
   ADDR_T pop_sp = A68_SP;
   char *str = fixed (p);
   A68_SP = pop_sp - 2 * SIZE (M_INT) - SIZE (M_NUMBER);
-  A68_REF ref = tmp_to_a68_string (p, str);
+  A68_REF ref = tmp_to_a68g_string (p, str);
   PUSH_REF (p, ref);
 }
 
@@ -2663,7 +2663,7 @@ void genie_real (NODE_T * p)
   ADDR_T pop_sp = A68_SP;
   char *str = real (p);
   A68_SP = pop_sp - 4 * SIZE (M_INT) - SIZE (M_NUMBER);
-  A68_REF ref = tmp_to_a68_string (p, str);
+  A68_REF ref = tmp_to_a68g_string (p, str);
   PUSH_REF (p, ref);
 }
 
@@ -2787,7 +2787,7 @@ void genie_read_line (NODE_T * p)
     add_history (line);
   }
   PUSH_REF (p, c_to_a_string (p, line, DEFAULT_WIDTH));
-  a68_free (line);
+  a68g_free (line);
 #else
   genie_read_string (p);
   genie_stand_in (p);
