@@ -34,9 +34,9 @@
 static void fft_error_handler (const char *reason, const char *file, int line, int gsl_errno)
 {
   if (line != 0) {
-    ASSERT (a68_bufprt (A68 (edit_line), SNPRINTF_SIZE, "%s in line %d of file %s", reason, line, file) >= 0);
+    ASSERT (a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "%s in line %d of file %s", reason, line, file) >= 0);
   } else {
-    ASSERT (a68_bufprt (A68 (edit_line), SNPRINTF_SIZE, "%s", reason) >= 0);
+    ASSERT (a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "%s", reason) >= 0);
   }
   diagnostic (A68_RUNTIME_ERROR, A68 (f_entry), ERROR_FFT, A68 (edit_line), gsl_strerror (gsl_errno));
   exit_genie (A68 (f_entry), A68_RUNTIME_ERROR);
@@ -188,7 +188,7 @@ void genie_fft_complex_forward (NODE_T * p)
   push_array_complex (p, data, len);
   gsl_fft_complex_wavetable_free (wt);
   gsl_fft_complex_workspace_free (ws);
-  a68_free (data);
+  a68g_free (data);
   (void) gsl_set_error_handler (save_handler);
 }
 
@@ -207,7 +207,7 @@ void genie_fft_complex_backward (NODE_T * p)
   push_array_complex (p, data, len);
   gsl_fft_complex_wavetable_free (wt);
   gsl_fft_complex_workspace_free (ws);
-  a68_free (data);
+  a68g_free (data);
   (void) gsl_set_error_handler (save_handler);
 }
 
@@ -226,7 +226,7 @@ void genie_fft_complex_inverse (NODE_T * p)
   push_array_complex (p, data, len);
   gsl_fft_complex_wavetable_free (wt);
   gsl_fft_complex_workspace_free (ws);
-  a68_free (data);
+  a68g_free (data);
   (void) gsl_set_error_handler (save_handler);
 }
 
@@ -245,7 +245,7 @@ void genie_fft_forward (NODE_T * p)
   push_array_complex (p, data, len);
   gsl_fft_complex_wavetable_free (wt);
   gsl_fft_complex_workspace_free (ws);
-  a68_free (data);
+  a68g_free (data);
   (void) gsl_set_error_handler (save_handler);
 }
 
@@ -264,7 +264,7 @@ void genie_fft_backward (NODE_T * p)
   push_array_real (p, data, len);
   gsl_fft_complex_wavetable_free (wt);
   gsl_fft_complex_workspace_free (ws);
-  a68_free (data);
+  a68g_free (data);
   (void) gsl_set_error_handler (save_handler);
 }
 
@@ -283,7 +283,7 @@ void genie_fft_inverse (NODE_T * p)
   push_array_real (p, data, len);
   gsl_fft_complex_wavetable_free (wt);
   gsl_fft_complex_workspace_free (ws);
-  a68_free (data);
+  a68g_free (data);
   (void) gsl_set_error_handler (save_handler);
 }
 
