@@ -119,7 +119,7 @@ void compute_pseudo_inverse (NODE_T *p, gsl_matrix **mpinv, gsl_matrix *X, REAL_
       gsl_matrix_set (S_inv, i, i, 0);
     }
   }
-  a68_vector_free (Sv);
+  a68g_vector_free (Sv);
 // GSL SVD yields thin SVD - pad with zeros.
   gsl_matrix *Uf = gsl_matrix_calloc (M, M);
   for (int i = 0; i < M; i++) {
@@ -129,8 +129,8 @@ void compute_pseudo_inverse (NODE_T *p, gsl_matrix **mpinv, gsl_matrix *X, REAL_
   }
 // Compute pseudo inverse A⁻¹ = VS⁻¹Uᵀ. 
   gsl_matrix *VS_inv = NO_REAL_MATRIX, *X_inv = NO_REAL_MATRIX;
-  a68_dgemm (SELF, SELF, 1, V, S_inv, 0, &VS_inv);
-  a68_dgemm (SELF, FLIP, 1, VS_inv, Uf, 0, &X_inv);
+  a68g_dgemm (SELF, SELF, 1, V, S_inv, 0, &VS_inv);
+  a68g_dgemm (SELF, FLIP, 1, VS_inv, Uf, 0, &X_inv);
 // Compose result.
   if (transpose) {
     (*mpinv) = gsl_matrix_calloc (M, N);
@@ -140,12 +140,12 @@ void compute_pseudo_inverse (NODE_T *p, gsl_matrix **mpinv, gsl_matrix *X, REAL_
     gsl_matrix_memcpy ((*mpinv), X_inv);
   }
 // Clean up.
-  a68_matrix_free (S_inv);
-  a68_matrix_free (U);
-  a68_matrix_free (Uf);
-  a68_matrix_free (V);
-  a68_matrix_free (VS_inv);
-  a68_matrix_free (X_inv);
+  a68g_matrix_free (S_inv);
+  a68g_matrix_free (U);
+  a68g_matrix_free (Uf);
+  a68g_matrix_free (V);
+  a68g_matrix_free (VS_inv);
+  a68g_matrix_free (X_inv);
 }
 
 //! @brief Compute Principal Component Analysis by SVD.
@@ -181,8 +181,8 @@ gsl_matrix *pca_svd (gsl_matrix *X, gsl_vector ** Sv)
   } else {
     ASSERT_GSL (gsl_matrix_memcpy (eigens, V));
   }
-  a68_matrix_free (U);
-  a68_matrix_free (V);
+  a68g_matrix_free (U);
+  a68g_matrix_free (V);
   return eigens;
 }
 
@@ -199,8 +199,8 @@ void genie_matrix_pinv_lim (NODE_T * p)
   gsl_matrix *X = pop_matrix (p, A68_TRUE), *mpinv = NO_REAL_MATRIX;
   compute_pseudo_inverse (p, &mpinv, X, VALUE (&lim));
   push_matrix (p, mpinv);
-  a68_matrix_free (mpinv);
-  a68_matrix_free (X);
+  a68g_matrix_free (mpinv);
+  a68g_matrix_free (X);
   (void) gsl_set_error_handler (save_handler);
 }
 
@@ -231,8 +231,8 @@ void genie_matrix_column_mean (NODE_T *p)
     }
   }
   push_matrix (p, A);
-  a68_matrix_free (A);
-  a68_matrix_free (Z);
+  a68g_matrix_free (A);
+  a68g_matrix_free (Z);
   (void) gsl_set_error_handler (save_handler);
 }
 
@@ -245,8 +245,8 @@ void genie_left_columns (NODE_T *p)
   gsl_matrix *X = pop_matrix (p, A68_TRUE); 
   gsl_matrix *Y = left_columns (p, X, VALUE (&k));
   push_matrix (p, Y);
-  a68_matrix_free (X);
-  a68_matrix_free (Y);
+  a68g_matrix_free (X);
+  a68g_matrix_free (Y);
 }
 
 //! @brief PROC pca cv = ([, ] REAL, REF [] REAL) [, ] REAL
@@ -269,7 +269,7 @@ void genie_matrix_pca_cv (NODE_T * p)
 // Covariance matrix, M samples: Cov = XᵀX.
   M = MAX (M, N);
   gsl_matrix *CV = NO_REAL_MATRIX;
-  a68_dgemm (FLIP, SELF, 1, C, C, 0, &CV);
+  a68g_dgemm (FLIP, SELF, 1, C, C, 0, &CV);
 // Compute and sort eigenvectors.
   gsl_vector *Sv = gsl_vector_calloc (M);
   gsl_matrix *eigens = gsl_matrix_calloc (M, M);
@@ -283,12 +283,12 @@ void genie_matrix_pca_cv (NODE_T * p)
   push_matrix (p, eigens);
   (void) gsl_set_error_handler (save_handler);
 // Garbage collector
-  a68_matrix_free (eigens);
-  a68_matrix_free (X);
+  a68g_matrix_free (eigens);
+  a68g_matrix_free (X);
   gsl_eigen_symmv_free (W);
-  a68_matrix_free (C);
-  a68_matrix_free (CV);
-  a68_vector_free (Sv);
+  a68g_matrix_free (C);
+  a68g_matrix_free (CV);
+  a68g_vector_free (Sv);
 }
 
 //! @brief PROC pca svd = ([, ] REAL, REF [] REAL) [, ] REAL
@@ -313,11 +313,11 @@ void genie_matrix_pca_svd (NODE_T * p)
   push_matrix (p, eigens);
   (void) gsl_set_error_handler (save_handler);
 // Clean up.
-  a68_matrix_free (eigens);
-  a68_matrix_free (X);
-  a68_matrix_free (C);
+  a68g_matrix_free (eigens);
+  a68g_matrix_free (X);
+  a68g_matrix_free (C);
   if (Sv != NO_REAL_VECTOR) {
-    a68_vector_free (Sv);
+    a68g_vector_free (Sv);
   }
 }
 
@@ -371,13 +371,13 @@ void genie_matrix_pcr (NODE_T * p)
   gsl_matrix *reduced = left_columns (p, eigens, Nk);
 // Compute projected set = X * reduced.
   gsl_matrix *proj = NO_REAL_MATRIX;
-  a68_dgemm (SELF, SELF, 1.0, X, reduced, 0.0, &proj);
+  a68g_dgemm (SELF, SELF, 1.0, X, reduced, 0.0, &proj);
 // Compute β = reduced * P⁻¹ * Y.
   gsl_matrix *mpinv = NO_REAL_MATRIX;
   compute_pseudo_inverse (p, &mpinv, proj, SMALL_EIGEN);
   gsl_matrix *z = NO_REAL_MATRIX, *beta = NO_REAL_MATRIX;
-  a68_dgemm (SELF, SELF, 1.0, reduced, mpinv, 0.0, &z);
-  a68_dgemm (SELF, SELF, 1.0, z, Y, 0.0, &beta);
+  a68g_dgemm (SELF, SELF, 1.0, reduced, mpinv, 0.0, &z);
+  a68g_dgemm (SELF, SELF, 1.0, z, Y, 0.0, &beta);
 // Yield results.
   if (!IS_NIL (singulars)) {
     *DEREF (A68_REF, &singulars) = vector_to_row (p, Sv);
@@ -385,16 +385,16 @@ void genie_matrix_pcr (NODE_T * p)
   push_matrix (p, beta);
   (void) gsl_set_error_handler (save_handler);
 // Clean up.
-  a68_matrix_free (eigens);
-  a68_matrix_free (reduced);
-  a68_matrix_free (X);
-  a68_matrix_free (Y);
-  a68_matrix_free (C);
-  a68_vector_free (Sv);
-  a68_matrix_free (z);
-  a68_matrix_free (mpinv);
-  a68_matrix_free (proj);
-  a68_matrix_free (beta);
+  a68g_matrix_free (eigens);
+  a68g_matrix_free (reduced);
+  a68g_matrix_free (X);
+  a68g_matrix_free (Y);
+  a68g_matrix_free (C);
+  a68g_vector_free (Sv);
+  a68g_matrix_free (z);
+  a68g_matrix_free (mpinv);
+  a68g_matrix_free (proj);
+  a68g_matrix_free (beta);
 }
 
 //! @brief PROC ols = ([, ] REAL, [, ] REAL) [, ] REAL
@@ -414,14 +414,14 @@ void genie_matrix_ols (NODE_T *p)
 // Compute β = X⁻¹ * Y.
   gsl_matrix *mpinv = NO_REAL_MATRIX, *beta = NO_REAL_MATRIX;
   compute_pseudo_inverse (p, &mpinv, X, SMALL_EIGEN);
-  a68_dgemm (SELF, SELF, 1.0, X, Y, 0.0, &beta);
+  a68g_dgemm (SELF, SELF, 1.0, X, Y, 0.0, &beta);
 // Yield results.
   push_matrix (p, beta);
   (void) gsl_set_error_handler (save_handler);
-  a68_matrix_free (beta);
-  a68_matrix_free (mpinv);
-  a68_matrix_free (X);
-  a68_matrix_free (Y);
+  a68g_matrix_free (beta);
+  a68g_matrix_free (mpinv);
+  a68g_matrix_free (X);
+  a68g_matrix_free (Y);
 }
 
 //! @brief PROC pls1 = ([, ] REAL, [, ] REAL, REF [] REAL, INT, REAL) [, ] REAL
@@ -470,7 +470,7 @@ void genie_matrix_pls1 (NODE_T *p)
   for (int k = 0; k < Nk && siga; k ++) {
 // E weight from E, F covariance.
 // eigens = Eᵀ * f / | Eᵀ * f |
-    a68_dgemm (FLIP, SELF, 1.0, E, F, 0.0, &eigens);
+    a68g_dgemm (FLIP, SELF, 1.0, E, F, 0.0, &eigens);
     REAL_T norm = matrix_norm (eigens);
     if (k > 0 && (norm / gsl_vector_get (Sv, 0)) < VALUE (&lim)) {
       Nk = k;
@@ -480,15 +480,15 @@ void genie_matrix_pls1 (NODE_T *p)
       gsl_vector_set (Sv, k, norm);
 // Compute latent variable.
 // lat = E * eigens / | E * eigens |
-      a68_dgemm (SELF, SELF, 1.0, E, eigens, 0.0, &lat);
+      a68g_dgemm (SELF, SELF, 1.0, E, eigens, 0.0, &lat);
       norm = matrix_norm (lat);
       ASSERT_GSL (gsl_matrix_scale (lat, 1.0 / norm));
 // Deflate E and F, remove latent variable from both.
 // pl = Eᵀ * lat; E -= lat * plᵀ and ql = Fᵀ * lat; F -= lat * qlᵀ
-      a68_dgemm (FLIP, SELF, 1.0, E, lat, 0.0, &pl);
-      a68_dgemm (SELF, FLIP, -1.0, lat, pl, 1.0, &E);
-      a68_dgemm (FLIP, SELF, 1.0, F, lat, 0.0, &ql);
-      a68_dgemm (SELF, FLIP, -1.0, lat, ql, 1.0, &F);
+      a68g_dgemm (FLIP, SELF, 1.0, E, lat, 0.0, &pl);
+      a68g_dgemm (SELF, FLIP, -1.0, lat, pl, 1.0, &E);
+      a68g_dgemm (FLIP, SELF, 1.0, F, lat, 0.0, &ql);
+      a68g_dgemm (SELF, FLIP, -1.0, lat, ql, 1.0, &F);
 // Build matrices.
       EIGEN = mat_before_ab (p, EIGEN, eigens);
       nE = mat_before_ab (p, nE, pl); // P
@@ -497,12 +497,12 @@ void genie_matrix_pls1 (NODE_T *p)
   }
 // Projection of original data = Eᵀ * EIGEN
   gsl_matrix *nP = NO_REAL_MATRIX;
-  a68_dgemm (FLIP, SELF, 1.0, nE, EIGEN, 0.0, &nP);
+  a68g_dgemm (FLIP, SELF, 1.0, nE, EIGEN, 0.0, &nP);
 // Compute β = EIGEN * nP⁻¹ * nF
   gsl_matrix *mpinv = NO_REAL_MATRIX, *z = NO_REAL_MATRIX, *beta = NO_REAL_MATRIX;
   compute_pseudo_inverse (p, &mpinv, nP, SMALL_EIGEN);
-  a68_dgemm (SELF, SELF, 1.0, EIGEN, mpinv, 0.0, &z);
-  a68_dgemm (SELF, SELF, 1.0, z, nF, 0.0, &beta);
+  a68g_dgemm (SELF, SELF, 1.0, EIGEN, mpinv, 0.0, &z);
+  a68g_dgemm (SELF, SELF, 1.0, z, nF, 0.0, &beta);
 // Yield results.
   if (!IS_NIL (singulars)) {
     gsl_vector *Svl = gsl_vector_calloc (Nk);
@@ -510,23 +510,23 @@ void genie_matrix_pls1 (NODE_T *p)
       gsl_vector_set (Svl, k, gsl_vector_get (Sv, k));
     }
     *DEREF (A68_REF, &singulars) = vector_to_row (p, Svl);
-    a68_vector_free (Svl);
+    a68g_vector_free (Svl);
   }
   push_matrix (p, beta);
   (void) gsl_set_error_handler (save_handler);
 // Garbage collector.
-  a68_matrix_free (E);
-  a68_matrix_free (F);
-  a68_matrix_free (eigens);
-  a68_matrix_free (lat);
-  a68_matrix_free (pl);
-  a68_matrix_free (ql);
-  a68_matrix_free (beta);
-  a68_matrix_free (EIGEN);
-  a68_matrix_free (nE);
-  a68_matrix_free (nF);
-  a68_matrix_free (nP);
-  a68_vector_free (Sv);
+  a68g_matrix_free (E);
+  a68g_matrix_free (F);
+  a68g_matrix_free (eigens);
+  a68g_matrix_free (lat);
+  a68g_matrix_free (pl);
+  a68g_matrix_free (ql);
+  a68g_matrix_free (beta);
+  a68g_matrix_free (EIGEN);
+  a68g_matrix_free (nE);
+  a68g_matrix_free (nF);
+  a68g_matrix_free (nP);
+  a68g_vector_free (Sv);
 }
 
 //! @brief PROC pls2 = ([, ] REAL, [, ] REAL, REF [] REAL, INT, REAL) [, ] REAL
@@ -572,7 +572,7 @@ void genie_matrix_pls2 (NODE_T *p)
     }
   } else {
     for (int k = 0; k < Mf; k ++) {
-      gsl_matrix_set (u, k, 0, a68_gauss_rand ());
+      gsl_matrix_set (u, k, 0, a68g_gauss_rand ());
     }
   }
 // Decompose E and F jointly.
@@ -590,19 +590,19 @@ void genie_matrix_pls2 (NODE_T *p)
 // Eᵀ * F * Fᵀ * E * w / |Eᵀ * F * Fᵀ * w| = (1 / lambda) (Fᵀ * E)ᵀ * (Fᵀ * E) * w,
 // that is, w is an eigenvector of covariance matrix Fᵀ * E and 
 // longest eigenvector of symmetric matrix Eᵀ * F * Fᵀ * E.
-      a68_dgemm (FLIP, SELF, 1.0, E, u, 0.0, &eigens);
+      a68g_dgemm (FLIP, SELF, 1.0, E, u, 0.0, &eigens);
       norm_e = matrix_norm (eigens);
       ASSERT_GSL (gsl_matrix_scale (eigens, 1.0 / norm_e));
 // X factor score.
-      a68_dgemm (SELF, SELF, 1.0, E, eigens, 0.0, &t);
+      a68g_dgemm (SELF, SELF, 1.0, E, eigens, 0.0, &t);
       norm = matrix_norm (t);
       ASSERT_GSL (gsl_matrix_scale (t, 1.0 / norm));
 // Y weight.
-      a68_dgemm (FLIP, SELF, 1.0, F, t, 0.0, &c);
+      a68g_dgemm (FLIP, SELF, 1.0, F, t, 0.0, &c);
       norm = matrix_norm (c);
       ASSERT_GSL (gsl_matrix_scale (c, 1.0 / norm));
 // Y score.
-      a68_dgemm (SELF, SELF, 1.0, F, c, 0.0, &u);
+      a68g_dgemm (SELF, SELF, 1.0, F, c, 0.0, &u);
       gsl_matrix_memcpy (diff, u);
       gsl_matrix_sub (diff, u0);
       norm = matrix_norm (diff);
@@ -616,16 +616,16 @@ void genie_matrix_pls2 (NODE_T *p)
     } else {
       gsl_vector_set (Sv, k, norm_e);
 // X factor loading and deflation.
-      a68_dgemm (FLIP, SELF, 1.0, E, t, 0.0, &pl);
+      a68g_dgemm (FLIP, SELF, 1.0, E, t, 0.0, &pl);
       norm = matrix_norm (t);
       ASSERT_GSL (gsl_matrix_scale (pl, 1.0 / (norm * norm)));
-      a68_dgemm (SELF, FLIP, -1.0, t, pl, 1.0, &E);
+      a68g_dgemm (SELF, FLIP, -1.0, t, pl, 1.0, &E);
 // Y factor loading and deflation.
-      a68_dgemm (FLIP, SELF, 1.0, F, u, 0.0, &ql);
+      a68g_dgemm (FLIP, SELF, 1.0, F, u, 0.0, &ql);
       norm = matrix_norm (u);
       ASSERT_GSL (gsl_matrix_scale (ql, 1.0 / (norm * norm)));
-      a68_dgemm (FLIP, SELF, 1.0, t, u, 0.0, &b);
-      a68_dgemm (SELF, FLIP, -gsl_matrix_get (b, 0, 0), t, ql, 1.0, &F);
+      a68g_dgemm (FLIP, SELF, 1.0, t, u, 0.0, &b);
+      a68g_dgemm (SELF, FLIP, -gsl_matrix_get (b, 0, 0), t, ql, 1.0, &F);
 // Build vector and matrices.
       gsl_vector_set (dD, k, gsl_matrix_get (b, 0, 0));
       nP = mat_before_ab (p, nP, pl); // P
@@ -641,8 +641,8 @@ void genie_matrix_pls2 (NODE_T *p)
   gsl_matrix *mpinv = NO_REAL_MATRIX;
   compute_pseudo_inverse (p, &mpinv, nP, SMALL_EIGEN);
   gsl_matrix *z = NO_REAL_MATRIX, *beta = NO_REAL_MATRIX;
-  a68_dgemm (FLIP, SELF, 1.0, mpinv, D, 0.0, &z);
-  a68_dgemm (SELF, FLIP, 1.0, z, nC, 0.0, &beta);
+  a68g_dgemm (FLIP, SELF, 1.0, mpinv, D, 0.0, &z);
+  a68g_dgemm (SELF, FLIP, 1.0, z, nC, 0.0, &beta);
 // Yield results.
   if (!IS_NIL (singulars)) {
     gsl_vector *Svl = gsl_vector_calloc (Nk);
@@ -650,28 +650,28 @@ void genie_matrix_pls2 (NODE_T *p)
       gsl_vector_set (Svl, k, gsl_vector_get (Sv, k));
     }
     *DEREF (A68_REF, &singulars) = vector_to_row (p, Svl);
-    a68_vector_free (Svl);
+    a68g_vector_free (Svl);
   }
   push_matrix (p, beta);
   (void) gsl_set_error_handler (save_handler);
 // Garbage collector.
-  a68_vector_free (dD);
-  a68_vector_free (Sv);
-  a68_matrix_free (b);
-  a68_matrix_free (beta);
-  a68_matrix_free (c);
-  a68_matrix_free (D);
-  a68_matrix_free (diff);
-  a68_matrix_free (eigens);
-  a68_matrix_free (nC);
-  a68_matrix_free (nP);
-  a68_matrix_free (mpinv);
-  a68_matrix_free (pl);
-  a68_matrix_free (ql);
-  a68_matrix_free (t);
-  a68_matrix_free (u);
-  a68_matrix_free (u0);
-  a68_matrix_free (z);
+  a68g_vector_free (dD);
+  a68g_vector_free (Sv);
+  a68g_matrix_free (b);
+  a68g_matrix_free (beta);
+  a68g_matrix_free (c);
+  a68g_matrix_free (D);
+  a68g_matrix_free (diff);
+  a68g_matrix_free (eigens);
+  a68g_matrix_free (nC);
+  a68g_matrix_free (nP);
+  a68g_matrix_free (mpinv);
+  a68g_matrix_free (pl);
+  a68g_matrix_free (ql);
+  a68g_matrix_free (t);
+  a68g_matrix_free (u);
+  a68g_matrix_free (u0);
+  a68g_matrix_free (z);
 #undef PLS_MAX_ITER
 }
 
