@@ -72,8 +72,8 @@ void genie_R_psigamma_real (NODE_T * p)
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);
 }
 
-#define D_3(a68_fun, R_fun)\
-void a68_fun (NODE_T * p)\
+#define D_3(a68g_fun, R_fun)\
+void a68g_fun (NODE_T * p)\
 {\
   A68_BOOL give_log;\
   A68_REAL a, b;\
@@ -86,8 +86,8 @@ void a68_fun (NODE_T * p)\
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);\
 }
 
-#define D_4(a68_fun, R_fun)\
-void a68_fun (NODE_T * p)\
+#define D_4(a68g_fun, R_fun)\
+void a68g_fun (NODE_T * p)\
 {\
   A68_BOOL give_log;\
   A68_REAL a, b, c;\
@@ -101,8 +101,8 @@ void a68_fun (NODE_T * p)\
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);\
 }
 
-#define D_5(a68_fun, R_fun)\
-void a68_fun (NODE_T * p)\
+#define D_5(a68g_fun, R_fun)\
+void a68g_fun (NODE_T * p)\
 {\
   A68_BOOL give_log;\
   A68_REAL a, b, c, d;\
@@ -117,8 +117,8 @@ void a68_fun (NODE_T * p)\
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);\
 }
 
-#define PQ_4(a68_fun, R_fun)\
-void a68_fun (NODE_T * p)\
+#define PQ_4(a68g_fun, R_fun)\
+void a68g_fun (NODE_T * p)\
 {\
   A68_BOOL lower_tail, log_p;\
   A68_REAL x, a;\
@@ -133,8 +133,8 @@ void a68_fun (NODE_T * p)\
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);\
 }
 
-#define PQ_5(a68_fun, R_fun)\
-void a68_fun (NODE_T * p)\
+#define PQ_5(a68g_fun, R_fun)\
+void a68g_fun (NODE_T * p)\
 {\
   A68_BOOL lower_tail, log_p;\
   A68_REAL x, a, b;\
@@ -150,8 +150,8 @@ void a68_fun (NODE_T * p)\
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);\
 }
 
-#define PQ_6(a68_fun, R_fun)\
-void a68_fun (NODE_T * p)\
+#define PQ_6(a68g_fun, R_fun)\
+void a68g_fun (NODE_T * p)\
 {\
   A68_BOOL lower_tail, log_p;\
   A68_REAL x, a, b, c;\
@@ -168,8 +168,8 @@ void a68_fun (NODE_T * p)\
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);\
 }
 
-#define R_1(a68_fun, R_fun)\
-void a68_fun (NODE_T * p)\
+#define R_1(a68g_fun, R_fun)\
+void a68g_fun (NODE_T * p)\
 {\
   A68_REAL a;\
   POP_OBJECT (p, &a, A68_REAL);\
@@ -178,8 +178,8 @@ void a68_fun (NODE_T * p)\
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);\
 }
 
-#define R_2(a68_fun, R_fun)\
-void a68_fun (NODE_T * p)\
+#define R_2(a68g_fun, R_fun)\
+void a68g_fun (NODE_T * p)\
 {\
   A68_REAL a, b;\
   POP_OBJECT (p, &b, A68_REAL);\
@@ -189,8 +189,8 @@ void a68_fun (NODE_T * p)\
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);\
 }
 
-#define R_3(a68_fun, R_fun)\
-void a68_fun (NODE_T * p)\
+#define R_3(a68g_fun, R_fun)\
+void a68g_fun (NODE_T * p)\
 {\
   A68_REAL a, b, c;\
   POP_OBJECT (p, &c, A68_REAL);\
