@@ -70,7 +70,7 @@ void genie_add_int (NODE_T * p)
   A68_INT *i, *j;
   POP_OPERAND_ADDRESSES (p, i, j, A68_INT);
   errno = 0;
-  VALUE (i) = a68_add_int (VALUE (i), VALUE (j));
+  VALUE (i) = a68g_add_int (VALUE (i), VALUE (j));
   MATH_RTE (p, errno != 0, M_INT, "M overflow");
 }
 
@@ -81,7 +81,7 @@ void genie_sub_int (NODE_T * p)
   A68_INT *i, *j;
   POP_OPERAND_ADDRESSES (p, i, j, A68_INT);
   errno = 0;
-  VALUE (i) = a68_sub_int (VALUE (i), VALUE (j));
+  VALUE (i) = a68g_sub_int (VALUE (i), VALUE (j));
   MATH_RTE (p, errno != 0, M_INT, "M overflow");
 }
 
@@ -92,7 +92,7 @@ void genie_mul_int (NODE_T * p)
   A68_INT *i, *j;
   POP_OPERAND_ADDRESSES (p, i, j, A68_INT);
   errno = 0;
-  VALUE (i) = a68_mul_int (VALUE (i), VALUE (j));
+  VALUE (i) = a68g_mul_int (VALUE (i), VALUE (j));
   MATH_RTE (p, errno != 0, M_INT, "M overflow");
 }
 
@@ -103,7 +103,7 @@ void genie_over_int (NODE_T * p)
   A68_INT *i, *j;
   POP_OPERAND_ADDRESSES (p, i, j, A68_INT);
   errno = 0;
-  VALUE (i) = a68_over_int (VALUE (i), VALUE (j));
+  VALUE (i) = a68g_over_int (VALUE (i), VALUE (j));
   MATH_RTE (p, errno != 0, M_INT, ERROR_DIVISION_BY_ZERO);
 }
 
@@ -114,7 +114,7 @@ void genie_mod_int (NODE_T * p)
   A68_INT *i, *j;
   POP_OPERAND_ADDRESSES (p, i, j, A68_INT);
   errno = 0;
-  VALUE (i) = a68_mod_int (VALUE (i), VALUE (j));
+  VALUE (i) = a68g_mod_int (VALUE (i), VALUE (j));
   MATH_RTE (p, errno != 0, M_INT, ERROR_DIVISION_BY_ZERO);
 }
 
@@ -126,7 +126,7 @@ void genie_div_int (NODE_T * p)
   POP_OBJECT (p, &j, A68_INT);
   POP_OBJECT (p, &i, A68_INT);
   errno = 0;
-  PUSH_VALUE (p, a68_div_int (VALUE (&i), VALUE (&j)), A68_REAL);
+  PUSH_VALUE (p, a68g_div_int (VALUE (&i), VALUE (&j)), A68_REAL);
   MATH_RTE (p, errno != 0, M_INT, "M division by zero");
 }
 
@@ -139,7 +139,7 @@ void genie_pow_int (NODE_T * p)
   PRELUDE_ERROR (VALUE (&j) < 0, p, ERROR_EXPONENT_INVALID, M_INT);
   POP_OBJECT (p, &i, A68_INT);
   errno = 0;
-  PUSH_VALUE (p, a68_m_up_n (VALUE (&i), VALUE (&j)), A68_INT);
+  PUSH_VALUE (p, a68g_m_up_n (VALUE (&i), VALUE (&j)), A68_INT);
   MATH_RTE (p, errno != 0, M_INT, "M overflow");
 }
 
@@ -217,7 +217,7 @@ void genie_round_real (NODE_T * p)
   A68_REAL x;
   POP_OBJECT (p, &x, A68_REAL);
   PRELUDE_ERROR (VALUE (&x) < -(REAL_T) A68_MAX_INT || VALUE (&x) > (REAL_T) A68_MAX_INT, p, ERROR_OUT_OF_BOUNDS, M_INT);
-  PUSH_VALUE (p, a68_round (VALUE (&x)), A68_INT);
+  PUSH_VALUE (p, a68g_round (VALUE (&x)), A68_INT);
 }
 
 // OP ENTIER = (REAL) INT
@@ -287,7 +287,7 @@ void genie_pow_real_int (NODE_T * p)
   A68_REAL x;
   POP_OBJECT (p, &j, A68_INT);
   POP_OBJECT (p, &x, A68_REAL);
-  REAL_T z = a68_x_up_n_real (VALUE (&x), VALUE (&j));
+  REAL_T z = a68g_x_up_n_real (VALUE (&x), VALUE (&j));
   CHECK_REAL (p, z);
   PUSH_VALUE (p, z, A68_REAL);
 }
@@ -300,7 +300,7 @@ void genie_pow_real (NODE_T * p)
   POP_OBJECT (p, &y, A68_REAL);
   POP_OBJECT (p, &x, A68_REAL);
   errno = 0;
-  REAL_T z = a68_x_up_y (VALUE (&x), VALUE (&y));
+  REAL_T z = a68g_x_up_y (VALUE (&x), VALUE (&y));
   MATH_RTE (p, errno != 0, M_REAL, NO_TEXT);
   PUSH_VALUE (p, z, A68_REAL);
 }
@@ -363,14 +363,14 @@ void genie_first_random (NODE_T * p)
 
 void genie_next_random (NODE_T * p)
 {
-  PUSH_VALUE (p, a68_unif_rand (), A68_REAL);
+  PUSH_VALUE (p, a68g_unif_rand (), A68_REAL);
 }
 
 // @brief PROC REAL rnd
 
 void genie_next_rnd (NODE_T * p)
 {
-  PUSH_VALUE (p, 2 * a68_unif_rand () - 1, A68_REAL);
+  PUSH_VALUE (p, 2 * a68g_unif_rand () - 1, A68_REAL);
 }
 
 // @brief PROC (REAL) REAL sqrt
@@ -402,14 +402,14 @@ void genie_exp_real (NODE_T * p)
 
 void genie_ln_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_ln_real);
+  C_FUNCTION (p, a68g_ln_real);
 }
 
 // @brief PROC (REAL) REAL ln1p
 
 void genie_ln1p_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_ln1p_real);
+  C_FUNCTION (p, a68g_ln1p_real);
 }
 
 // @brief PROC (REAL) REAL log
@@ -437,7 +437,7 @@ void genie_asin_real (NODE_T * p)
 
 void genie_cas_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_cas_real);
+  C_FUNCTION (p, a68g_cas_real);
 }
 
 // @brief PROC (REAL) REAL cos
@@ -465,42 +465,42 @@ void genie_tan_real (NODE_T * p)
 
 void genie_csc_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_csc_real);
+  C_FUNCTION (p, a68g_csc_real);
 }
 
 // @brief PROC (REAL) REAL acsc
 
 void genie_acsc_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_acsc_real);
+  C_FUNCTION (p, a68g_acsc_real);
 }
 
 // @brief PROC (REAL) REAL sec 
 
 void genie_sec_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_sec_real);
+  C_FUNCTION (p, a68g_sec_real);
 }
 
 // @brief PROC (REAL) REAL asec
 
 void genie_asec_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_asec_real);
+  C_FUNCTION (p, a68g_asec_real);
 }
 
 // @brief PROC (REAL) REAL cot 
 
 void genie_cot_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_cot_real);
+  C_FUNCTION (p, a68g_cot_real);
 }
 
 // @brief PROC (REAL) REAL acot
 
 void genie_acot_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_acot_real);
+  C_FUNCTION (p, a68g_acot_real);
 }
 
 // @brief PROC (REAL) REAL arctan
@@ -518,7 +518,7 @@ void genie_atan2_real (NODE_T * p)
   POP_OPERAND_ADDRESSES (p, x, y, A68_REAL);
   errno = 0;
   PRELUDE_ERROR (VALUE (x) == 0.0 && VALUE (y) == 0.0, p, ERROR_INVALID_ARGUMENT, M_LONG_REAL);
-  VALUE (x) = a68_atan2_real (VALUE (y), VALUE (x));
+  VALUE (x) = a68g_atan2_real (VALUE (y), VALUE (x));
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);
 }
 
@@ -526,84 +526,84 @@ void genie_atan2_real (NODE_T * p)
 
 void genie_sindg_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_sindg_real);
+  C_FUNCTION (p, a68g_sindg_real);
 }
 
 // @brief PROC (REAL) REAL arcsindg
 
 void genie_asindg_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_asindg_real);
+  C_FUNCTION (p, a68g_asindg_real);
 }
 
 // @brief PROC (REAL) REAL cosdg
 
 void genie_cosdg_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_cosdg_real);
+  C_FUNCTION (p, a68g_cosdg_real);
 }
 
 // @brief PROC (REAL) REAL arccosdg
 
 void genie_acosdg_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_acosdg_real);
+  C_FUNCTION (p, a68g_acosdg_real);
 }
 
 // @brief PROC (REAL) REAL tandg
 
 void genie_tandg_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_tandg_real);
+  C_FUNCTION (p, a68g_tandg_real);
 }
 
 // @brief PROC (REAL) REAL arctandg
 
 void genie_atandg_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_atandg_real);
+  C_FUNCTION (p, a68g_atandg_real);
 }
 
 // @brief PROC (REAL) REAL cscdg
 
 void genie_cscdg_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_cscdg_real);
+  C_FUNCTION (p, a68g_cscdg_real);
 }
 
 // @brief PROC (REAL) REAL acscdg
 
 void genie_acscdg_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_acscdg_real);
+  C_FUNCTION (p, a68g_acscdg_real);
 }
 
 // @brief PROC (REAL) REAL secdg 
 
 void genie_secdg_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_secdg_real);
+  C_FUNCTION (p, a68g_secdg_real);
 }
 
 // @brief PROC (REAL) REAL asecdg
 
 void genie_asecdg_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_asecdg_real);
+  C_FUNCTION (p, a68g_asecdg_real);
 }
 
 // @brief PROC (REAL) REAL cotdg 
 
 void genie_cotdg_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_cot_realdg_real);
+  C_FUNCTION (p, a68g_cot_realdg_real);
 }
 
 // @brief PROC (REAL) REAL acotdg
 
 void genie_acotdg_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_acotdg_real);
+  C_FUNCTION (p, a68g_acotdg_real);
 }
 
 // @brief PROC (REAL, REAL) REAL arctan2dg
@@ -614,7 +614,7 @@ void genie_atan2dg_real (NODE_T * p)
   POP_OPERAND_ADDRESSES (p, x, y, A68_REAL);
   errno = 0;
   PRELUDE_ERROR (VALUE (x) == 0.0 && VALUE (y) == 0.0, p, ERROR_INVALID_ARGUMENT, M_LONG_REAL);
-  VALUE (x) = CONST_180_OVER_PI * a68_atan2_real (VALUE (y), VALUE (x));
+  VALUE (x) = CONST_180_OVER_PI * a68g_atan2_real (VALUE (y), VALUE (x));
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);
 }
 
@@ -622,28 +622,28 @@ void genie_atan2dg_real (NODE_T * p)
 
 void genie_sinpi_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_sinpi_real);
+  C_FUNCTION (p, a68g_sinpi_real);
 }
 
 // @brief PROC (REAL) REAL cospi
 
 void genie_cospi_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_cospi_real);
+  C_FUNCTION (p, a68g_cospi_real);
 }
 
 // @brief PROC (REAL) REAL tanpi
 
 void genie_tanpi_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_tanpi_real);
+  C_FUNCTION (p, a68g_tanpi_real);
 }
 
 // @brief PROC (REAL) REAL cotpi 
 
 void genie_cotpi_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_cot_realpi);
+  C_FUNCTION (p, a68g_cot_realpi);
 }
 
 // @brief PROC (REAL) REAL sinh
@@ -671,21 +671,21 @@ void genie_tanh_real (NODE_T * p)
 
 void genie_asinh_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_asinh_real);
+  C_FUNCTION (p, a68g_asinh_real);
 }
 
 // @brief PROC (REAL) REAL acosh
 
 void genie_acosh_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_acosh_real);
+  C_FUNCTION (p, a68g_acosh_real);
 }
 
 // @brief PROC (REAL) REAL atanh
 
 void genie_atanh_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_atanh_real);
+  C_FUNCTION (p, a68g_atanh_real);
 }
 
 // @brief PROC (REAL) REAL erf
@@ -699,7 +699,7 @@ void genie_erf_real (NODE_T * p)
 
 void genie_inverf_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_inverf_real);
+  C_FUNCTION (p, a68g_inverf_real);
 }
 
 // @brief PROC (REAL) REAL erfc
@@ -713,7 +713,7 @@ void genie_erfc_real (NODE_T * p)
 
 void genie_inverfc_real (NODE_T * p)
 {
-  C_FUNCTION (p, a68_inverfc_real);
+  C_FUNCTION (p, a68g_inverfc_real);
 }
 
 // @brief PROC (REAL) REAL gamma
@@ -737,7 +737,7 @@ void genie_beta_real (NODE_T * p)
   A68_REAL *x, *y;
   POP_OPERAND_ADDRESSES (p, x, y, A68_REAL);
   errno = 0;
-  VALUE (x) = a68_beta_real (VALUE (x), VALUE (y));
+  VALUE (x) = a68g_beta_real (VALUE (x), VALUE (y));
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);
 }
 
@@ -748,7 +748,7 @@ void genie_ln_beta_real (NODE_T * p)
   A68_REAL *x, *y;
   POP_OPERAND_ADDRESSES (p, x, y, A68_REAL);
   errno = 0;
-  VALUE (x) = a68_ln_beta_real (VALUE (x), VALUE (y));
+  VALUE (x) = a68g_ln_beta_real (VALUE (x), VALUE (y));
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);
 }
 
@@ -759,7 +759,7 @@ void genie_beta_inc_cf_real (NODE_T * p)
   A68_REAL *s, *t, *x;
   POP_3_OPERAND_ADDRESSES (p, s, t, x, A68_REAL);
   errno = 0;
-  VALUE (s) = a68_beta_inc_real (VALUE (s), VALUE (t), VALUE (x));
+  VALUE (s) = a68g_beta_inc_real (VALUE (s), VALUE (t), VALUE (x));
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);
 }
 
@@ -849,7 +849,7 @@ void genie_abs_complex (NODE_T * p)
 {
   A68_REAL re_x, im_x;
   POP_COMPLEX (p, &re_x, &im_x);
-  PUSH_VALUE (p, a68_hypot_real (VALUE (&re_x), VALUE (&im_x)), A68_REAL);
+  PUSH_VALUE (p, a68g_hypot_real (VALUE (&re_x), VALUE (&im_x)), A68_REAL);
 }
 
 // OP ARG = (COMPLEX) REAL
@@ -1148,105 +1148,105 @@ void genie_atanh_complex (NODE_T * p)
 
 //! @brief PROC (COMPLEX) COMPLEX csqrt
 
-void a68_sqrt_complex (A68_REAL * z, A68_REAL * x)
+void a68g_sqrt_complex (A68_REAL * z, A68_REAL * x)
 {
   C_C_INLINE (z, x, csqrt);
 }
 
 //! @brief PROC (COMPLEX) COMPLEX cexp
 
-void a68_exp_real_complex (A68_REAL * z, A68_REAL * x)
+void a68g_exp_real_complex (A68_REAL * z, A68_REAL * x)
 {
   C_C_INLINE (z, x, cexp);
 }
 
 //! @brief PROC (COMPLEX) COMPLEX cln
 
-void a68_ln_complex (A68_REAL * z, A68_REAL * x)
+void a68g_ln_complex (A68_REAL * z, A68_REAL * x)
 {
   C_C_INLINE (z, x, clog);
 }
 
 //! @brief PROC (COMPLEX) COMPLEX csin
 
-void a68_sin_complex (A68_REAL * z, A68_REAL * x)
+void a68g_sin_complex (A68_REAL * z, A68_REAL * x)
 {
   C_C_INLINE (z, x, csin);
 }
 
 //! @brief PROC (COMPLEX) COMPLEX ccos
 
-void a68_cos_complex (A68_REAL * z, A68_REAL * x)
+void a68g_cos_complex (A68_REAL * z, A68_REAL * x)
 {
   C_C_INLINE (z, x, ccos);
 }
 
 //! @brief PROC (COMPLEX) COMPLEX ctan
 
-void a68_tan_complex (A68_REAL * z, A68_REAL * x)
+void a68g_tan_complex (A68_REAL * z, A68_REAL * x)
 {
   C_C_INLINE (z, x, ctan);
 }
 
 //! @brief PROC (COMPLEX) COMPLEX casin
 
-void a68_asin_complex (A68_REAL * z, A68_REAL * x)
+void a68g_asin_complex (A68_REAL * z, A68_REAL * x)
 {
   C_C_INLINE (z, x, casin);
 }
 
 //! @brief PROC (COMPLEX) COMPLEX cacos
 
-void a68_acos_complex (A68_REAL * z, A68_REAL * x)
+void a68g_acos_complex (A68_REAL * z, A68_REAL * x)
 {
   C_C_INLINE (z, x, cacos);
 }
 
 //! @brief PROC (COMPLEX) COMPLEX catan
 
-void a68_atan_complex (A68_REAL * z, A68_REAL * x)
+void a68g_atan_complex (A68_REAL * z, A68_REAL * x)
 {
   C_C_INLINE (z, x, catan);
 }
 
 //! @brief PROC (COMPLEX) COMPLEX csinh
 
-void a68_sinh_complex (A68_REAL * z, A68_REAL * x)
+void a68g_sinh_complex (A68_REAL * z, A68_REAL * x)
 {
   C_C_INLINE (z, x, csinh);
 }
 
 //! @brief PROC (COMPLEX) COMPLEX ccosh
 
-void a68_cosh_complex (A68_REAL * z, A68_REAL * x)
+void a68g_cosh_complex (A68_REAL * z, A68_REAL * x)
 {
   C_C_INLINE (z, x, ccosh);
 }
 
 //! @brief PROC (COMPLEX) COMPLEX ctanh
 
-void a68_tanh_complex (A68_REAL * z, A68_REAL * x)
+void a68g_tanh_complex (A68_REAL * z, A68_REAL * x)
 {
   C_C_INLINE (z, x, ctanh);
 }
 
 //! @brief PROC (COMPLEX) COMPLEX casinh
 
-void a68_asinh_real_complex (A68_REAL * z, A68_REAL * x)
+void a68g_asinh_real_complex (A68_REAL * z, A68_REAL * x)
 {
   C_C_INLINE (z, x, casinh);
 }
 
 //! @brief PROC (COMPLEX) COMPLEX cacosh
 
-void a68_acosh_real_complex (A68_REAL * z, A68_REAL * x)
+void a68g_acosh_real_complex (A68_REAL * z, A68_REAL * x)
 {
   C_C_INLINE (z, x, cacosh);
 }
 
 //! @brief PROC (COMPLEX) COMPLEX catanh
 
-void a68_atanh_real_complex (A68_REAL * z, A68_REAL * x)
+void a68g_atanh_real_complex (A68_REAL * z, A68_REAL * x)
 {
   C_C_INLINE (z, x, catanh);
 }
@@ -1258,7 +1258,7 @@ void genie_fact_real (NODE_T * p)
   A68_INT n;
   POP_OBJECT (p, &n, A68_INT);
   errno = 0;
-  PUSH_VALUE (p, a68_fact_real (VALUE (&n)), A68_REAL);
+  PUSH_VALUE (p, a68g_fact_real (VALUE (&n)), A68_REAL);
   MATH_RTE (p, errno != 0, M_INT, NO_TEXT);
 }
 
@@ -1269,7 +1269,7 @@ void genie_ln_fact_real (NODE_T * p)
   A68_INT n;
   POP_OBJECT (p, &n, A68_INT);
   errno = 0;
-  PUSH_VALUE (p, a68_ln_fact_real (VALUE (&n)), A68_REAL);
+  PUSH_VALUE (p, a68g_ln_fact_real (VALUE (&n)), A68_REAL);
   MATH_RTE (p, errno != 0, M_INT, NO_TEXT);
 }
 
@@ -1279,7 +1279,7 @@ void genie_choose_real (NODE_T * p)
   POP_OBJECT (p, &m, A68_INT);
   POP_OBJECT (p, &n, A68_INT);
   errno = 0;
-  PUSH_VALUE (p, a68_choose_real (VALUE (&n), VALUE (&m)), A68_REAL);
+  PUSH_VALUE (p, a68g_choose_real (VALUE (&n), VALUE (&m)), A68_REAL);
   MATH_RTE (p, errno != 0, M_INT, NO_TEXT);
 }
 
@@ -1291,13 +1291,13 @@ void genie_ln_choose_real (NODE_T * p)
   POP_OBJECT (p, &m, A68_INT);
   POP_OBJECT (p, &n, A68_INT);
   errno = 0;
-  PUSH_VALUE (p, a68_ln_choose_real (VALUE (&n), VALUE (&m)), A68_REAL);
+  PUSH_VALUE (p, a68g_ln_choose_real (VALUE (&n), VALUE (&m)), A68_REAL);
   MATH_RTE (p, errno != 0, M_INT, NO_TEXT);
 }
 
 // OP / = (COMPLEX, COMPLEX) COMPLEX
 
-void a68_div_complex (A68_REAL * z, A68_REAL * x, A68_REAL * y)
+void a68g_div_complex (A68_REAL * z, A68_REAL * x, A68_REAL * y)
 {
   STATUS_RE (z) = INIT_MASK;
   STATUS_IM (z) = INIT_MASK;
