@@ -4,7 +4,7 @@
 //! @section Copyright
 //!
 //! This file is part of Algol68G - an Algol 68 compiler-interpreter.
-//! Copyright 2001-2024 J. Marcel van der Veer [algol68g@xs4all.nl].
+//! Copyright 2001-2025 J. Marcel van der Veer [algol68g@xs4all.nl].
 
 //! @section License
 //!
@@ -47,7 +47,7 @@ struct MODULE_T
 };
 
 typedef struct MODE_CACHE_T MODE_CACHE_T;
-#define MODE(p)        A68 (a68_modes.p)
+#define MODE(p)        A68 (a68g_modes.p)
 struct MODE_CACHE_T
 {
   MOID_T *proc_bool;
@@ -293,7 +293,7 @@ struct GLOBALS_T
   BOOL_T no_warnings;
   BYTE_T *stack_segment, *heap_segment, *handle_segment;
   BYTE_T *system_stack_offset;
-  BUFFER a68_cmd_name;
+  BUFFER a68g_cmd_name;
   char **argv;
   char *f_plugin;
   char *marker[BUFFER_SIZE];
@@ -303,7 +303,7 @@ struct GLOBALS_T
   GC_GLOBALS_T gc;
   INDENT_GLOBALS_T indent;
   int argc;
-  int chars_in_tty_line;
+  int chars_in_stderr, chars_in_stdout;
   int global_level, max_lex_lvl;
   int max_simplout_size;
   int new_nodes, new_modes, new_postulates, new_node_infos, new_genie_infos;
@@ -313,7 +313,7 @@ struct GLOBALS_T
   jmp_buf genie_exit_label;
   KEYWORD_T *top_keyword;
   MODE_CACHE_T mode_cache;
-  MODES_T a68_modes;
+  MODES_T a68g_modes;
   MODULE_T job;
   MONITOR_GLOBALS_T mon;
   MP_GLOBALS_T mp;
