@@ -115,7 +115,7 @@
 
 #define _SKIP_ { (void) 0;}
 
-#define BUFCLR(z) {a68_bufset ((z), 0, BUFFER_SIZE + 1);}
+#define BUFCLR(z) {a68g_bufset ((z), 0, BUFFER_SIZE + 1);}
 
 #define ABS(n) ((n) >= 0 ? (n) : -(n))
 
@@ -227,7 +227,7 @@
 // Access macros
 
 #define A(p) ((p)->a)
-#define A68_STANDENV_PROC(p) ((p)->a68_standenv_proc)
+#define A68_STANDENV_PROC(p) ((p)->a68g_standenv_proc)
 #define ACTION(p) ((p)->action)
 #define ACTIVE(p) ((p)->active)
 #define ADDR(p) ((p)->addr)
@@ -643,7 +643,7 @@
 #define IS_LITERALLY(p, s) (strcmp (NSYMBOL (p), s) == 0)
 #define IS_NEW_LEXICAL_LEVEL(p) ((p)->is_new_lexical_level)
 #define ISNT(p, s) (! IS (p, s))
-#define IS(p, s) (ATTRIBUTE (p) == (s))
+#define IS(p, s) ((void *) (p) == NO_REF ? A68_FALSE : ATTRIBUTE (p) == (s))
 #define IS_REF_FLEX(m) (IS (m, REF_SYMBOL) && IS (SUB (m), FLEX_SYMBOL))
 #define IS_REF(m) IS ((m), REF_SYMBOL)
 #define IS_ROW(m) IS ((m), ROW_SYMBOL)
