@@ -43,12 +43,13 @@ void write_source_line (FILE_T, LINE_T *, NODE_T *, int);
 #define A68_MATH_WARNING      ((STATUS_MASK_T) 0x8)
 #define A68_WARNING           ((STATUS_MASK_T) 0x10)
 #define A68_RUNTIME_ERROR     ((STATUS_MASK_T) 0x20)
-#define A68_SUPPRESS_SEVERITY ((STATUS_MASK_T) 0x40)
 #define A68_ALL_DIAGNOSTICS   ((STATUS_MASK_T) 0x80)
 #define A68_RERUN             ((STATUS_MASK_T) 0x100)
 #define A68_FORCE_DIAGNOSTICS ((STATUS_MASK_T) 0x200)
 #define A68_FORCE_QUIT        ((STATUS_MASK_T) 0x400)
 #define A68_NO_SYNTHESIS      ((STATUS_MASK_T) 0x800)
+#define A68_SCANNER_ERROR     ((STATUS_MASK_T) 0x1000)
+#define A68_SCANNER_WARNING   ((STATUS_MASK_T) 0x2000)
 
 // Diagnostic texts
 
@@ -127,7 +128,6 @@ void write_source_line (FILE_T, LINE_T *, NODE_T *, int);
 #define ERROR_INVALID_PARAMETER "invalid parameter (U Z)"
 #define ERROR_INVALID_PRIORITY "invalid priority declaration"
 #define ERROR_INVALID_RADIX "invalid radix D"
-#define ERROR_INVALID_SEQUENCE "Y is an invalid A"
 #define ERROR_INVALID_SIZE "object of invalid size"
 #define ERROR_INVALID_VALUE "invalid value"
 #define ERROR_IN_DENOTATION "error in M denotation"
@@ -187,7 +187,7 @@ void write_source_line (FILE_T, LINE_T *, NODE_T *, int);
 #define ERROR_REFINEMENT_APPLIED "refinement is applied more than once"
 #define ERROR_REFINEMENT_DEFINED "refinement already defined"
 #define ERROR_REFINEMENT_EMPTY "empty refinement at end of source"
-#define ERROR_REFINEMENT_INVALID "invalid refinement"
+#define ERROR_REFINEMENT_INVALID "incorrect refinement"
 #define ERROR_REFINEMENT_NOT_APPLIED "refinement is not applied"
 #define ERROR_RESOLVE "cannot resolve symbol"
 #define ERROR_SCOPE_DYNAMIC_0 "value is exported out of its scope"
@@ -204,8 +204,8 @@ void write_source_line (FILE_T, LINE_T *, NODE_T *, int);
 #define ERROR_SYNTAX "detected in A"
 #define ERROR_SYNTAX_EXPECTED "expected A"
 #define ERROR_SYNTAX_MIXED_DECLARATION "possibly mixed identity-declaration and variable-declaration"
-#define ERROR_SYNTAX_STRANGE_SEPARATOR "possibly a missing or erroneous separator nearby"
-#define ERROR_SYNTAX_STRANGE_TOKENS "possibly a missing or erroneous symbol nearby"
+#define ERROR_SYNTAX_SENTENCE "incorrect sentence: Y"
+#define ERROR_SYNTAX_STRANGE_TOKENS "possibly a missing or incorrect symbol nearby"
 #define ERROR_TIME_LIMIT_EXCEEDED "time limit exceeded"
 #define ERROR_TOO_MANY_ARGUMENTS "too many arguments"
 #define ERROR_TOO_MANY_OPEN_FILES "too many open files"
